public abstract static class CoderRegistry.CoderFactory
extends java.lang.Object
| Constructor and Description |
|---|
CoderRegistry.CoderFactory() |
| Modifier and Type | Method and Description |
|---|---|
abstract Coder<?> |
create(java.util.List<? extends Coder<?>> typeArgumentCoders)
Returns the default Coder to use for values of a particular type,
given the Coders for each of the type's generic parameter types.
|
abstract java.util.List<java.lang.Object> |
getInstanceComponents(java.lang.Object value)
Returns a list of objects contained in
value, one per
type argument, or null if none can be determined. |
public abstract Coder<?> create(java.util.List<? extends Coder<?>> typeArgumentCoders)
public abstract java.util.List<java.lang.Object> getInstanceComponents(java.lang.Object value)
value, one per
type argument, or null if none can be determined.