T - the type of the values being transcodedpublic abstract class DeterministicStandardCoder<T> extends StandardCoder<T>
DeterministicStandardCoder is a StandardCoder that is
deterministic, in the sense that for objects considered equal
according to Object.equals(), the encoded bytes are
also equal.Coder.Context, Coder.NonDeterministicException| Modifier | Constructor and Description |
|---|---|
protected |
DeterministicStandardCoder() |
| Modifier and Type | Method and Description |
|---|---|
void |
verifyDeterministic()
As a
DeterministicStandardCoder is presumed deterministic, this
method does nothing. |
asCloudObject, consistentWithEquals, equals, getComponents, getEncodedElementByteSize, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, structuralValue, toString, verifyDeterministic, verifyDeterministicclone, finalize, getClass, notify, notifyAll, wait, wait, waitdecode, encode, getCoderArgumentspublic void verifyDeterministic()
throws Coder.NonDeterministicException
DeterministicStandardCoder is presumed deterministic, this
method does nothing.Coder.NonDeterministicException - if this coder is not deterministic.