public class DoubleCoder extends AtomicCoder<Double>
DoubleCoder encodes Double values in 8 bytes using Java serialization.Coder.Context, Coder.NonDeterministicException| Modifier and Type | Method and Description |
|---|---|
boolean |
consistentWithEquals()
Returns true if whenever the encoded bytes of two values are equal, then the original values
are equal according to
Objects.equals() (note that this is well-defined for
null). |
Double |
decode(InputStream inStream,
Coder.Context context)
Decodes a value of type
T from the given input stream in
the given context. |
void |
encode(Double value,
OutputStream outStream,
Coder.Context context)
Encodes the given value of type
T onto the given output stream
in the given context. |
protected long |
getEncodedElementByteSize(Double value,
Coder.Context context)
Returns the size in bytes of the encoded value using this
coder.
|
boolean |
isRegisterByteSizeObserverCheap(Double value,
Coder.Context context)
Returns true since registerByteSizeObserver() runs in constant time.
|
static DoubleCoder |
of() |
void |
verifyDeterministic()
Floating-point operations are not guaranteed to be deterministic, even
if the storage format might be, so floating point representations are not
recommended for use in operations that require deterministic inputs.
|
getCoderArguments, getInstanceComponentsasCloudObject, equals, getAllowedEncodings, getComponents, getEncodingId, hashCode, registerByteSizeObserver, structuralValue, toString, verifyDeterministic, verifyDeterministicpublic static DoubleCoder of()
public void encode(Double value, OutputStream outStream, Coder.Context context) throws IOException, CoderException
CoderT onto the given output stream
in the given context.IOException - if writing to the OutputStream fails
for some reasonCoderException - if the value could not be encoded for some reasonpublic Double decode(InputStream inStream, Coder.Context context) throws IOException, CoderException
CoderT from the given input stream in
the given context. Returns the decoded value.IOException - if reading from the InputStream fails
for some reasonCoderException - if the value could not be decoded for some reasonpublic void verifyDeterministic()
throws Coder.NonDeterministicException
verifyDeterministic in interface Coder<Double>verifyDeterministic in class DeterministicStandardCoder<Double>Coder.NonDeterministicException - if this coder is not deterministic.public boolean consistentWithEquals()
CoderObjects.equals() (note that this is well-defined for
null). In other words, encoding is injective.
This condition is most notably false for arrays. More generally, this condition is false
whenever equals() compares object identity, rather than performing a
semantic/structural comparison.
consistentWithEquals in interface Coder<Double>consistentWithEquals in class StandardCoder<Double>public boolean isRegisterByteSizeObserverCheap(Double value, Coder.Context context)
isRegisterByteSizeObserverCheap in interface Coder<Double>isRegisterByteSizeObserverCheap in class StandardCoder<Double>protected long getEncodedElementByteSize(Double value, Coder.Context context) throws Exception
StandardCodergetEncodedElementByteSize in class StandardCoder<Double>Exception