T - the type of the elements of the Iterables being transcodedpublic class IterableCoder<T> extends IterableLikeCoder<T,java.lang.Iterable<T>>
Coder.Context, Coder.NonDeterministicException| Modifier | Constructor and Description |
|---|---|
protected |
IterableCoder(Coder<T> elemCoder) |
| Modifier and Type | Method and Description |
|---|---|
com.google.cloud.dataflow.sdk.util.CloudObject |
asCloudObject()
Returns the
CloudObject that represents this Coder. |
protected java.lang.Iterable<T> |
decodeToIterable(java.util.List<T> decodedElements)
Builds an instance of the coder's associated
Iterable from a list
of decoded elements. |
static <T> java.util.List<java.lang.Object> |
getInstanceComponents(java.lang.Iterable<T> exampleValue)
Returns the first element in this iterable if it is non-empty,
otherwise returns
null. |
static <T> IterableCoder<T> |
of(Coder<T> elemCoder) |
static IterableCoder<?> |
of(java.util.List<Coder<?>> components) |
decode, encode, getCoderArguments, getElemCoder, getInstanceComponentsHelper, isDeterministic, isRegisterByteSizeObserverCheap, registerByteSizeObserver, verifyDeterministicequals, getComponents, getEncodedElementByteSize, hashCode, toString, verifyDeterministic, verifyDeterministicpublic static <T> IterableCoder<T> of(Coder<T> elemCoder)
protected final java.lang.Iterable<T> decodeToIterable(java.util.List<T> decodedElements)
IterableLikeCoderIterable from a list
of decoded elements. If IT is a supertype of List<T>, the
derived class implementation is permitted to return decodedElements
directly.decodeToIterable in class IterableLikeCoder<T,java.lang.Iterable<T>>public static IterableCoder<?> of(java.util.List<Coder<?>> components)
public static <T> java.util.List<java.lang.Object> getInstanceComponents(java.lang.Iterable<T> exampleValue)
null.public com.google.cloud.dataflow.sdk.util.CloudObject asCloudObject()
CoderCloudObject that represents this Coder.asCloudObject in interface Coder<java.lang.Iterable<T>>asCloudObject in class StandardCoder<java.lang.Iterable<T>>