T - the type of values being transcodedpublic abstract class KvCoderBase<T> extends StandardCoder<T>
KvCoder directly (as of this writing, Jackson2 walks off the end of
an array when it tries to deserialize a class with multiple generic type
parameters). This class should be removed when possible.Coder.Context, Coder.NonDeterministicException| Modifier | Constructor and Description |
|---|---|
protected |
KvCoderBase() |
| Modifier and Type | Method and Description |
|---|---|
static KvCoderBase<?> |
of(String typeId,
boolean isPairLike,
List<Coder<?>> components) |
asCloudObject, consistentWithEquals, equals, getComponents, getEncodedElementByteSize, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, structuralValue, toString, verifyDeterministic, verifyDeterministicclone, finalize, getClass, notify, notifyAll, wait, wait, waitdecode, encode, getCoderArguments, verifyDeterministicpublic static KvCoderBase<?> of(String typeId, boolean isPairLike, List<Coder<?>> components)