T - the type of values being transcoded@Deprecated public abstract class MapCoderBase<T> extends StandardCoder<T>
MapCoder directly (as of this writing, Jackson2 walks off the end of
an array when it tries to deserialize a class with multiple generic type
parameters). This should be removed in favor of a better workaround.Coder.Context, Coder.NonDeterministicException| Modifier | Constructor and Description |
|---|---|
protected |
MapCoderBase()
Deprecated.
|
| Modifier and Type | Method and Description |
|---|---|
static MapCoderBase<?> |
of(String typeId,
List<Coder<?>> components)
Deprecated.
|
asCloudObject, consistentWithEquals, equals, getAllowedEncodings, getComponents, getEncodedElementByteSize, getEncodingId, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, structuralValue, toString, verifyDeterministic, verifyDeterministicclone, finalize, getClass, notify, notifyAll, wait, wait, waitdecode, encode, getCoderArguments, verifyDeterministic@Deprecated public static MapCoderBase<?> of(String typeId, List<Coder<?>> components)