public class TableRowJsonCoder extends AtomicCoder<com.google.api.services.bigquery.model.TableRow>
TableRowJsonCoder encodes BigQuery TableRow objects.Coder.Context, Coder.NonDeterministicException| Modifier and Type | Method and Description |
|---|---|
com.google.api.services.bigquery.model.TableRow |
decode(InputStream inStream,
Coder.Context context)
Decodes a value of type
T from the given input stream in
the given context. |
void |
encode(com.google.api.services.bigquery.model.TableRow value,
OutputStream outStream,
Coder.Context context)
Encodes the given value of type
T onto the given output stream
in the given context. |
protected long |
getEncodedElementByteSize(com.google.api.services.bigquery.model.TableRow value,
Coder.Context context)
Returns the size in bytes of the encoded value using this
coder.
|
static TableRowJsonCoder |
of() |
void |
verifyDeterministic()
TableCell can hold arbitrary Object instances, which makes the encoding
non-deterministic.
|
getCoderArguments, getInstanceComponentsasCloudObject, consistentWithEquals, equals, getAllowedEncodings, getComponents, getEncodingId, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, structuralValue, toString, verifyDeterministic, verifyDeterministicpublic static TableRowJsonCoder of()
public void encode(com.google.api.services.bigquery.model.TableRow value,
OutputStream outStream,
Coder.Context context)
throws IOException
CoderT onto the given output stream
in the given context.IOException - if writing to the OutputStream fails
for some reasonCoderException - if the value could not be encoded for some reasonpublic com.google.api.services.bigquery.model.TableRow decode(InputStream inStream, Coder.Context context) throws IOException
CoderT from the given input stream in
the given context. Returns the decoded value.IOException - if reading from the InputStream fails
for some reasonCoderException - if the value could not be decoded for some reasonprotected long getEncodedElementByteSize(com.google.api.services.bigquery.model.TableRow value,
Coder.Context context)
throws Exception
StandardCodergetEncodedElementByteSize in class StandardCoder<com.google.api.services.bigquery.model.TableRow>Exceptionpublic void verifyDeterministic()
throws Coder.NonDeterministicException
verifyDeterministic in interface Coder<com.google.api.services.bigquery.model.TableRow>verifyDeterministic in class DeterministicStandardCoder<com.google.api.services.bigquery.model.TableRow>Coder.NonDeterministicException - if this coder is not deterministic.