public class VarIntCoder extends AtomicCoder<Integer>
VarIntCoder encodes Integers using between 1 and 5 bytes. Negative
numbers always take 5 bytes, so BigEndianIntegerCoder may be preferable for
ints that are known to often be large or negative.Coder.Context, Coder.NonDeterministicException| Modifier and Type | Method and Description |
|---|---|
boolean |
consistentWithEquals()
Returns true if the encoded bytes of two objects are
equal only when they are also equal according to
Object.equals(). |
Integer |
decode(InputStream inStream,
Coder.Context context)
Decodes a value of type
T from the given input stream in
the given context. |
void |
encode(Integer value,
OutputStream outStream,
Coder.Context context)
Encodes the given value of type
T onto the given output stream
in the given context. |
protected long |
getEncodedElementByteSize(Integer value,
Coder.Context context)
Returns the size in bytes of the encoded value using this
coder.
|
boolean |
isRegisterByteSizeObserverCheap(Integer value,
Coder.Context context)
Returns true since registerByteSizeObserver() runs in constant time.
|
static VarIntCoder |
of() |
getCoderArguments, getInstanceComponentsverifyDeterministicasCloudObject, equals, getComponents, hashCode, registerByteSizeObserver, structuralValue, toString, verifyDeterministic, verifyDeterministicpublic static VarIntCoder of()
public void encode(Integer value, OutputStream outStream, Coder.Context context) throws IOException, CoderException
CoderT onto the given output stream
in the given context.IOException - if writing to the OutputStream fails
for some reasonCoderException - if the value could not be encoded for some reasonpublic Integer decode(InputStream inStream, Coder.Context context) throws IOException, CoderException
CoderT from the given input stream in
the given context. Returns the decoded value.IOException - if reading from the InputStream fails
for some reasonCoderException - if the value could not be decoded for some reasonpublic boolean consistentWithEquals()
CoderObject.equals().
(and also implements a compatible Object.hasCode())
This most notably false for arrays. It will generally
be false when Object.equals() compares object identity,
rather than performing a semantic/structural comparison.
consistentWithEquals in interface Coder<Integer>consistentWithEquals in class StandardCoder<Integer>public boolean isRegisterByteSizeObserverCheap(Integer value, Coder.Context context)
isRegisterByteSizeObserverCheap in interface Coder<Integer>isRegisterByteSizeObserverCheap in class StandardCoder<Integer>protected long getEncodedElementByteSize(Integer value, Coder.Context context) throws Exception
StandardCodergetEncodedElementByteSize in class StandardCoder<Integer>Exception