public class VarLongCoder extends AtomicCoder<Long>
VarLongCoder encodes longs using between 1 and 10 bytes. Negative
numbers always take 10 bytes, so BigEndianLongCoder may be preferable for
longs that are known to often be large or negative.Coder.Context, Coder.NonDeterministicException| Modifier and Type | Method and Description |
|---|---|
boolean |
consistentWithEquals()
Returns true if the encoded bytes of two objects are
equal only when they are also equal according to
Object.equals(). |
Long |
decode(InputStream inStream,
Coder.Context context)
Decodes a value of type
T from the given input stream in
the given context. |
void |
encode(Long value,
OutputStream outStream,
Coder.Context context)
Encodes the given value of type
T onto the given output stream
in the given context. |
protected long |
getEncodedElementByteSize(Long value,
Coder.Context context)
Returns the size in bytes of the encoded value using this
coder.
|
boolean |
isRegisterByteSizeObserverCheap(Long value,
Coder.Context context)
Returns true since registerByteSizeObserver() runs in constant time.
|
static VarLongCoder |
of() |
void |
verifyDeterministic()
As a
DeterministicStandardCoder is presumed deterministic, this
method does nothing. |
getCoderArguments, getInstanceComponentsasCloudObject, equals, getComponents, hashCode, registerByteSizeObserver, structuralValue, toString, verifyDeterministic, verifyDeterministicpublic static VarLongCoder of()
public void encode(Long value, OutputStream outStream, Coder.Context context) throws IOException, CoderException
CoderT onto the given output stream
in the given context.IOException - if writing to the OutputStream fails
for some reasonCoderException - if the value could not be encoded for some reasonpublic Long decode(InputStream inStream, Coder.Context context) throws IOException, CoderException
CoderT from the given input stream in
the given context. Returns the decoded value.IOException - if reading from the InputStream fails
for some reasonCoderException - if the value could not be decoded for some reasonpublic void verifyDeterministic()
DeterministicStandardCoderDeterministicStandardCoder is presumed deterministic, this
method does nothing.verifyDeterministic in interface Coder<Long>verifyDeterministic in class DeterministicStandardCoder<Long>public boolean consistentWithEquals()
CoderObject.equals().
(and also implements a compatible Object.hasCode())
This most notably false for arrays. It will generally
be false when Object.equals() compares object identity,
rather than performing a semantic/structural comparison.
consistentWithEquals in interface Coder<Long>consistentWithEquals in class StandardCoder<Long>public boolean isRegisterByteSizeObserverCheap(Long value, Coder.Context context)
isRegisterByteSizeObserverCheap in interface Coder<Long>isRegisterByteSizeObserverCheap in class StandardCoder<Long>protected long getEncodedElementByteSize(Long value, Coder.Context context) throws Exception
StandardCodergetEncodedElementByteSize in class StandardCoder<Long>Exception