public class VoidCoder extends AtomicCoder<Void>
VoidCoder encodes Voids. Uses zero bytes per Void.Coder.Context, Coder.NonDeterministicException| Modifier and Type | Method and Description |
|---|---|
boolean |
consistentWithEquals()
Returns true if whenever the encoded bytes of two values are equal, then the original values
are equal according to
Objects.equals() (note that this is well-defined for
null). |
Void |
decode(InputStream inStream,
Coder.Context context)
Decodes a value of type
T from the given input stream in
the given context. |
void |
encode(Void value,
OutputStream outStream,
Coder.Context context)
Encodes the given value of type
T onto the given output stream
in the given context. |
protected long |
getEncodedElementByteSize(Void value,
Coder.Context context)
Returns the size in bytes of the encoded value using this
coder.
|
boolean |
isRegisterByteSizeObserverCheap(Void value,
Coder.Context context)
Returns true since registerByteSizeObserver() runs in constant time.
|
static VoidCoder |
of() |
getCoderArguments, getInstanceComponentsverifyDeterministicasCloudObject, equals, getAllowedEncodings, getComponents, getEncodingId, hashCode, registerByteSizeObserver, structuralValue, toString, verifyDeterministic, verifyDeterministicpublic static VoidCoder of()
public void encode(Void value, OutputStream outStream, Coder.Context context)
CoderT onto the given output stream
in the given context.public Void decode(InputStream inStream, Coder.Context context)
CoderT from the given input stream in
the given context. Returns the decoded value.public boolean consistentWithEquals()
CoderObjects.equals() (note that this is well-defined for
null). In other words, encoding is injective.
This condition is most notably false for arrays. More generally, this condition is false
whenever equals() compares object identity, rather than performing a
semantic/structural comparison.
consistentWithEquals in interface Coder<Void>consistentWithEquals in class StandardCoder<Void>public boolean isRegisterByteSizeObserverCheap(Void value, Coder.Context context)
isRegisterByteSizeObserverCheap in interface Coder<Void>isRegisterByteSizeObserverCheap in class StandardCoder<Void>protected long getEncodedElementByteSize(Void value, Coder.Context context) throws Exception
StandardCodergetEncodedElementByteSize in class StandardCoder<Void>Exception