public static class BigQueryIO.Write.Bound extends PTransform<PCollection<TableRow>,PDone>
PTransform that can write either a bounded or unbounded
PCollection of TableRows to a BigQuery table.name| Constructor and Description |
|---|
Bound()
Deprecated.
Should be private. Instead, use one of the factory methods in
BigQueryIO.Write, such as BigQueryIO.Write.to(String), to create an
instance of this class. |
| Modifier and Type | Method and Description |
|---|---|
PDone |
apply(PCollection<TableRow> input)
Applies this
PTransform on the given InputT, and returns its
Output. |
BigQueryIO.Write.CreateDisposition |
getCreateDisposition()
Returns the create disposition.
|
protected Coder<Void> |
getDefaultOutputCoder()
Returns the default
Coder to use for the output of this
single-output PTransform. |
TableSchema |
getSchema()
Returns the table schema.
|
TableReference |
getTable()
Returns the table reference, or
null if a . |
boolean |
getValidate()
Returns
true if table validation is enabled. |
BigQueryIO.Write.WriteDisposition |
getWriteDisposition()
Returns the write disposition.
|
BigQueryIO.Write.Bound |
named(String name)
Returns a copy of this write transformation, but with the specified transform name.
|
BigQueryIO.Write.Bound |
to(SerializableFunction<BoundedWindow,String> tableSpecFunction)
Returns a copy of this write transformation, but using the specified function to determine
which table to write to for each window.
|
BigQueryIO.Write.Bound |
to(String tableSpec)
Returns a copy of this write transformation, but writing to the specified table.
|
BigQueryIO.Write.Bound |
to(TableReference table)
Returns a copy of this write transformation, but writing to the specified table.
|
BigQueryIO.Write.Bound |
toTableReference(SerializableFunction<BoundedWindow,TableReference> tableRefFunction)
Returns a copy of this write transformation, but using the specified function to determine
which table to write to for each window.
|
BigQueryIO.Write.Bound |
withCreateDisposition(BigQueryIO.Write.CreateDisposition createDisposition)
Returns a copy of this write transformation, but using the specified create disposition.
|
BigQueryIO.Write.Bound |
withoutValidation()
Returns a copy of this write transformation, but without BigQuery table validation.
|
BigQueryIO.Write.Bound |
withSchema(TableSchema schema)
Returns a copy of this write transformation, but using the specified schema for rows
to be written.
|
BigQueryIO.Write.Bound |
withWriteDisposition(BigQueryIO.Write.WriteDisposition writeDisposition)
Returns a copy of this write transformation, but using the specified write disposition.
|
getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, populateDisplayData, toString, validate@Deprecated public Bound()
BigQueryIO.Write, such as BigQueryIO.Write.to(String), to create an
instance of this class.public BigQueryIO.Write.Bound named(String name)
Does not modify this object.
public BigQueryIO.Write.Bound to(String tableSpec)
BigQueryIO.parseTableSpec(String) for the specification format.
Does not modify this object.
public BigQueryIO.Write.Bound to(TableReference table)
Does not modify this object.
public BigQueryIO.Write.Bound to(SerializableFunction<BoundedWindow,String> tableSpecFunction)
Does not modify this object.
tableSpecFunction should be deterministic. When given the same window, it
should always return the same table specification.
public BigQueryIO.Write.Bound toTableReference(SerializableFunction<BoundedWindow,TableReference> tableRefFunction)
Does not modify this object.
tableRefFunction should be deterministic. When given the same window, it should
always return the same table reference.
public BigQueryIO.Write.Bound withSchema(TableSchema schema)
Does not modify this object.
public BigQueryIO.Write.Bound withCreateDisposition(BigQueryIO.Write.CreateDisposition createDisposition)
Does not modify this object.
public BigQueryIO.Write.Bound withWriteDisposition(BigQueryIO.Write.WriteDisposition writeDisposition)
Does not modify this object.
public BigQueryIO.Write.Bound withoutValidation()
Does not modify this object.
public PDone apply(PCollection<TableRow> input)
PTransformPTransform on the given InputT, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<InputT, OutputT>, InputT).
apply in class PTransform<PCollection<TableRow>,PDone>protected Coder<Void> getDefaultOutputCoder()
PTransformCoder to use for the output of this
single-output PTransform.
By default, always throws
getDefaultOutputCoder in class PTransform<PCollection<TableRow>,PDone>public BigQueryIO.Write.CreateDisposition getCreateDisposition()
public BigQueryIO.Write.WriteDisposition getWriteDisposition()
public TableSchema getSchema()
public TableReference getTable()
null if a .public boolean getValidate()
true if table validation is enabled.