public static enum CompressedSource.CompressionMode extends Enum<CompressedSource.CompressionMode> implements CompressedSource.DecompressingChannelFactory
CompressedSource.| Modifier and Type | Method and Description |
|---|---|
abstract ReadableByteChannel |
createDecompressingChannel(ReadableByteChannel channel)
Given a channel, create a channel that decompresses the content read from the channel.
|
static CompressedSource.CompressionMode |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static CompressedSource.CompressionMode[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final CompressedSource.CompressionMode GZIP
public static final CompressedSource.CompressionMode BZIP2
public static CompressedSource.CompressionMode[] values()
for (CompressedSource.CompressionMode c : CompressedSource.CompressionMode.values()) System.out.println(c);
public static CompressedSource.CompressionMode valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic abstract ReadableByteChannel createDecompressingChannel(ReadableByteChannel channel) throws IOException
CompressedSource.DecompressingChannelFactorycreateDecompressingChannel in interface CompressedSource.DecompressingChannelFactoryIOException