public static class ReadSource.Bound<T> extends PTransform<PInput,PCollection<T>>
ReadSource PTransform builder.name| Modifier and Type | Method and Description |
|---|---|
PCollection<T> |
apply(PInput input)
Applies this
PTransform on the given Input, and returns its
Output. |
<T> ReadSource.Bound<T> |
from(Source<T> source)
Returns a new
ReadSource PTransform that's like this one but
reads from the given Source. |
protected Coder<T> |
getDefaultOutputCoder()
Returns the default
Coder to use for the output of this
single-output PTransform, or null if
none can be inferred. |
Source<T> |
getSource()
Returns the
Source used to create this ReadSource PTransform. |
ReadSource.Bound<T> |
named(java.lang.String name)
Returns a new
ReadSource PTransform that's like this one but
has the given name. |
finishSpecifying, getCoderRegistry, getDefaultName, getDefaultOutputCoder, getInput, getKindString, getName, getOutput, getPipeline, setName, setPipeline, toString, withNamepublic <T> ReadSource.Bound<T> from(Source<T> source)
ReadSource PTransform that's like this one but
reads from the given Source.
Does not modify this object.
public ReadSource.Bound<T> named(java.lang.String name)
ReadSource PTransform that's like this one but
has the given name.
Does not modify this object.
protected Coder<T> getDefaultOutputCoder()
PTransformCoder to use for the output of this
single-output PTransform, or null if
none can be inferred.
By default, returns null.
getDefaultOutputCoder in class PTransform<PInput,PCollection<T>>public final PCollection<T> apply(PInput input)
PTransformPTransform on the given Input, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<Input, Output>, Input).
apply in class PTransform<PInput,PCollection<T>>