T - public abstract static class Source.AbstractReader<T> extends Object implements Source.Reader<T>
Source.Reader in a default way:
BoundedWindow.TIMESTAMP_MIN_VALUE.
| Constructor and Description |
|---|
AbstractReader() |
| Modifier and Type | Method and Description |
|---|---|
org.joda.time.Instant |
getCurrentTimestamp()
Returns the timestamp associated with the current data item.
|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitadvance, close, getCurrent, getCurrentSource, startpublic org.joda.time.Instant getCurrentTimestamp()
throws NoSuchElementException
Source.Reader
If the source does not support timestamps, this should return
BoundedWindow.TIMESTAMP_MIN_VALUE.
Multiple calls to this method without an intervening call to Source.Reader.advance() should
return the same result.
getCurrentTimestamp in interface Source.Reader<T>NoSuchElementException - if the reader is at the beginning of the input and
Source.Reader.start() or Source.Reader.advance() wasn't called, or if the last Source.Reader.start() or
Source.Reader.advance() returned false.