public static interface UnboundedSource.CheckpointMark
UnboundedSource.UnboundedReader.
For example, this could be offsets in a set of files being read.
| Modifier and Type | Method and Description |
|---|---|
void |
finalizeCheckpoint()
Perform any finalization that needs to happen after a bundle of data read from
the source has been processed and committed.
|
void finalizeCheckpoint()
throws IOException
For example, this could be sending acknowledgement requests to an external data source such as Pub/Sub.
This may be called from any thread, potentially at the same time as calls to the
UnboundedReader that created it.
IOException