public interface DataflowPipelineDebugOptions extends PipelineOptions
| Modifier and Type | Interface and Description |
|---|---|
static class |
DataflowPipelineDebugOptions.DataflowClientFactory
Returns the default Dataflow client built from the passed in PipelineOptions.
|
static class |
DataflowPipelineDebugOptions.PathValidatorFactory
Creates a
PathValidator object using the class specified in
getPathValidatorClass(). |
static class |
DataflowPipelineDebugOptions.StagerFactory
Creates a
Stager object using the class specified in
getStagerClass(). |
PipelineOptions.CheckEnabled| Modifier and Type | Method and Description |
|---|---|
String |
getApiRootUrl()
The root URL for the Dataflow API.
|
com.google.api.services.dataflow.Dataflow |
getDataflowClient()
An instance of the Dataflow client.
|
String |
getDataflowEndpoint()
Dataflow endpoint to use.
|
String |
getDataflowJobFile()
The path to write the translated Dataflow job specification out to
at job submission time.
|
List<String> |
getExperiments()
The list of backend experiments to enable.
|
String |
getOverrideWindmillBinary()
Custom windmill_main binary to use with the streaming runner.
|
PathValidator |
getPathValidator()
The path validator instance that should be created and used to validate paths.
|
Class<? extends PathValidator> |
getPathValidatorClass()
The class of the validator that should be created and used to validate paths.
|
String |
getPubsubRootUrl()
Root URL for use with the Pubsub API.
|
Stager |
getStager()
The resource stager instance that should be created and used to stage resources.
|
Class<? extends Stager> |
getStagerClass()
The class responsible for staging resources to be accessible by workers
during job execution.
|
Map<String,String> |
getTransformNameMapping()
Mapping of old PTranform names to new ones, specified as a semicolon-separated list of
oldName=newName pairs.
|
boolean |
getUpdate()
Whether to update the currently running pipeline with the same name as this one.
|
void |
setApiRootUrl(String value) |
void |
setDataflowClient(com.google.api.services.dataflow.Dataflow value) |
void |
setDataflowEndpoint(String value) |
void |
setDataflowJobFile(String value) |
void |
setExperiments(List<String> value) |
void |
setOverrideWindmillBinary(String value) |
void |
setPathValidator(PathValidator validator) |
void |
setPathValidatorClass(Class<? extends PathValidator> validatorClass) |
void |
setPubsubRootUrl(String value) |
void |
setStager(Stager stager) |
void |
setStagerClass(Class<? extends Stager> stagerClass) |
void |
setTransformNameMapping(Map<String,String> value) |
void |
setUpdate(boolean value) |
as, cloneAs, getRunner, getStableUniqueNames, setRunner, setStableUniqueNames@Experimental List<String> getExperiments()
Dataflow provides a number of experimental features that can be enabled with this flag.
Please sync with the Dataflow team before enabling any experiments.
String getApiRootUrl()
dataflowEndpoint can override this value
if it contains an absolute URL, otherwise apiRootUrl will be combined with
dataflowEndpoint to generate the full URL to communicate with the Dataflow API.void setApiRootUrl(String value)
String getDataflowEndpoint()
Defaults to the current version of the Google Cloud Dataflow API, at the time the current SDK version was released.
If the string contains "://", then this is treated as a url,
otherwise getApiRootUrl() is used as the root
url.
void setDataflowEndpoint(String value)
String getDataflowJobFile()
void setDataflowJobFile(String value)
Class<? extends PathValidator> getPathValidatorClass()
void setPathValidatorClass(Class<? extends PathValidator> validatorClass)
PathValidator getPathValidator()
void setPathValidator(PathValidator validator)
Class<? extends Stager> getStagerClass()
Stager getStager()
void setStager(Stager stager)
com.google.api.services.dataflow.Dataflow getDataflowClient()
void setDataflowClient(com.google.api.services.dataflow.Dataflow value)
String getPubsubRootUrl()
void setPubsubRootUrl(String value)
boolean getUpdate()
void setUpdate(boolean value)
Map<String,String> getTransformNameMapping()
String getOverrideWindmillBinary()
void setOverrideWindmillBinary(String value)