public interface DataflowPipelineOptions extends PipelineOptions, GcpOptions, ApplicationNameOptions, DataflowPipelineDebugOptions, DataflowPipelineWorkerPoolOptions, BigQueryOptions, GcsOptions, StreamingOptions, CloudDebuggerOptions, DataflowWorkerLoggingOptions, DataflowProfilingOptions
DataflowPipeline.| Modifier and Type | Interface and Description |
|---|---|
static class |
DataflowPipelineOptions.JobNameFactory
Returns a normalized job name constructed from
ApplicationNameOptions.getAppName(), the
local system user name (if available), and the current time. |
DataflowPipelineDebugOptions.DataflowClientFactory, DataflowPipelineDebugOptions.PathValidatorFactory, DataflowPipelineDebugOptions.StagerFactoryDataflowPipelineWorkerPoolOptions.AutoscalingAlgorithmType, DataflowPipelineWorkerPoolOptions.TeardownPolicy, DataflowPipelineWorkerPoolOptions.WorkerHarnessContainerImageFactoryGcpOptions.CredentialDirFactory, GcpOptions.DefaultProjectFactory, GcpOptions.GcpUserCredentialsFactoryGoogleApiDebugOptions.GoogleApiTracerPipelineOptions.CheckEnabledGcsOptions.ExecutorServiceFactoryDataflowWorkerLoggingOptions.Level, DataflowWorkerLoggingOptions.WorkerLogLevelOverridesDataflowProfilingOptions.DataflowProfilingAgentConfiguration| Modifier and Type | Method and Description |
|---|---|
String |
getJobName()
The Dataflow job name is used as an idempotence key within the Dataflow service.
|
String |
getProject()
Project id to use when launching jobs.
|
String |
getStagingLocation()
GCS path for staging local files, e.g.
|
boolean |
getUpdate()
Whether to update the currently running pipeline with the same name as this one.
|
void |
setJobName(String value) |
void |
setProject(String value) |
void |
setStagingLocation(String value) |
void |
setUpdate(boolean value) |
getApiRootUrl, getDataflowClient, getDataflowEndpoint, getDataflowJobFile, getDumpHeapOnOOM, getExperiments, getNumberOfWorkerHarnessThreads, getOverrideWindmillBinary, getPathValidator, getPathValidatorClass, getPubsubRootUrl, getStager, getStagerClass, getTransformNameMapping, getWindmillServiceEndpoint, getWindmillServicePort, setApiRootUrl, setDataflowClient, setDataflowEndpoint, setDataflowJobFile, setDumpHeapOnOOM, setExperiments, setNumberOfWorkerHarnessThreads, setOverrideWindmillBinary, setPathValidator, setPathValidatorClass, setPubsubRootUrl, setStager, setStagerClass, setTransformNameMapping, setWindmillServiceEndpoint, setWindmillServicePortgetAutoscalingAlgorithm, getDiskSizeGb, getFilesToStage, getMaxNumWorkers, getNetwork, getNumWorkers, getSubnetwork, getTeardownPolicy, getUsePublicIps, getWorkerDiskType, getWorkerHarnessContainerImage, getWorkerMachineType, getZone, setAutoscalingAlgorithm, setDiskSizeGb, setFilesToStage, setMaxNumWorkers, setNetwork, setNumWorkers, setSubnetwork, setTeardownPolicy, setUsePublicIps, setWorkerDiskType, setWorkerHarnessContainerImage, setWorkerMachineType, setZonegetTempDatasetId, setTempDatasetIdisStreaming, setStreaminggetAppName, setAppNamegetAuthorizationServerEncodedUrl, getCredentialDir, getCredentialFactoryClass, getCredentialId, getGcpCredential, getSecretsFile, getServiceAccountKeyfile, getServiceAccountName, getTokenServerUrl, setAuthorizationServerEncodedUrl, setCredentialDir, setCredentialFactoryClass, setCredentialId, setGcpCredential, setSecretsFile, setServiceAccountKeyfile, setServiceAccountName, setTokenServerUrlgetGoogleApiTrace, setGoogleApiTraceas, cloneAs, getRunner, getStableUniqueNames, getTempLocation, setRunner, setStableUniqueNames, setTempLocationpopulateDisplayDatagetExecutorService, getGcsEndpoint, getGcsUploadBufferSizeBytes, getGcsUtil, setExecutorService, setGcsEndpoint, setGcsUploadBufferSizeBytes, setGcsUtilgetDebuggee, getEnableCloudDebugger, getMaxConditionCost, setDebuggee, setEnableCloudDebugger, setMaxConditionCostgetDefaultWorkerLogLevel, getWorkerLogLevelOverrides, setDefaultWorkerLogLevel, setWorkerLogLevelOverridesgetEnableProfilingAgent, getProfilingAgentConfiguration, setEnableProfilingAgent, setProfilingAgentConfiguration@Validation.Required @Default.InstanceFactory(value=GcpOptions.DefaultProjectFactory.class) String getProject()
GcpOptionsgetProject in interface GcpOptionsvoid setProject(String value)
setProject in interface GcpOptionsString getStagingLocation()
Must be a valid Cloud Storage URL, beginning with the prefix "gs://"
At least one of PipelineOptions.getTempLocation() or getStagingLocation() must be set. If
PipelineOptions.getTempLocation() is not set, then the Dataflow pipeline defaults to using
getStagingLocation().
void setStagingLocation(String value)
@Default.InstanceFactory(value=DataflowPipelineOptions.JobNameFactory.class) String getJobName()
void setJobName(String value)
boolean getUpdate()
getUpdate in interface DataflowPipelineDebugOptionsvoid setUpdate(boolean value)
setUpdate in interface DataflowPipelineDebugOptions