public static class DataflowPipelineOptions.JobNameFactory extends Object implements DefaultValueFactory<String>
ApplicationNameOptions.getAppName(), the
local system user name (if available), and the current time. The normalization makes sure that
the job name matches the required pattern of [a-z]([-a-z0-9]*[a-z0-9])? and length limit of 40
characters.
This job name factory is only able to generate one unique name per second per application and user combination.
| Constructor and Description |
|---|
JobNameFactory() |
| Modifier and Type | Method and Description |
|---|---|
String |
create(PipelineOptions options)
Creates a default value for a getter marked with
Default.InstanceFactory. |
public String create(PipelineOptions options)
DefaultValueFactoryDefault.InstanceFactory.create in interface DefaultValueFactory<String>options - The current pipeline options.