public interface DataflowPipelineWorkerPoolOptions extends PipelineOptions
| Modifier and Type | Interface and Description |
|---|---|
static class |
DataflowPipelineWorkerPoolOptions.AutoscalingAlgorithmType
Type of autoscaling algorithm to use.
|
static class |
DataflowPipelineWorkerPoolOptions.TeardownPolicy
The policy for tearing down the workers spun up by the service.
|
PipelineOptions.CheckEnabled| Modifier and Type | Method and Description |
|---|---|
DataflowPipelineWorkerPoolOptions.AutoscalingAlgorithmType |
getAutoscalingAlgorithm() |
int |
getDiskSizeGb()
Remote worker disk size, in gigabytes, or 0 to use the default size.
|
String |
getDiskSourceImage()
Disk source image to use by VMs for jobs.
|
List<String> |
getFilesToStage()
List of local files to make available to workers.
|
int |
getMaxNumWorkers()
The maximum number of workers to use when using workerpool autoscaling.
|
String |
getNetwork()
GCE network for launching
workers.
|
int |
getNumWorkers()
Number of workers to use when executing the Dataflow job.
|
DataflowPipelineWorkerPoolOptions.TeardownPolicy |
getTeardownPolicy()
The teardown policy for the VMs.
|
String |
getWorkerDiskType()
Specifies what type of persistent disk should be used.
|
String |
getWorkerMachineType()
Machine type to create Dataflow worker VMs as.
|
String |
getZone()
GCE availability zone for launching workers.
|
void |
setAutoscalingAlgorithm(DataflowPipelineWorkerPoolOptions.AutoscalingAlgorithmType value) |
void |
setDiskSizeGb(int value) |
void |
setDiskSourceImage(String value) |
void |
setFilesToStage(List<String> value) |
void |
setMaxNumWorkers(int value) |
void |
setNetwork(String value) |
void |
setNumWorkers(int value) |
void |
setTeardownPolicy(DataflowPipelineWorkerPoolOptions.TeardownPolicy value) |
void |
setWorkerDiskType(String value) |
void |
setWorkerMachineType(String value) |
void |
setZone(String value) |
as, cloneAs, getRunner, getStableUniqueNames, setRunner, setStableUniqueNamesString getDiskSourceImage()
void setDiskSourceImage(String value)
int getNumWorkers()
void setNumWorkers(int value)
@Experimental(value=AUTOSCALING) DataflowPipelineWorkerPoolOptions.AutoscalingAlgorithmType getAutoscalingAlgorithm()
void setAutoscalingAlgorithm(DataflowPipelineWorkerPoolOptions.AutoscalingAlgorithmType value)
@Experimental(value=AUTOSCALING) int getMaxNumWorkers()
void setMaxNumWorkers(int value)
int getDiskSizeGb()
void setDiskSizeGb(int value)
String getNetwork()
Default is up to the Dataflow service.
void setNetwork(String value)
String getZone()
Default is up to the Dataflow service.
void setZone(String value)
String getWorkerMachineType()
See GCE machine types for a list of valid options.
If unset, the Dataflow service will choose a reasonable default.
void setWorkerMachineType(String value)
DataflowPipelineWorkerPoolOptions.TeardownPolicy getTeardownPolicy()
By default this is left unset and the service sets the default policy.
void setTeardownPolicy(DataflowPipelineWorkerPoolOptions.TeardownPolicy value)
List<String> getFilesToStage()
Files are placed on the worker's classpath.
The default value is the list of jars from the main program's classpath.
String getWorkerDiskType()
void setWorkerDiskType(String value)