public static enum DataflowWorkerLoggingOptions.Level extends Enum<DataflowWorkerLoggingOptions.Level>
| Modifier and Type | Method and Description |
|---|---|
static DataflowWorkerLoggingOptions.Level |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static DataflowWorkerLoggingOptions.Level[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final DataflowWorkerLoggingOptions.Level DEBUG
public static final DataflowWorkerLoggingOptions.Level ERROR
public static final DataflowWorkerLoggingOptions.Level INFO
public static final DataflowWorkerLoggingOptions.Level TRACE
public static final DataflowWorkerLoggingOptions.Level WARN
public static DataflowWorkerLoggingOptions.Level[] values()
for (DataflowWorkerLoggingOptions.Level c : DataflowWorkerLoggingOptions.Level.values()) System.out.println(c);
public static DataflowWorkerLoggingOptions.Level valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is null