T - The type of object this factory produces.public interface DefaultValueFactory<T>
Default.InstanceFactory annotation to specify the class that will
be an instance factory to produce default values for a given getter on PipelineOptions.
When a property on a PipelineOptions is fetched, and is currently unset, the default
value factory will be instantiated and invoked.
Care must be taken to not produce an infinite loop when accessing other fields on the
PipelineOptions object.
| Modifier and Type | Method and Description |
|---|---|
T |
create(PipelineOptions options)
Creates a default value for a getter marked with
Default.InstanceFactory. |
T create(PipelineOptions options)
Default.InstanceFactory.options - The current pipeline options.