public interface DirectPipelineOptions extends ApplicationNameOptions, BigQueryOptions, GcsOptions, GcpOptions, PipelineOptions, StreamingOptions
DirectPipeline.GcpOptions.CredentialDirFactory, GcpOptions.DefaultProjectFactory, GcpOptions.GcpUserCredentialsFactoryGoogleApiDebugOptions.GoogleApiTracerPipelineOptions.CheckEnabledGcsOptions.ExecutorServiceFactory| Modifier and Type | Method and Description |
|---|---|
Long |
getDirectPipelineRunnerRandomSeed()
The random seed to use for pseudorandom behaviors in the
DirectPipelineRunner. |
boolean |
isTestEncodability()
Controls whether the runner should ensure that all of the elements of
every
PCollection can be encoded using the appropriate
Coder. |
boolean |
isTestSerializability()
Controls whether the runner should ensure that all of the elements of
the pipeline, such as DoFns, can be serialized.
|
boolean |
isTestUnorderedness()
Controls whether the runner should randomize the order of each
PCollection. |
void |
setDirectPipelineRunnerRandomSeed(Long value) |
void |
setTestEncodability(boolean testEncodability) |
void |
setTestSerializability(boolean testSerializability) |
void |
setTestUnorderedness(boolean testUnorderedness) |
getTempDatasetId, setTempDatasetIdisStreaming, setStreaminggetAppName, setAppNamegetCredentialDir, getCredentialFactoryClass, getCredentialId, getGcpCredential, getProject, getSecretsFile, getServiceAccountKeyfile, getServiceAccountName, setCredentialDir, setCredentialFactoryClass, setCredentialId, setGcpCredential, setProject, setSecretsFile, setServiceAccountKeyfile, setServiceAccountNamegetGoogleApiTrace, setGoogleApiTraceas, cloneAs, getRunner, getStableUniqueNames, setRunner, setStableUniqueNamesgetExecutorService, getGcsEndpoint, getGcsUploadBufferSizeBytes, getGcsUtil, setExecutorService, setGcsEndpoint, setGcsUploadBufferSizeBytes, setGcsUtilLong getDirectPipelineRunnerRandomSeed()
DirectPipelineRunner.
If not explicitly specified, a random seed will be generated.void setDirectPipelineRunnerRandomSeed(Long value)
@Default.Boolean(value=true) boolean isTestSerializability()
void setTestSerializability(boolean testSerializability)
@Default.Boolean(value=true) boolean isTestEncodability()
PCollection can be encoded using the appropriate
Coder.void setTestEncodability(boolean testEncodability)
@Default.Boolean(value=true) boolean isTestUnorderedness()
PCollection.void setTestUnorderedness(boolean testUnorderedness)