public interface GcpOptions extends GoogleApiDebugOptions, PipelineOptions
These options configure which of the following 4 different mechanisms for obtaining a credential are used:
| Modifier and Type | Interface and Description |
|---|---|
static class |
GcpOptions.CredentialDirFactory
Returns the default credential directory of ${user.home}/.store/data-flow.
|
static class |
GcpOptions.DefaultProjectFactory
Attempts to get infer the default project based upon the environment this application
is executing within.
|
static class |
GcpOptions.GcpUserCredentialsFactory
Attempts to load the GCP credentials.
|
GoogleApiDebugOptions.GoogleApiTracerPipelineOptions.CheckEnabled| Modifier and Type | Method and Description |
|---|---|
String |
getCredentialDir()
Directory for storing dataflow credentials after execution of the OAuth 2 webflow.
|
Class<? extends com.google.cloud.dataflow.sdk.util.CredentialFactory> |
getCredentialFactoryClass()
The class of the credential factory that should be created and used to create
credentials.
|
String |
getCredentialId()
This option controls which credential store to use when creating the credentials
using the OAuth 2 webflow.
|
com.google.api.client.auth.oauth2.Credential |
getGcpCredential()
The credential instance that should be used to authenticate against GCP services.
|
String |
getProject()
Project id to use when launching jobs.
|
String |
getSecretsFile()
This option controls which file to use when attempting to create the credentials
using the OAuth 2 webflow.
|
String |
getServiceAccountKeyfile()
This option controls which file to use when attempting to create the credentials using the
service account method.
|
String |
getServiceAccountName()
This option controls which service account to use when attempting to create the credentials
using the service account method.
|
void |
setCredentialDir(String value) |
void |
setCredentialFactoryClass(Class<? extends com.google.cloud.dataflow.sdk.util.CredentialFactory> credentialFactoryClass) |
void |
setCredentialId(String value) |
void |
setGcpCredential(com.google.api.client.auth.oauth2.Credential value) |
void |
setProject(String value) |
void |
setSecretsFile(String value) |
void |
setServiceAccountKeyfile(String value) |
void |
setServiceAccountName(String value) |
getGoogleApiTrace, setGoogleApiTraceas, cloneAs, getRunner, getStableUniqueNames, setRunner, setStableUniqueNamesString getProject()
void setProject(String value)
String getServiceAccountKeyfile()
This option if specified, needs be combined with the
serviceAccountName.
void setServiceAccountKeyfile(String value)
String getServiceAccountName()
This option if specified, needs be combined with the
serviceAccountKeyfile.
void setServiceAccountName(String value)
String getSecretsFile()
void setSecretsFile(String value)
String getCredentialId()
void setCredentialId(String value)
String getCredentialDir()
void setCredentialDir(String value)
Class<? extends com.google.cloud.dataflow.sdk.util.CredentialFactory> getCredentialFactoryClass()
void setCredentialFactoryClass(Class<? extends com.google.cloud.dataflow.sdk.util.CredentialFactory> credentialFactoryClass)
com.google.api.client.auth.oauth2.Credential getGcpCredential()
void setGcpCredential(com.google.api.client.auth.oauth2.Credential value)