public interface GcsOptions extends ApplicationNameOptions, GcpOptions, PipelineOptions
| Modifier and Type | Interface and Description |
|---|---|
static class |
GcsOptions.ExecutorServiceFactory
Returns the default
ExecutorService to use within the Dataflow SDK. |
GcpOptions.CredentialDirFactory, GcpOptions.DefaultProjectFactory, GcpOptions.GcpUserCredentialsFactoryGoogleApiDebugOptions.GoogleApiTracerPipelineOptions.CheckEnabled| Modifier and Type | Method and Description |
|---|---|
ExecutorService |
getExecutorService()
The ExecutorService instance to use to create threads, can be overridden to specify an
ExecutorService that is compatible with the users environment.
|
String |
getGcsEndpoint()
GCS endpoint to use.
|
com.google.cloud.dataflow.sdk.util.GcsUtil |
getGcsUtil()
The GcsUtil instance that should be used to communicate with Google Cloud Storage.
|
void |
setExecutorService(ExecutorService value) |
void |
setGcsEndpoint(String value) |
void |
setGcsUtil(com.google.cloud.dataflow.sdk.util.GcsUtil value) |
getAppName, setAppNamegetCredentialDir, getCredentialFactoryClass, getCredentialId, getGcpCredential, getProject, getSecretsFile, getServiceAccountKeyfile, getServiceAccountName, setCredentialDir, setCredentialFactoryClass, setCredentialId, setGcpCredential, setProject, setSecretsFile, setServiceAccountKeyfile, setServiceAccountNamegetGoogleApiTrace, setGoogleApiTraceas, cloneAs, getRunner, getStableUniqueNames, setRunner, setStableUniqueNamescom.google.cloud.dataflow.sdk.util.GcsUtil getGcsUtil()
void setGcsUtil(com.google.cloud.dataflow.sdk.util.GcsUtil value)
ExecutorService getExecutorService()
void setExecutorService(ExecutorService value)
String getGcsEndpoint()
void setGcsEndpoint(String value)