public interface GoogleApiDebugOptions extends PipelineOptions
| Modifier and Type | Interface and Description |
|---|---|
static class |
GoogleApiDebugOptions.GoogleApiTracer
A
GoogleClientRequestInitializer that adds the trace destination to Google API calls. |
PipelineOptions.CheckEnabled| Modifier and Type | Method and Description |
|---|---|
GoogleApiDebugOptions.GoogleApiTracer |
getGoogleApiTrace()
This option enables tracing of API calls to Google services used within the Dataflow SDK.
|
void |
setGoogleApiTrace(GoogleApiDebugOptions.GoogleApiTracer commands) |
as, cloneAs, getRunner, getStableUniqueNames, setRunner, setStableUniqueNamesGoogleApiDebugOptions.GoogleApiTracer getGoogleApiTrace()
void setGoogleApiTrace(GoogleApiDebugOptions.GoogleApiTracer commands)