public interface StreamingOptions extends ApplicationNameOptions, GcpOptions, PipelineOptions
Important: Streaming support is experimental. It is only supported in the
DataflowPipelineRunner for users whitelisted in a
streaming early access program.
You should expect this class to change significantly in future versions of the SDK or be removed entirely.
GcpOptions.CredentialDirFactory, GcpOptions.GcpUserCredentialsFactoryGoogleApiDebugOptions.GoogleApiTracer| Modifier and Type | Method and Description |
|---|---|
boolean |
isStreaming()
Note that this feature is currently experimental and only available to users whitelisted in
a streaming early access program.
|
void |
setStreaming(boolean value) |
getAppName, setAppNamegetCredentialDir, getCredentialFactoryClass, getCredentialId, getGcpCredential, getProject, getSecretsFile, getServiceAccountKeyfile, getServiceAccountName, setCredentialDir, setCredentialFactoryClass, setCredentialId, setGcpCredential, setProject, setSecretsFile, setServiceAccountKeyfile, setServiceAccountNamegetGoogleApiTrace, setGoogleApiTraceas, getRunner, setRunner