public interface ValueProvider<T> extends Serializable
ValueProvider is an interface which abstracts the notion of
fetching a value that may or may not be currently available. This can be
used to parameterize transforms that only read values in at runtime, for
example.| Modifier and Type | Interface and Description |
|---|---|
static class |
ValueProvider.Deserializer
Deserializer for
ValueProvider, which handles type marshalling. |
static class |
ValueProvider.NestedValueProvider<T,X>
ValueProvider.NestedValueProvider is an implementation of ValueProvider that
allows for wrapping another ValueProvider object. |
static class |
ValueProvider.RuntimeValueProvider<T>
ValueProvider.RuntimeValueProvider is an implementation of ValueProvider that
allows for a value to be provided at execution time rather than at graph
construction time. |
static class |
ValueProvider.Serializer
Serializer for
ValueProvider. |
static class |
ValueProvider.StaticValueProvider<T>
ValueProvider.StaticValueProvider is an implementation of ValueProvider that
allows for a static value to be provided. |
| Modifier and Type | Method and Description |
|---|---|
T |
get()
Return the value wrapped by this
ValueProvider. |
boolean |
isAccessible()
Whether the contents of this
ValueProvider is available to
routines that run at graph construction time. |
T get()
ValueProvider.boolean isAccessible()
ValueProvider is available to
routines that run at graph construction time.