PipelineOptions for
configuring pipeline execution.See: Description
| Interface | Description |
|---|---|
| ApplicationNameOptions |
Options that allow setting the application name.
|
| BigQueryOptions |
Properties needed when using BigQuery with the Dataflow SDK.
|
| BlockingDataflowPipelineOptions |
Options that are used to configure the
BlockingDataflowPipelineRunner. |
| CloudDebuggerOptions |
Options for controlling Cloud Debugger.
|
| DataflowPipelineDebugOptions |
Internal.
|
| DataflowPipelineOptions |
Options that can be used to configure the
DataflowPipeline. |
| DataflowPipelineWorkerPoolOptions |
Options that are used to configure the Dataflow pipeline worker pool.
|
| DataflowWorkerHarnessOptions |
Options that are used exclusively within the Dataflow worker harness.
|
| DataflowWorkerLoggingOptions |
Options that are used to control logging configuration on the Dataflow worker.
|
| DefaultValueFactory<T> |
An interface used with
Default.InstanceFactory annotation to specify the class that will
be an instance factory to produce default values for a given getter on PipelineOptions. |
| DirectPipelineOptions |
Options that can be used to configure the
DirectPipeline. |
| GcpOptions |
Options used to configure Google Cloud Platform project and credentials.
|
| GcsOptions |
Options used to configure Google Cloud Storage.
|
| GoogleApiDebugOptions |
These options configure debug settings for Google API clients created within the Dataflow SDK.
|
| PipelineOptions |
PipelineOptions are used to configure Pipelines.
|
| PipelineOptionsRegistrar |
PipelineOptions creators have the ability to automatically have their
PipelineOptions registered with this SDK by creating a ServiceLoader entry
and a concrete implementation of this interface. |
| StreamingOptions |
Options used to configure streaming.
|
| Class | Description |
|---|---|
| BlockingDataflowPipelineOptions.StandardOutputFactory |
Returns a default of
System.out. |
| DataflowPipelineDebugOptions.DataflowClientFactory |
Returns the default Dataflow client built from the passed in PipelineOptions.
|
| DataflowPipelineDebugOptions.PathValidatorFactory |
Creates a
PathValidator object using the class specified in
DataflowPipelineDebugOptions.getPathValidatorClass(). |
| DataflowPipelineDebugOptions.StagerFactory |
Creates a
Stager object using the class specified in
DataflowPipelineDebugOptions.getStagerClass(). |
| DataflowPipelineOptions.JobNameFactory |
Returns a normalized job name constructed from
ApplicationNameOptions.getAppName(), the
local system user name (if available), and the current time. |
| DataflowWorkerLoggingOptions.WorkerLogLevelOverrides |
Defines a log level override for a specific class, package, or name.
|
| GcpOptions.CredentialDirFactory |
Returns the default credential directory of ${user.home}/.store/data-flow.
|
| GcpOptions.DefaultProjectFactory |
Attempts to get infer the default project based upon the environment this application
is executing within.
|
| GcpOptions.GcpUserCredentialsFactory |
Attempts to load the GCP credentials.
|
| GcsOptions.ExecutorServiceFactory |
Returns the default
ExecutorService to use within the Dataflow SDK. |
| GoogleApiDebugOptions.GoogleApiTracer |
A
GoogleClientRequestInitializer that adds the trace destination to Google API calls. |
| PipelineOptionsFactory |
Constructs a
PipelineOptions or any derived interface that is composable to any other
derived interface of PipelineOptions via the PipelineOptions.as(java.lang.Class<T>) method. |
| PipelineOptionsFactory.Builder |
A fluent
PipelineOptions builder. |
| PipelineOptionsValidator |
Validates that the
PipelineOptions conforms to all the Validation criteria. |
| Enum | Description |
|---|---|
| DataflowPipelineWorkerPoolOptions.AutoscalingAlgorithmType |
Type of autoscaling algorithm to use.
|
| DataflowPipelineWorkerPoolOptions.TeardownPolicy |
The policy for tearing down the workers spun up by the service.
|
| DataflowWorkerLoggingOptions.Level |
The set of log levels that can be used on the Dataflow worker.
|
| PipelineOptions.CheckEnabled |
Enumeration of the possible states for a given check.
|
| Annotation Type | Description |
|---|---|
| Default |
Default represents a set of annotations that can be used to annotate getter properties
on PipelineOptions with information representing the default value to be returned
if no value is specified. |
| Default.Boolean |
This represents that the default of the option is the specified boolean primitive value.
|
| Default.Byte |
This represents that the default of the option is the specified byte primitive value.
|
| Default.Character |
This represents that the default of the option is the specified char primitive value.
|
| Default.Class |
This represents that the default of the option is the specified
Class value. |
| Default.Double |
This represents that the default of the option is the specified double primitive value.
|
| Default.Enum |
This represents that the default of the option is the specified enum.
|
| Default.Float |
This represents that the default of the option is the specified float primitive value.
|
| Default.InstanceFactory |
Value must be of type
DefaultValueFactory and have a default constructor. |
| Default.Integer |
This represents that the default of the option is the specified int primitive value.
|
| Default.Long |
This represents that the default of the option is the specified long primitive value.
|
| Default.Short |
This represents that the default of the option is the specified short primitive value.
|
| Default.String |
This represents that the default of the option is the specified
String
value. |
| Description |
Descriptions are used to generate human readable output when the --help
command is specified.
|
| Hidden |
Methods and/or interfaces annotated with
@Hidden will be suppressed from
being output when --help is specified on the command-line. |
| Validation |
Validation represents a set of annotations that can be used to annotate getter
properties on PipelineOptions with information representing the validation criteria to
be used when validating with the PipelineOptionsValidator. |
| Validation.Required |
This criteria specifies that the value must be not null.
|
PipelineOptions for
configuring pipeline execution.
PipelineOptions encapsulates the various
parameters that describe how a pipeline should be run. PipelineOptions are created
using a PipelineOptionsFactory.