ElemT - the type of elements the input PCollection contains.ViewT - the type of the PCollectionView this writer writes to.public static interface InProcessPipelineRunner.PCollectionViewWriter<ElemT,ViewT>
InProcessPipelineRunner.PCollectionViewWriter is responsible for writing contents of a PCollection to
a storage mechanism that can be read from while constructing a PCollectionView.| Modifier and Type | Method and Description |
|---|---|
void |
add(Iterable<com.google.cloud.dataflow.sdk.util.WindowedValue<ElemT>> values) |