public class DataflowSideInputReader extends SizedSideInputReader.Defaults implements SizedSideInputReader
Sizes are accurate only for PCollectionView implementations that read the same
amount of data for each access.
SizedSideInputReader.Defaults| Modifier and Type | Method and Description |
|---|---|
<T> boolean |
contains(PCollectionView<T> view)
Returns true if the given
PCollectionView is valid for this reader. |
<T> Sized<T> |
getSized(PCollectionView<T> view,
BoundedWindow window)
Gets a side input for a view and window by reading data according to the corresponding
SideInputInfo, passing the result through the view's
PCollectionView.fromIterableInternal(java.lang.Iterable<com.google.cloud.dataflow.sdk.util.WindowedValue<?>>) conversion method, and extracting
the value for the appropriate window. |
boolean |
isEmpty()
Returns true if there are no side inputs in this reader.
|
static DataflowSideInputReader |
of(Iterable<? extends com.google.api.services.dataflow.model.SideInputInfo> sideInputInfos,
PipelineOptions options,
ExecutionContext context)
Creates a new
SideInputReader that will provide side inputs
according to the provided SideInputInfo descriptors. |
getclone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitgetpublic static DataflowSideInputReader of(Iterable<? extends com.google.api.services.dataflow.model.SideInputInfo> sideInputInfos, PipelineOptions options, ExecutionContext context) throws Exception
SideInputReader that will provide side inputs
according to the provided SideInputInfo descriptors.Exceptionpublic <T> boolean contains(PCollectionView<T> view)
SideInputReaderPCollectionView is valid for this reader.contains in interface SideInputReaderpublic boolean isEmpty()
SideInputReaderisEmpty in interface SideInputReaderpublic <T> Sized<T> getSized(PCollectionView<T> view, BoundedWindow window)
SideInputInfo, passing the result through the view's
PCollectionView.fromIterableInternal(java.lang.Iterable<com.google.cloud.dataflow.sdk.util.WindowedValue<?>>) conversion method, and extracting
the value for the appropriate window.getSized in interface SizedSideInputReader