public static interface DataflowAssert.SingletonAssert<T>
| Modifier and Type | Method and Description |
|---|---|
Coder<T> |
getCoder()
Deprecated.
instead call
PCollection.getCoder() on the actual PCollection
directly |
DataflowAssert.SingletonAssert<T> |
inFinalPane(BoundedWindow window)
Creates a new
DataflowAssert.SingletonAssert like this one, but with the assertion restricted to
only run on the provided window, running the checker only on the final pane for each key. |
DataflowAssert.SingletonAssert<T> |
inOnlyPane(BoundedWindow window)
Creates a new
DataflowAssert.SingletonAssert like this one, but with the assertion restricted to
only run on the provided window. |
DataflowAssert.SingletonAssert<T> |
inOnTimePane(BoundedWindow window)
Creates a new
DataflowAssert.SingletonAssert like this one, but with the assertion restricted to
only run on the provided window, running the checker only on the on-time pane for each key. |
DataflowAssert.SingletonAssert<T> |
is(T expected)
Deprecated.
instead use
isEqualTo(Object) |
DataflowAssert.SingletonAssert<T> |
isEqualTo(T expected)
Asserts that the value in question is equal to the provided value, according to
Object.equals(java.lang.Object). |
DataflowAssert.SingletonAssert<T> |
notEqualTo(T notExpected)
Asserts that the value in question is not equal to the provided value, according
to
Object.equals(java.lang.Object). |
DataflowAssert.SingletonAssert<T> |
satisfies(SerializableFunction<T,Void> checkerFn)
Applies the provided checking function (presumably containing assertions) to the
value in question.
|
DataflowAssert.SingletonAssert<T> |
setCoder(Coder<T> coderOrNull)
Deprecated.
instead call
PCollection.setCoder(Coder) on the actual
PCollection directly. |
@Deprecated DataflowAssert.SingletonAssert<T> setCoder(Coder<T> coderOrNull)
PCollection.setCoder(Coder) on the actual
PCollection directly.PCollection.DataflowAssert.IterableAssert builder for further assertions@Deprecated Coder<T> getCoder()
PCollection.getCoder() on the actual PCollection
directlyPCollection.DataflowAssert.SingletonAssert<T> inOnlyPane(BoundedWindow window)
DataflowAssert.SingletonAssert like this one, but with the assertion restricted to
only run on the provided window.
The assertion will expect outputs to be produced to the provided window exactly once. If
the upstream Trigger may produce output multiple times, consider instead using
inFinalPane(BoundedWindow) or inOnTimePane(BoundedWindow).
DataflowAssert.SingletonAssert like this one but with the assertion only applied to
the specified window.DataflowAssert.SingletonAssert<T> inFinalPane(BoundedWindow window)
DataflowAssert.SingletonAssert like this one, but with the assertion restricted to
only run on the provided window, running the checker only on the final pane for each key.
If the input WindowingStrategy does not always produce final panes, the assertion
may be executed over an empty input even if the trigger has fired previously. To ensure that
a final pane is always produced, set the ClosingBehavior of the windowing strategy
(via Window.Bound#withAllowedLateness(Duration, ClosingBehavior) setting
ClosingBehavior to ClosingBehavior#FIRE_ALWAYS).
DataflowAssert.SingletonAssert like this one but with the assertion only applied to
the specified window.DataflowAssert.SingletonAssert<T> inOnTimePane(BoundedWindow window)
DataflowAssert.SingletonAssert like this one, but with the assertion restricted to
only run on the provided window, running the checker only on the on-time pane for each key.DataflowAssert.SingletonAssert like this one but with the assertion only applied to
the specified window.DataflowAssert.SingletonAssert<T> isEqualTo(T expected)
Object.equals(java.lang.Object).DataflowAssert.SingletonAssert builder for further assertions@Deprecated DataflowAssert.SingletonAssert<T> is(T expected)
isEqualTo(Object)Object.equals(java.lang.Object).DataflowAssert.SingletonAssert builder for further assertionsDataflowAssert.SingletonAssert<T> notEqualTo(T notExpected)
Object.equals(java.lang.Object).DataflowAssert.SingletonAssert builder for further assertionsDataflowAssert.SingletonAssert<T> satisfies(SerializableFunction<T,Void> checkerFn)
DataflowAssert.SingletonAssert builder for further assertions