public class TestDataflowPipelineRunner extends PipelineRunner<DataflowPipelineJob>
TestDataflowPipelineRunner is a pipeline runner that wraps a
DataflowPipelineRunner when running tests against the TestPipeline.TestPipeline| Modifier and Type | Method and Description |
|---|---|
<OutputT extends POutput,InputT extends PInput> |
apply(PTransform<InputT,OutputT> transform,
InputT input)
Applies a transform to the given input, returning the output.
|
static TestDataflowPipelineRunner |
fromOptions(PipelineOptions options)
Constructs a runner from the provided options.
|
DataflowPipelineJob |
run(Pipeline pipeline)
Processes the given Pipeline, returning the results.
|
String |
toString() |
public static TestDataflowPipelineRunner fromOptions(PipelineOptions options)
public DataflowPipelineJob run(Pipeline pipeline)
PipelineRunnerrun in class PipelineRunner<DataflowPipelineJob>public <OutputT extends POutput,InputT extends PInput> OutputT apply(PTransform<InputT,OutputT> transform, InputT input)
PipelineRunnerThe default implementation calls PTransform.apply(input), but can be overridden to customize behavior for a particular runner.
apply in class PipelineRunner<DataflowPipelineJob>