See: Description
| Interface | Description |
|---|---|
| DataflowAssert.IterableAssert<T> |
Builder interface for assertions applicable to iterables and PCollection contents.
|
| DataflowAssert.SingletonAssert<T> |
Builder interface for assertions applicable to a single value.
|
| RunnableOnService |
Category tag for tests that can be run on the
DataflowPipelineRunner if the
runIntegrationTestOnService System property is set to true. |
| TestDataflowPipelineOptions |
A set of options used to configure the
TestPipeline. |
| TestStream.Event<T> |
An event in a
TestStream. |
| Class | Description |
|---|---|
| CoderProperties |
Properties for use in
Coder tests. |
| DataflowAssert |
An assertion on the contents of a
PCollection incorporated into the pipeline. |
| DataflowAssert.GroupThenAssert<T> |
A transform that applies an assertion-checking function over iterables of
ActualT to
the entirety of the contents of its input. |
| DataflowAssert.GroupThenAssertForSingleton<T> |
A transform that applies an assertion-checking function to a single iterable contained as the
sole element of a
PCollection. |
| DataflowAssert.OneSideInputAssert<ActualT> |
An assertion checker that takes a single
PCollectionView<ActualT> and an assertion over ActualT, and checks it within a
Beam pipeline. |
| SourceTestUtils |
Helper functions and test harnesses for checking correctness of
implementations. |
| TestDataflowPipelineRunner |
TestDataflowPipelineRunner is a pipeline runner that wraps a
DataflowPipelineRunner when running tests against the TestPipeline. |
| TestPipeline |
A creator of test pipelines that can be used inside of tests that can be
configured to run locally or against the live service.
|
| TestStream<T> |
A testing input that generates an unbounded
PCollection of elements, advancing the
watermark and processing time as elements are emitted. |
| TestStream.Builder<T> |
An incomplete
TestStream. |
| TestStream.ElementEvent<T> |
An
TestStream.Event that produces elements. |
| TestStream.ProcessingTimeEvent<T> |
An
TestStream.Event that advances the processing time clock. |
| TestStream.WatermarkEvent<T> |
An
TestStream.Event that advances the watermark. |
| WindowFnTestUtils |
A utility class for testing
WindowFns. |
| Enum | Description |
|---|---|
| SourceTestUtils.ExpectedSplitOutcome |
Expected outcome of
BoundedSource.BoundedReader.splitAtFraction(double). |
| TestStream.EventType |
The types of
TestStream.Event that are supported by TestStream. |
PTransforms and
examples included the Dataflow SDK provide examples of using these utilities.