public static class Combine.PerKeyWithHotKeyFanout<K,InputT,OutputT> extends PTransform<PCollection<KV<K,InputT>>,PCollection<KV<K,OutputT>>>
Combine.PerKey, but sharding the combining of hot keys.name| Modifier and Type | Method and Description |
|---|---|
PCollection<KV<K,OutputT>> |
apply(PCollection<KV<K,InputT>> input)
Applies this
PTransform on the given InputT, and returns its
Output. |
getDefaultOutputCoder, getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, toString, validatepublic PCollection<KV<K,OutputT>> apply(PCollection<KV<K,InputT>> input)
PTransformPTransform on the given InputT, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<InputT, OutputT>, InputT).
apply in class PTransform<PCollection<KV<K,InputT>>,PCollection<KV<K,OutputT>>>