| Modifier and Type | Method and Description |
|---|---|
<T> T |
lookup(CodedTupleTag<T> tag)
Returns the value associated with the given tag in this
KeyedState, or null if the tag has no asssociated
value. |
CodedTupleTagMap |
lookup(java.util.List<? extends CodedTupleTag<?>> tags)
Returns a map from the given tags to the values associated with
those tags in this
KeyedState. |
<T> void |
store(CodedTupleTag<T> tag,
T value)
Updates this
KeyedState in place so that the given tag
maps to the given value. |
<T> void store(CodedTupleTag<T> tag, T value) throws java.io.IOException
KeyedState in place so that the given tag
maps to the given value.java.io.IOException - if encoding the given value fails<T> T lookup(CodedTupleTag<T> tag) throws java.io.IOException
KeyedState, or null if the tag has no asssociated
value.
See lookup(List) to look up multiple tags at
once. It is significantly more efficient to look up multiple
tags all at once rather than one at a time.
java.io.IOException - if decoding the requested value failsCodedTupleTagMap lookup(java.util.List<? extends CodedTupleTag<?>> tags) throws java.io.IOException
KeyedState. A tag will map to null if
the tag had no associated value.
See lookup(CodedTupleTag) to look up a single
tag.
CoderException - if decoding any of the requested values failsjava.io.IOException