public abstract class DoFn.ProcessContext extends DoFn.Context
DoFn.processElement(com.google.cloud.dataflow.sdk.transforms.DoFn<InputT, OutputT>.ProcessContext).| Constructor and Description |
|---|
ProcessContext() |
| Modifier and Type | Method and Description |
|---|---|
abstract InputT |
element()
Returns the input element to be processed.
|
abstract PaneInfo |
pane()
Returns information about the pane within this window into which the
input element has been assigned.
|
abstract <T> T |
sideInput(PCollectionView<T> view)
Returns the value of the side input for the window corresponding to the
window of the main input element.
|
abstract org.joda.time.Instant |
timestamp()
Returns the timestamp of the input element.
|
abstract BoundedWindow |
window()
Returns the window into which the input element has been assigned.
|
abstract com.google.cloud.dataflow.sdk.util.WindowingInternals<InputT,OutputT> |
windowingInternals()
Returns the process context to use for implementing windowing.
|
createAggregatorInternal, getPipelineOptions, output, outputWithTimestamp, setupDelegateAggregators, sideOutput, sideOutputWithTimestamppublic abstract InputT element()
The element will not be changed -- it is safe to cache, etc. without copying.
public abstract <T> T sideInput(PCollectionView<T> view)
See
WindowFn.getSideInputWindow(com.google.cloud.dataflow.sdk.transforms.windowing.BoundedWindow)
for how this corresponding window is determined.
IllegalArgumentException - if this is not a side inputParDo.withSideInputs(com.google.cloud.dataflow.sdk.values.PCollectionView<?>...)public abstract org.joda.time.Instant timestamp()
See Window
for more information.
public abstract BoundedWindow window()
See Window
for more information.
UnsupportedOperationException - if this DoFn does
not implement DoFn.RequiresWindowAccess.public abstract PaneInfo pane()
Generally all data is in a single, uninteresting pane unless custom
triggering and/or late data has been explicitly requested.
See Window
for more information.
@Experimental public abstract com.google.cloud.dataflow.sdk.util.WindowingInternals<InputT,OutputT> windowingInternals()