public static class GroupByKey.GroupAlsoByWindow<K,V> extends PTransform<PCollection<KV<K,Iterable<com.google.cloud.dataflow.sdk.util.WindowedValue<V>>>>,PCollection<KV<K,Iterable<V>>>>
name| Constructor and Description |
|---|
GroupAlsoByWindow(com.google.cloud.dataflow.sdk.util.WindowingStrategy<?,?> windowingStrategy) |
| Modifier and Type | Method and Description |
|---|---|
PCollection<KV<K,Iterable<V>>> |
apply(PCollection<KV<K,Iterable<com.google.cloud.dataflow.sdk.util.WindowedValue<V>>>> input)
Applies this
PTransform on the given InputT, and returns its
Output. |
getDefaultOutputCoder, getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, populateDisplayData, toString, validatepublic GroupAlsoByWindow(com.google.cloud.dataflow.sdk.util.WindowingStrategy<?,?> windowingStrategy)
public PCollection<KV<K,Iterable<V>>> apply(PCollection<KV<K,Iterable<com.google.cloud.dataflow.sdk.util.WindowedValue<V>>>> input)
PTransformPTransform on the given InputT, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<InputT, OutputT>, InputT).
apply in class PTransform<PCollection<KV<K,Iterable<com.google.cloud.dataflow.sdk.util.WindowedValue<V>>>>,PCollection<KV<K,Iterable<V>>>>