InputT - the type of the (main) input PCollection elementsOutputT - the type of the (main) output PCollection elementspublic static class IntraBundleParallelization.Bound<InputT,OutputT> extends PTransform<PCollection<? extends InputT>,PCollection<OutputT>>
PTransform that, when applied to a PCollection<InputT>,
invokes a user-specified DoFn<InputT, OutputT> on all its elements,
with all its outputs collected into an output
PCollection<OutputT>.
Note that the specified doFn needs to be thread safe.
name| Modifier and Type | Method and Description |
|---|---|
PCollection<OutputT> |
apply(PCollection<? extends InputT> input)
Applies this
PTransform on the given InputT, and returns its
Output. |
<NewInputT,NewOutputT> |
of(DoFn<NewInputT,NewOutputT> doFn)
|
IntraBundleParallelization.Bound<InputT,OutputT> |
withMaxParallelism(int maxParallelism)
Returns a new
IntraBundleParallelization PTransform like this one
with the specified maximum concurrency level. |
getDefaultOutputCoder, getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, populateDisplayData, toString, validatepublic IntraBundleParallelization.Bound<InputT,OutputT> withMaxParallelism(int maxParallelism)
IntraBundleParallelization PTransform like this one
with the specified maximum concurrency level.public <NewInputT,NewOutputT> IntraBundleParallelization.Bound<NewInputT,NewOutputT> of(DoFn<NewInputT,NewOutputT> doFn)
IntraBundleParallelization PTransform like this one
with the specified DoFn.
Note that the specified doFn needs to be thread safe.
public PCollection<OutputT> apply(PCollection<? extends InputT> input)
PTransformPTransform on the given InputT, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<InputT, OutputT>, InputT).
apply in class PTransform<PCollection<? extends InputT>,PCollection<OutputT>>