public static class Max.MaxIntegerFn extends Max.MaxFn<Integer> implements com.google.cloud.dataflow.sdk.util.common.CounterProvider<Integer>
CombineFn that computes the maximum of a collection of Integers, useful as an
argument to Combine.globally(com.google.cloud.dataflow.sdk.transforms.SerializableFunction<java.lang.Iterable<V>, V>) or Combine.perKey(com.google.cloud.dataflow.sdk.transforms.SerializableFunction<java.lang.Iterable<V>, V>).| Constructor and Description |
|---|
MaxIntegerFn() |
| Modifier and Type | Method and Description |
|---|---|
TypeVariable<?> |
getAccumTVariable()
Returns the
TypeVariable of AccumT. |
com.google.cloud.dataflow.sdk.util.common.Counter<Integer> |
getCounter(String name) |
String |
getIncompatibleGlobalWindowErrorMessage()
Returns the error message for not supported default values in Combine.globally().
|
TypeVariable<?> |
getInputTVariable()
Returns the
TypeVariable of InputT. |
TypeVariable<?> |
getOutputTVariable()
Returns the
TypeVariable of OutputT. |
apply, identity, naturalOrder, naturalOrder, of, ofaddInput, createAccumulator, extractOutput, getAccumulatorCoder, getDefaultOutputCoder, mergeAccumulatorsapply, asKeyedFn, compact, defaultValue, getOutputTypepublic com.google.cloud.dataflow.sdk.util.common.Counter<Integer> getCounter(String name)
getCounter in interface com.google.cloud.dataflow.sdk.util.common.CounterProvider<Integer>public String getIncompatibleGlobalWindowErrorMessage()
CombineFnBase.GlobalCombineFngetIncompatibleGlobalWindowErrorMessage in interface CombineFnBase.GlobalCombineFn<InputT,AccumT,OutputT>public TypeVariable<?> getInputTVariable()
TypeVariable of InputT.public TypeVariable<?> getAccumTVariable()
TypeVariable of AccumT.public TypeVariable<?> getOutputTVariable()
TypeVariable of OutputT.