public class Min
extends java.lang.Object
PTransforms for computing the minimum of the elements in a
PCollection, or the minimum of the values associated with
each key in a PCollection of KVs.
Example 1: get the minimum of a PCollection of Doubles.
PCollection<Double> input = ...;
PCollection<Double> min = input.apply(Min.doublesGlobally());
Example 2: calculate the minimum of the Integers
associated with each unique key (which is of type String).
PCollection<KV<String, Integer>> input = ...;
PCollection<KV<String, Integer>> minPerKey = input
.apply(Min.<String>integersPerKey());
| Constructor and Description |
|---|
Min() |
| Modifier and Type | Method and Description |
|---|---|
static Combine.Globally<java.lang.Double,java.lang.Double> |
doublesGlobally()
Returns a
PTransform that takes an input
PCollection<Double> and returns a
PCollection<Double> whose contents is the minimum of the
input PCollection's elements, or
Double.POSITIVE_INFINITY if there are no elements. |
static <K> Combine.PerKey<K,java.lang.Double,java.lang.Double> |
doublesPerKey()
Returns a
PTransform that takes an input
PCollection<KV<K, Double>> and returns a
PCollection<KV<K, Double>> that contains an output
element mapping each distinct key in the input
PCollection to the minimum of the values associated with
that key in the input PCollection. |
static Combine.Globally<java.lang.Integer,java.lang.Integer> |
integersGlobally()
Returns a
PTransform that takes an input
PCollection<Integer> and returns a
PCollection<Integer> whose contents is a single value that is
the minimum of the input PCollection's elements, or
Integer.MAX_VALUE if there are no elements. |
static <K> Combine.PerKey<K,java.lang.Integer,java.lang.Integer> |
integersPerKey()
Returns a
PTransform that takes an input
PCollection<KV<K, Integer>> and returns a
PCollection<KV<K, Integer>> that contains an output
element mapping each distinct key in the input
PCollection to the minimum of the values associated with
that key in the input PCollection. |
static Combine.Globally<java.lang.Long,java.lang.Long> |
longsGlobally()
Returns a
PTransform that takes an input
PCollection<Long> and returns a
PCollection<Long> whose contents is the minimum of the
input PCollection's elements, or
Long.MAX_VALUE if there are no elements. |
static <K> Combine.PerKey<K,java.lang.Long,java.lang.Long> |
longsPerKey()
Returns a
PTransform that takes an input
PCollection<KV<K, Long>> and returns a
PCollection<KV<K, Long>> that contains an output
element mapping each distinct key in the input
PCollection to the minimum of the values associated with
that key in the input PCollection. |
public static Combine.Globally<java.lang.Integer,java.lang.Integer> integersGlobally()
PTransform that takes an input
PCollection<Integer> and returns a
PCollection<Integer> whose contents is a single value that is
the minimum of the input PCollection's elements, or
Integer.MAX_VALUE if there are no elements.public static <K> Combine.PerKey<K,java.lang.Integer,java.lang.Integer> integersPerKey()
PTransform that takes an input
PCollection<KV<K, Integer>> and returns a
PCollection<KV<K, Integer>> that contains an output
element mapping each distinct key in the input
PCollection to the minimum of the values associated with
that key in the input PCollection.
See Combine.PerKey for how this affects timestamps and windowing.
public static Combine.Globally<java.lang.Long,java.lang.Long> longsGlobally()
PTransform that takes an input
PCollection<Long> and returns a
PCollection<Long> whose contents is the minimum of the
input PCollection's elements, or
Long.MAX_VALUE if there are no elements.public static <K> Combine.PerKey<K,java.lang.Long,java.lang.Long> longsPerKey()
PTransform that takes an input
PCollection<KV<K, Long>> and returns a
PCollection<KV<K, Long>> that contains an output
element mapping each distinct key in the input
PCollection to the minimum of the values associated with
that key in the input PCollection.
See Combine.PerKey for how this affects timestamps and windowing.
public static Combine.Globally<java.lang.Double,java.lang.Double> doublesGlobally()
PTransform that takes an input
PCollection<Double> and returns a
PCollection<Double> whose contents is the minimum of the
input PCollection's elements, or
Double.POSITIVE_INFINITY if there are no elements.public static <K> Combine.PerKey<K,java.lang.Double,java.lang.Double> doublesPerKey()
PTransform that takes an input
PCollection<KV<K, Double>> and returns a
PCollection<KV<K, Double>> that contains an output
element mapping each distinct key in the input
PCollection to the minimum of the values associated with
that key in the input PCollection.
See Combine.PerKey for how this affects timestamps and windowing.