InputT - the type of the (main) input PCollection elementsOutputT - the type of the main output PCollection elementspublic static class ParDo.BoundMulti<InputT,OutputT> extends PTransform<PCollection<? extends InputT>,PCollectionTuple>
PTransform that, when applied to a
PCollection<InputT>, invokes a user-specified
DoFn<InputT, OutputT> on all its elements, which can emit elements
to any of the PTransform's main and side output
PCollections, which are bundled into a result
PCollectionTuple.name| Modifier and Type | Method and Description |
|---|---|
PCollectionTuple |
apply(PCollection<? extends InputT> input)
Applies this
PTransform on the given InputT, and returns its
Output. |
protected String |
getDefaultName()
Returns the name to use by default for this
PTransform
(not including the names of any enclosing PTransforms). |
protected Coder<OutputT> |
getDefaultOutputCoder()
Returns the default
Coder to use for the output of this
single-output PTransform. |
<T> Coder<T> |
getDefaultOutputCoder(PCollection<? extends InputT> input,
TypedPValue<T> output)
Returns the default
Coder to use for the given output of
this single-output PTransform when applied to the given input. |
DoFn<InputT,OutputT> |
getFn() |
protected String |
getKindString()
Returns a string describing what kind of
PTransform this is. |
TupleTag<OutputT> |
getMainOutputTag() |
List<PCollectionView<?>> |
getSideInputs() |
ParDo.BoundMulti<InputT,OutputT> |
named(String name)
Returns a new multi-output
ParDo PTransform
that's like this PTransform but with the specified
name. |
ParDo.BoundMulti<InputT,OutputT> |
withSideInputs(Iterable<? extends PCollectionView<?>> sideInputs)
Returns a new multi-output
ParDo PTransform
that's like this PTransform but with the specified side
inputs. |
ParDo.BoundMulti<InputT,OutputT> |
withSideInputs(PCollectionView<?>... sideInputs)
Returns a new multi-output
ParDo PTransform
that's like this PTransform but with the specified side
inputs. |
getDefaultOutputCoder, getName, setName, toString, validate, withNamepublic ParDo.BoundMulti<InputT,OutputT> named(String name)
ParDo PTransform
that's like this PTransform but with the specified
name. Does not modify this PTransform.
See the discussion of Naming above for more explanation.
public ParDo.BoundMulti<InputT,OutputT> withSideInputs(PCollectionView<?>... sideInputs)
ParDo PTransform
that's like this PTransform but with the specified side
inputs. Does not modify this PTransform.
See the discussion of Side Inputs above and on
ParDo.withSideInputs(com.google.cloud.dataflow.sdk.values.PCollectionView<?>...) for more explanation.
public ParDo.BoundMulti<InputT,OutputT> withSideInputs(Iterable<? extends PCollectionView<?>> sideInputs)
ParDo PTransform
that's like this PTransform but with the specified side
inputs. Does not modify this PTransform.
See the discussion of Side Inputs above and on
ParDo.withSideInputs(com.google.cloud.dataflow.sdk.values.PCollectionView<?>...) for more explanation.
public PCollectionTuple apply(PCollection<? extends InputT> input)
PTransformPTransform on the given InputT, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<InputT, OutputT>, InputT).
apply in class PTransform<PCollection<? extends InputT>,PCollectionTuple>protected Coder<OutputT> getDefaultOutputCoder()
PTransformCoder to use for the output of this
single-output PTransform.
By default, always throws
getDefaultOutputCoder in class PTransform<PCollection<? extends InputT>,PCollectionTuple>public <T> Coder<T> getDefaultOutputCoder(PCollection<? extends InputT> input, TypedPValue<T> output) throws CannotProvideCoderException
PTransformCoder to use for the given output of
this single-output PTransform when applied to the given input.getDefaultOutputCoder in class PTransform<PCollection<? extends InputT>,PCollectionTuple>CannotProvideCoderException - if none can be inferred.
By default, always throws.
protected String getDefaultName()
PTransformPTransform
(not including the names of any enclosing PTransforms).
By default, returns PTransform.getKindString().
The caller is responsible for ensuring that names of applied
PTransforms are unique, e.g., by adding a uniquifying
suffix when needed.
getDefaultName in class PTransform<PCollection<? extends InputT>,PCollectionTuple>protected String getKindString()
PTransformPTransform this is.
By default, returns the base name of this
PTransform's class.
getKindString in class PTransform<PCollection<? extends InputT>,PCollectionTuple>public List<PCollectionView<?>> getSideInputs()