O - the type of the main output PCollection elementspublic static class ParDo.UnboundMulti<O>
extends java.lang.Object
ParDo transform, with unbound
input type.
Before being applied, of(com.google.cloud.dataflow.sdk.transforms.DoFn<I, O>) must be
invoked to specify the DoFn to invoke, which will also
bind the input type of this PTransform.
| Modifier and Type | Method and Description |
|---|---|
ParDo.UnboundMulti<O> |
named(java.lang.String name)
Returns a new multi-output
ParDo transform that's like
this transform but with the specified name. |
<I> ParDo.BoundMulti<I,O> |
of(DoFn<I,O> fn)
Returns a new multi-output
ParDo PTransform
that's like this transform but which will invoke the given
DoFn function, and which has its input type bound. |
ParDo.UnboundMulti<O> |
withSideInputs(java.lang.Iterable<? extends PCollectionView<?,?>> sideInputs)
Returns a new multi-output
ParDo transform that's like
this transform but with the specified side inputs. |
ParDo.UnboundMulti<O> |
withSideInputs(PCollectionView<?,?>... sideInputs)
Returns a new multi-output
ParDo transform that's like
this transform but with the specified side inputs. |
public ParDo.UnboundMulti<O> named(java.lang.String name)
ParDo transform that's like
this transform but with the specified name. Does not modify
this transform. The resulting transform is still incomplete.
See the discussion of Naming above for more explanation.
public ParDo.UnboundMulti<O> withSideInputs(PCollectionView<?,?>... sideInputs)
ParDo transform that's like
this transform but with the specified side inputs. Does not
modify this transform. The resulting transform is still
incomplete.
See the discussion of Side Inputs above and on
ParDo.withSideInputs(com.google.cloud.dataflow.sdk.values.PCollectionView<?, ?>...) for more explanation.
public ParDo.UnboundMulti<O> withSideInputs(java.lang.Iterable<? extends PCollectionView<?,?>> sideInputs)
ParDo transform that's like
this transform but with the specified side inputs. Does not
modify this transform. The resulting transform is still
incomplete.
See the discussion of Side Inputs above and on
ParDo.withSideInputs(com.google.cloud.dataflow.sdk.values.PCollectionView<?, ?>...) for more explanation.
public <I> ParDo.BoundMulti<I,O> of(DoFn<I,O> fn)
ParDo PTransform
that's like this transform but which will invoke the given
DoFn function, and which has its input type bound.
Does not modify this transform. The resulting
PTransform is sufficiently specified to be applied, but
more properties can still be specified.