T - the type of input and output elementIdT - the type of representative values used to deduppublic static class RemoveDuplicates.WithRepresentativeValues<T,IdT> extends PTransform<PCollection<T>,PCollection<T>>
RemoveDuplicates PTransform that uses a SerializableFunction to
obtain a representative value for each input element.
Construct via RemoveDuplicates.withRepresentativeValueFn(SerializableFunction).
name| Modifier and Type | Method and Description |
|---|---|
PCollection<T> |
apply(PCollection<T> in)
Applies this
PTransform on the given InputT, and returns its
Output. |
RemoveDuplicates.WithRepresentativeValues<T,IdT> |
withRepresentativeType(TypeDescriptor<IdT> type)
Return a
WithRepresentativeValues PTransform that is like this one, but with
the specified output type descriptor. |
getDefaultOutputCoder, getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, populateDisplayData, toString, validatepublic PCollection<T> apply(PCollection<T> in)
PTransformPTransform on the given InputT, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<InputT, OutputT>, InputT).
apply in class PTransform<PCollection<T>,PCollection<T>>public RemoveDuplicates.WithRepresentativeValues<T,IdT> withRepresentativeType(TypeDescriptor<IdT> type)
WithRepresentativeValues PTransform that is like this one, but with
the specified output type descriptor.
Required for use of
RemoveDuplicates.withRepresentativeValueFn(SerializableFunction) in Java 8 with a
lambda as the fn.
type - a TypeDescriptor describing the representative type of this
WithRepresentativeValuesWithRepresentativeValues PTransform that is like this one, but with
the specified output type descriptor.