public static class Sample.SampleAny<T> extends PTransform<PCollection<T>,PCollection<T>>
PTransform that takes a PCollection<T> and a limit, and
produces a new PCollection<T> containing up to limit
elements of the input PCollection.name| Modifier and Type | Method and Description |
|---|---|
PCollection<T> |
apply(PCollection<T> in)
Applies this
PTransform on the given InputT, and returns its
Output. |
getDefaultOutputCoder, getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, populateDisplayData, toString, validatepublic PCollection<T> apply(PCollection<T> in)
PTransformPTransform on the given InputT, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<InputT, OutputT>, InputT).
apply in class PTransform<PCollection<T>,PCollection<T>>