public static class View.AsMap<K,V> extends PTransform<PCollection<KV<K,V>>,PCollectionView<Map<K,V>>>
PTransform that produces a PCollectionView of a keyed PCollection
yielding a map from each key to its unique associated value. When converting
a PCollection that has more than one value per key, precede this transform with a
Combine.perKey:
PCollectionView<Map<K, OutputT>> input
.apply(Combine.perKey(myCombineFunction))
.apply(View.<K, OutputT>asMap());
Instantiate via View.asMap().
name| Modifier and Type | Method and Description |
|---|---|
PCollectionView<Map<K,V>> |
apply(PCollection<KV<K,V>> input)
Applies this
PTransform on the given InputT, and returns its
Output. |
void |
validate(PCollection<KV<K,V>> input)
Called before invoking apply (which may be intercepted by the runner) to
verify this transform is fully specified and applicable to the specified
input.
|
View.AsMap<K,V> |
withSingletonValues()
Deprecated.
this method simply returns this AsMap unmodified
|
getDefaultOutputCoder, getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, toString@Deprecated public View.AsMap<K,V> withSingletonValues()
public void validate(PCollection<KV<K,V>> input)
PTransformBy default, does nothing.
validate in class PTransform<PCollection<KV<K,V>>,PCollectionView<Map<K,V>>>public PCollectionView<Map<K,V>> apply(PCollection<KV<K,V>> input)
PTransformPTransform on the given InputT, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<InputT, OutputT>, InputT).
apply in class PTransform<PCollection<KV<K,V>>,PCollectionView<Map<K,V>>>