public static class View.AsMultimap<K,V> extends PTransform<PCollection<KV<K,V>>,PCollectionView<Map<K,Iterable<V>>>>
PTransform that produces a PCollectionView of a keyed PCollection
yielding a map of keys to all associated values.
Instantiate via View.asMap().
name| Modifier and Type | Method and Description |
|---|---|
PCollectionView<Map<K,Iterable<V>>> |
apply(PCollection<KV<K,V>> input)
Applies this
PTransform on the given InputT, and returns its
Output. |
getDefaultOutputCoder, getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, toString, validatepublic PCollectionView<Map<K,Iterable<V>>> apply(PCollection<KV<K,V>> input)
PTransformPTransform on the given InputT, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<InputT, OutputT>, InputT).
apply in class PTransform<PCollection<KV<K,V>>,PCollectionView<Map<K,Iterable<V>>>>