public static class View.AsSingleton<T> extends PTransform<PCollection<T>,PCollectionView<T>>
PTransform that produces a PCollectionView of a singleton
PCollection yielding the single element it contains.
Instantiate via View.asIterable().
name| Modifier and Type | Method and Description |
|---|---|
PCollectionView<T> |
apply(PCollection<T> input)
Applies this
PTransform on the given Input, and returns its
Output. |
View.AsSingleton<T> |
withDefaultValue(T defaultValue)
Default value to return for windows with no value in them.
|
finishSpecifying, getCoderRegistry, getDefaultName, getDefaultOutputCoder, getDefaultOutputCoder, getInput, getKindString, getName, getOutput, getPipeline, setName, setPipeline, toString, withNamepublic View.AsSingleton<T> withDefaultValue(T defaultValue)
public PCollectionView<T> apply(PCollection<T> input)
PTransformPTransform on the given Input, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<Input, Output>, Input).
apply in class PTransform<PCollection<T>,PCollectionView<T>>