public static class View.AsSingletonMap<K,VI,VO> extends PTransform<PCollection<KV<K,VI>>,PCollectionView<java.util.Map<K,VO>>>
PTransform that produces a PCollectionView of a keyed PCollection
yielding a map of keys to a single associated values.
Instantiate via View.asMap().
name| Modifier and Type | Method and Description |
|---|---|
PCollectionView<java.util.Map<K,VO>> |
apply(PCollection<KV<K,VI>> input)
Applies this
PTransform on the given Input, and returns its
Output. |
finishSpecifyingInternal, getDefaultName, getDefaultOutputCoder, getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, setName, setPipeline, toString, validate, withNamepublic PCollectionView<java.util.Map<K,VO>> apply(PCollection<KV<K,VI>> input)
PTransformPTransform on the given Input, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<Input, Output>, Input).
apply in class PTransform<PCollection<KV<K,VI>>,PCollectionView<java.util.Map<K,VO>>>