ElemT - The type of the elements of the input PCollectionViewT - The type associated with the PCollectionView used as a side inputpublic static class View.CreatePCollectionView<ElemT,ViewT> extends PTransform<PCollection<ElemT>,PCollectionView<ViewT>>
PCollectionView.
For internal use only by runner implementors.
name| Modifier and Type | Method and Description |
|---|---|
PCollectionView<ViewT> |
apply(PCollection<ElemT> input)
Applies this
PTransform on the given InputT, and returns its
Output. |
static <ElemT,ViewT> |
of(PCollectionView<ViewT> view) |
getDefaultOutputCoder, getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, toString, validatepublic static <ElemT,ViewT> View.CreatePCollectionView<ElemT,ViewT> of(PCollectionView<ViewT> view)
public PCollectionView<ViewT> apply(PCollection<ElemT> input)
PTransformPTransform on the given InputT, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<InputT, OutputT>, InputT).
apply in class PTransform<PCollection<ElemT>,PCollectionView<ViewT>>