public static interface DisplayData.Builder
| Modifier and Type | Method and Description |
|---|---|
DisplayData.ItemBuilder |
add(String key,
Class<?> value)
Register the given class display metadata.
|
DisplayData.ItemBuilder |
add(String key,
double value)
Register the given floating point display metadata.
|
DisplayData.ItemBuilder |
add(String key,
Duration value)
Register the given duration display metadata.
|
DisplayData.ItemBuilder |
add(String key,
Instant value)
Register the given timestamp display metadata.
|
DisplayData.ItemBuilder |
add(String key,
long value)
Register the given numeric display metadata.
|
DisplayData.ItemBuilder |
add(String key,
String value)
Register the given string display metadata.
|
DisplayData.Builder |
include(HasDisplayData subComponent)
Include display metadata from the specified subcomponent.
|
DisplayData.Builder include(HasDisplayData subComponent)
ParDo
transform includes display metadata from the encapsulated DoFn.DisplayData.ItemBuilder add(String key, String value)
DisplayData.Type.STRING, and is identified by the specified key and namespace from
the current transform or component.DisplayData.ItemBuilder add(String key, long value)
DisplayData.Type.INTEGER, and is identified by the specified key and namespace from
the current transform or component.DisplayData.ItemBuilder add(String key, double value)
DisplayData.Type.FLOAT, and is identified by the specified key and namespace
from the current transform or component.DisplayData.ItemBuilder add(String key, Instant value)
DisplayData.Type.TIMESTAMP, and is identified by the specified key and namespace from
the current transform or component.DisplayData.ItemBuilder add(String key, Duration value)
DisplayData.Type.DURATION, and is identified by the specified key and namespace from
the current transform or component.DisplayData.ItemBuilder add(String key, Class<?> value)
DisplayData.Type.JAVA_CLASS, and is identified by the specified key and namespace
from the current transform or component.