public static class DisplayData.Identifier extends Object
Display metadata registered with the same key from different components will have different
namespaces and thus will both be represented in the composed DisplayData. If a
single component registers multiple metadata items with the same key, only the most recent
item will be retained; previous versions are discarded.
| Modifier and Type | Method and Description |
|---|---|
boolean |
equals(Object obj) |
String |
getKey() |
String |
getNamespace() |
int |
hashCode() |
String |
toString() |