K - the type of key shared by all constituent PCollectionspublic class KeyedPCollectionTuple<K> extends Object implements PInput
PCollections
with key type K.
(PCollections containing values of type
KV<K, ?>)| Modifier and Type | Class and Description |
|---|---|
static class |
KeyedPCollectionTuple.TaggedKeyedPCollection<K,V>
A utility class to help ensure coherence of tag and input PCollection
types.
|
| Modifier and Type | Method and Description |
|---|---|
<V> KeyedPCollectionTuple<K> |
and(TupleTag<V> tag,
PCollection<KV<K,V>> pc)
Returns a new
KeyedPCollectionTuple<K> that is the same as this,
appended with the given PCollection. |
<OutputT extends POutput> |
apply(PTransform<KeyedPCollectionTuple<K>,OutputT> transform)
Applies the given
PTransform to this input. |
static <K> KeyedPCollectionTuple<K> |
empty(Pipeline pipeline)
Returns an empty
KeyedPCollectionTuple<K> on the given pipeline. |
Collection<? extends PValue> |
expand()
Expands the component
PCollections, stripping off
any tag-specific information. |
void |
finishSpecifying()
After building, finalizes this
PInput to make it ready for
being used as an input to a PTransform. |
CoGbkResultSchema |
getCoGbkResultSchema()
Returns the
CoGbkResultSchema associated with this
KeyedPCollectionTuple. |
Coder<K> |
getKeyCoder()
|
List<KeyedPCollectionTuple.TaggedKeyedPCollection<K,?>> |
getKeyedCollections()
Returns a list of
TaggedKeyedPCollections for the
PCollections contained in this KeyedPCollectionTuple. |
Pipeline |
getPipeline()
Returns the owning
Pipeline of this PInput. |
boolean |
isEmpty() |
static <K,InputT> KeyedPCollectionTuple<K> |
of(TupleTag<InputT> tag,
PCollection<KV<K,InputT>> pc)
Returns a new
KeyedPCollectionTuple<K> with the given tag and initial
PCollection. |
public static <K> KeyedPCollectionTuple<K> empty(Pipeline pipeline)
KeyedPCollectionTuple<K> on the given pipeline.public static <K,InputT> KeyedPCollectionTuple<K> of(TupleTag<InputT> tag, PCollection<KV<K,InputT>> pc)
KeyedPCollectionTuple<K> with the given tag and initial
PCollection.public <V> KeyedPCollectionTuple<K> and(TupleTag<V> tag, PCollection<KV<K,V>> pc)
KeyedPCollectionTuple<K> that is the same as this,
appended with the given PCollection.public boolean isEmpty()
public List<KeyedPCollectionTuple.TaggedKeyedPCollection<K,?>> getKeyedCollections()
TaggedKeyedPCollections for the
PCollections contained in this KeyedPCollectionTuple.public <OutputT extends POutput> OutputT apply(PTransform<KeyedPCollectionTuple<K>,OutputT> transform)
PTransform to this input.public Collection<? extends PValue> expand()
PCollections, stripping off
any tag-specific information.public CoGbkResultSchema getCoGbkResultSchema()
CoGbkResultSchema associated with this
KeyedPCollectionTuple.public Pipeline getPipeline()
PInputPipeline of this PInput.getPipeline in interface PInputpublic void finishSpecifying()
PInput After building, finalizes this PInput to make it ready for
being used as an input to a PTransform.
Automatically invoked whenever apply() is invoked on
this PInput, so users do not normally call this explicitly.
finishSpecifying in interface PInput