W - BoundedWindow subclass used to represent the windows used@Experimental(value=TRIGGER) public class AfterProcessingTime<W extends BoundedWindow> extends AfterDelayFromFirstElement<W>
AfterProcessingTime triggers fire based on the current processing time. They operate in
the real-time domain.
The time at which to fire the timer can be adjusted via the methods in TimeTrigger,
such as TimeTrigger#plusDelayOf or TimeTrigger#alignedTo.
Trigger.MergingTriggerInfo<W extends BoundedWindow>, Trigger.OnceTrigger<W extends BoundedWindow>, Trigger.OnElementContext, Trigger.OnMergeContext, Trigger.TriggerContext, Trigger.TriggerInfo<W extends BoundedWindow>DELAYED_UNTIL_TAG, IDENTITY, timestampMapperssubTriggers| Modifier and Type | Method and Description |
|---|---|
boolean |
equals(Object obj) |
protected Trigger<W> |
getContinuationTrigger(List<Trigger<W>> continuationTriggers)
Return the
Trigger.getContinuationTrigger() of this Trigger. |
Instant |
getCurrentTime(Trigger.TriggerContext context)
To complete an implementation, return the desired time from the TriggerContext.
|
Instant |
getWatermarkThatGuaranteesFiring(W window)
Returns a bound in watermark time by which this trigger would have fired at least once
for a given window had there been input data.
|
int |
hashCode() |
protected AfterProcessingTime<W> |
newWith(List<SerializableFunction<Instant,Instant>> transforms)
To complete an implementation, return a new instance like this one, but incorporating
the provided timestamp mapping functions.
|
static <W extends BoundedWindow> |
pastFirstElementInPane()
Creates a trigger that fires when the current processing time passes the processing time
at which this trigger saw the first element in a pane.
|
String |
toString() |
alignedTo, alignedTo, clear, computeTargetTimestamp, isCompatible, mappedTo, onElement, onMerge, onOnlyFiring, plusDelayOf, prefetchOnElement, prefetchOnMerge, prefetchShouldFire, shouldFiregetContinuationTrigger, onFirebuildTrigger, orFinally, prefetchOnFire, subTriggers@Nullable public Instant getCurrentTime(Trigger.TriggerContext context)
AfterDelayFromFirstElementgetCurrentTime in class AfterDelayFromFirstElement<W extends BoundedWindow>public static <W extends BoundedWindow> AfterProcessingTime<W> pastFirstElementInPane()
protected AfterProcessingTime<W> newWith(List<SerializableFunction<Instant,Instant>> transforms)
AfterDelayFromFirstElementnewWith in class AfterDelayFromFirstElement<W extends BoundedWindow>public Instant getWatermarkThatGuaranteesFiring(W window)
TriggerFor triggers that do not fire based on the watermark advancing, returns
BoundedWindow.TIMESTAMP_MAX_VALUE.
This estimate is used to determine that there are no elements in a side-input window, which causes the default value to be used instead.
getWatermarkThatGuaranteesFiring in class AfterDelayFromFirstElement<W extends BoundedWindow>protected Trigger<W> getContinuationTrigger(List<Trigger<W>> continuationTriggers)
TriggerTrigger.getContinuationTrigger() of this Trigger. For convenience, this
is provided the continuation trigger of each of the sub-triggers.getContinuationTrigger in class Trigger<W extends BoundedWindow>public String toString()
toString in class Trigger<W extends BoundedWindow>public boolean equals(Object obj)
equals in class Trigger<W extends BoundedWindow>public int hashCode()
hashCode in class Trigger<W extends BoundedWindow>