public static class CalendarWindows.DaysWindows extends PartitioningWindowFn<Object,IntervalWindow>
WindowFn that windows elements into periods measured by days.
By default, periods of multiple days are measured starting at the
epoch. This can be overridden with withStartingDay(int, int, int).
The time zone used to determine calendar boundaries is UTC, unless this
is overridden with the withTimeZone(org.joda.time.DateTimeZone) method.
WindowFn.AssignContext, WindowFn.MergeContext| Modifier and Type | Method and Description |
|---|---|
IntervalWindow |
assignWindow(Instant timestamp)
Returns the single window to which elements with this timestamp belong.
|
int |
getNumber() |
DateTime |
getStartDate() |
DateTimeZone |
getTimeZone() |
boolean |
isCompatible(WindowFn<?,?> other)
Returns whether this performs the same merging as the given
WindowFn. |
Coder<IntervalWindow> |
windowCoder()
Returns the
Coder used for serializing the windows used
by this windowFn. |
CalendarWindows.DaysWindows |
withStartingDay(int year,
int month,
int day) |
CalendarWindows.DaysWindows |
withTimeZone(DateTimeZone timeZone) |
assignsToSingleWindow, assignWindows, getOutputTime, getSideInputWindowisNonMerging, mergeWindowsgetOutputTimeFnpublic CalendarWindows.DaysWindows withStartingDay(int year, int month, int day)
public CalendarWindows.DaysWindows withTimeZone(DateTimeZone timeZone)
public IntervalWindow assignWindow(Instant timestamp)
PartitioningWindowFnassignWindow in class PartitioningWindowFn<Object,IntervalWindow>public Coder<IntervalWindow> windowCoder()
WindowFnCoder used for serializing the windows used
by this windowFn.windowCoder in class WindowFn<Object,IntervalWindow>public boolean isCompatible(WindowFn<?,?> other)
WindowFnWindowFn.isCompatible in class WindowFn<Object,IntervalWindow>public int getNumber()
public DateTime getStartDate()
public DateTimeZone getTimeZone()