public static class CalendarWindows.YearsWindows extends PartitioningWindowFn<Object,IntervalWindow>
WindowFn that windows elements into periods measured by years.
By default, periods of multiple years are measured starting at the
epoch. This can be overridden with withStartingYear(int).
Years start on the first day of each calendar year, unless overridden by
beginningOnDay(int, int).
The time zone used to determine calendar boundaries is UTC, unless this
is overridden with the withTimeZone(org.joda.time.DateTimeZone) method.
WindowFn.AssignContext, WindowFn.MergeContext| Modifier and Type | Method and Description |
|---|---|
IntervalWindow |
assignWindow(Instant timestamp)
Returns the single window to which elements with this timestamp belong.
|
CalendarWindows.YearsWindows |
beginningOnDay(int monthOfYear,
int dayOfMonth) |
int |
getDayOfMonth() |
int |
getMonthOfYear() |
int |
getNumber() |
DateTime |
getStartDate() |
DateTimeZone |
getTimeZone() |
boolean |
isCompatible(WindowFn<?,?> other)
Returns whether this performs the same merging as the given
WindowFn. |
Coder<IntervalWindow> |
windowCoder()
Returns the
Coder used for serializing the windows used
by this windowFn. |
CalendarWindows.YearsWindows |
withStartingYear(int year) |
CalendarWindows.YearsWindows |
withTimeZone(DateTimeZone timeZone) |
assignsToSingleWindow, assignWindows, getOutputTime, getSideInputWindowisNonMerging, mergeWindowsgetOutputTimeFnpublic CalendarWindows.YearsWindows beginningOnDay(int monthOfYear, int dayOfMonth)
public CalendarWindows.YearsWindows withStartingYear(int year)
public CalendarWindows.YearsWindows withTimeZone(DateTimeZone timeZone)
public IntervalWindow assignWindow(Instant timestamp)
PartitioningWindowFnassignWindow in class PartitioningWindowFn<Object,IntervalWindow>public Coder<IntervalWindow> windowCoder()
WindowFnCoder used for serializing the windows used
by this windowFn.windowCoder in class WindowFn<Object,IntervalWindow>public boolean isCompatible(WindowFn<?,?> other)
WindowFnWindowFn.isCompatible in class WindowFn<Object,IntervalWindow>public DateTimeZone getTimeZone()
public DateTime getStartDate()
public int getDayOfMonth()
public int getMonthOfYear()
public int getNumber()