public static class GlobalWindow.Coder extends AtomicCoder<GlobalWindow>
Coder for encoding and decoding Windows.Coder.Context, Coder.NonDeterministicException| Modifier and Type | Field and Description |
|---|---|
static GlobalWindow.Coder |
INSTANCE |
| Modifier and Type | Method and Description |
|---|---|
GlobalWindow |
decode(java.io.InputStream inStream,
Coder.Context context)
Decodes a value of type
T from the given input stream in
the given context. |
void |
encode(GlobalWindow window,
java.io.OutputStream outStream,
Coder.Context context)
Encodes the given value of type
T onto the given output stream
in the given context. |
boolean |
isDeterministic()
Returns true if the coding is deterministic.
|
getCoderArguments, getInstanceComponentsasCloudObject, equals, getComponents, getEncodedElementByteSize, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, toString, verifyDeterministic, verifyDeterministic, verifyDeterministicpublic static final GlobalWindow.Coder INSTANCE
public void encode(GlobalWindow window, java.io.OutputStream outStream, Coder.Context context)
CoderT onto the given output stream
in the given context.public GlobalWindow decode(java.io.InputStream inStream, Coder.Context context)
CoderT from the given input stream in
the given context. Returns the decoded value.public boolean isDeterministic()
Coder In order for a Coder to be considered deterministic,
the following must be true:
Object.equals()
or Comparable.compareTo(), if supported), have the same
encoding.
Coder always produces a canonical encoding, which is the
same for an instance of an object even if produced on different
computers at different times.