W - window typepublic class InvalidWindows<W extends BoundedWindow> extends WindowFn<Object,W>
WindowFn that represents an invalid pipeline state.WindowFn.AssignContext, WindowFn.MergeContext| Constructor and Description |
|---|
InvalidWindows(String cause,
WindowFn<?,W> originalWindowFn) |
| Modifier and Type | Method and Description |
|---|---|
Collection<W> |
assignWindows(WindowFn.AssignContext c)
Given a timestamp and element, returns the set of windows into which it
should be placed.
|
String |
getCause()
Returns the reason that this
WindowFn is invalid. |
WindowFn<?,W> |
getOriginalWindowFn()
Returns the original windowFn that this InvalidWindows replaced.
|
Instant |
getOutputTime(Instant inputTimestamp,
W window) |
W |
getSideInputWindow(BoundedWindow window)
Returns the window of the side input corresponding to the given window of
the main input.
|
boolean |
isCompatible(WindowFn<?,?> other)
InvalidWindows objects with the same originalWindowFn are compatible. |
void |
mergeWindows(WindowFn.MergeContext c)
Does whatever merging of windows is necessary.
|
Coder<W> |
windowCoder()
Returns the
Coder used for serializing the windows used
by this windowFn. |
assignsToSingleWindow, getOutputTimeFn, isNonMergingpublic String getCause()
WindowFn is invalid.public WindowFn<?,W> getOriginalWindowFn()
public Collection<W> assignWindows(WindowFn.AssignContext c)
WindowFnassignWindows in class WindowFn<Object,W extends BoundedWindow>public void mergeWindows(WindowFn.MergeContext c)
WindowFnSee MergeOverlappingIntervalWindows.mergeWindows(com.google.cloud.dataflow.sdk.transforms.windowing.WindowFn<?, com.google.cloud.dataflow.sdk.transforms.windowing.IntervalWindow>.MergeContext) for an
example of how to override this method.
mergeWindows in class WindowFn<Object,W extends BoundedWindow>public Coder<W> windowCoder()
WindowFnCoder used for serializing the windows used
by this windowFn.windowCoder in class WindowFn<Object,W extends BoundedWindow>public boolean isCompatible(WindowFn<?,?> other)
InvalidWindows objects with the same originalWindowFn are compatible.isCompatible in class WindowFn<Object,W extends BoundedWindow>public W getSideInputWindow(BoundedWindow window)
WindowFnAuthors of custom WindowFns should override this.
getSideInputWindow in class WindowFn<Object,W extends BoundedWindow>public Instant getOutputTime(Instant inputTimestamp, W window)
getOutputTime in class WindowFn<Object,W extends BoundedWindow>