public static interface Trigger.TriggerInfo<W extends BoundedWindow>
| Modifier and Type | Method and Description |
|---|---|
boolean |
areAllSubtriggersFinished()
Returns true if all the sub-triggers of the current trigger are marked finished.
|
com.google.cloud.dataflow.sdk.util.ExecutableTrigger<W> |
firstUnfinishedSubTrigger()
Returns the first unfinished sub-trigger.
|
boolean |
isFinished()
Returns true if the current trigger is marked finished.
|
boolean |
isFinished(int subtriggerIndex)
Return true if the given subtrigger is marked finished.
|
boolean |
isMerging()
Returns true if the windowing strategy of the current
PCollection is a merging
WindowFn. |
void |
resetTree()
Clears all keyed state for triggers in the current sub-tree and unsets all the associated
finished bits.
|
void |
setFinished(boolean finished)
Sets the finished bit for the current trigger.
|
void |
setFinished(boolean finished,
int subTriggerIndex)
Sets the finished bit for the given sub-trigger.
|
com.google.cloud.dataflow.sdk.util.ExecutableTrigger<W> |
subTrigger(int subtriggerIndex)
Access the executable version of the specified sub-trigger.
|
Iterable<com.google.cloud.dataflow.sdk.util.ExecutableTrigger<W>> |
subTriggers()
Access the executable versions of the sub-triggers of the current trigger.
|
Iterable<com.google.cloud.dataflow.sdk.util.ExecutableTrigger<W>> |
unfinishedSubTriggers()
Returns an iterable over the unfinished sub-triggers of the current trigger.
|
boolean isMerging()
PCollection is a merging
WindowFn. If true, the trigger execution needs to keep enough information to support the
possibility of Trigger.onMerge(com.google.cloud.dataflow.sdk.transforms.windowing.Trigger<W>.OnMergeContext) being called. If false, Trigger.onMerge(com.google.cloud.dataflow.sdk.transforms.windowing.Trigger<W>.OnMergeContext) will
never be called.Iterable<com.google.cloud.dataflow.sdk.util.ExecutableTrigger<W>> subTriggers()
com.google.cloud.dataflow.sdk.util.ExecutableTrigger<W> subTrigger(int subtriggerIndex)
boolean isFinished()
boolean isFinished(int subtriggerIndex)
boolean areAllSubtriggersFinished()
Iterable<com.google.cloud.dataflow.sdk.util.ExecutableTrigger<W>> unfinishedSubTriggers()
com.google.cloud.dataflow.sdk.util.ExecutableTrigger<W> firstUnfinishedSubTrigger()
void resetTree()
throws Exception
Exceptionvoid setFinished(boolean finished)
void setFinished(boolean finished,
int subTriggerIndex)