public static enum Trigger.TriggerResult extends Enum<Trigger.TriggerResult>
TriggerResult enumerates the possible result a trigger can have when it is executed.| Enum Constant and Description |
|---|
CONTINUE |
FIRE |
FIRE_AND_FINISH |
| Modifier and Type | Method and Description |
|---|---|
boolean |
isFinish() |
boolean |
isFire() |
static Trigger.TriggerResult |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Trigger.TriggerResult[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Trigger.TriggerResult FIRE
public static final Trigger.TriggerResult CONTINUE
public static final Trigger.TriggerResult FIRE_AND_FINISH
public static Trigger.TriggerResult[] values()
for (Trigger.TriggerResult c : Trigger.TriggerResult.values()) System.out.println(c);
public static Trigger.TriggerResult valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic boolean isFire()
public boolean isFinish()