T - Type of elements being windowedW - Window type@SystemDoFnInternal public class AssignWindowsDoFn<T,W extends BoundedWindow> extends DoFn<T,T>
DoFn.Context, DoFn.ProcessContext, DoFn.RequiresWindowAccess| Constructor and Description |
|---|
AssignWindowsDoFn(WindowFn<? super T,W> fn) |
| Modifier and Type | Method and Description |
|---|---|
void |
processElement(DoFn.ProcessContext c)
Processes one input element.
|
createAggregator, createAggregator, finishBundle, getAllowedTimestampSkew, getInputTypeDescriptor, getOutputTypeDescriptor, startBundlepublic void processElement(DoFn.ProcessContext c) throws Exception
DoFn The current element of the input PCollection is returned by
c.element(). It should be considered immutable. The Dataflow
runtime will not mutate the element, so it is safe to cache, etc. The element should not be
mutated by any of the DoFn methods, because it may be cached elsewhere, retained by the
Dataflow runtime, or used in other unspecified ways.
A value is added to the main output PCollection by DoFn.Context.output(OutputT).
Once passed to output the element should be considered immutable and not be modified in
any way. It may be cached elsewhere, retained by the Dataflow runtime, or used in other
unspecified ways.
processElement in class DoFn<T,T>ExceptionDoFn.ProcessContext