public class BatchModeExecutionContext extends BaseExecutionContext
ExecutionContext for use in batch mode.| Constructor and Description |
|---|
BatchModeExecutionContext()
Creates a
BatchModeExecutionContext. |
| Modifier and Type | Method and Description |
|---|---|
ExecutionContext.StepContext |
createStepContext(String stepName,
String transformName)
Create a new
ExecutionContext.StepContext. |
Object |
getKey()
Returns the key of the work currently being processed.
|
void |
setKey(Object key)
Sets the key of the work currently being processed.
|
protected void |
switchStateKey(Object newKey) |
getAllStepContexts, getStepContext, noteOutput, noteSideOutputpublic BatchModeExecutionContext()
BatchModeExecutionContext.public ExecutionContext.StepContext createStepContext(String stepName, String transformName)
ExecutionContext.StepContext.createStepContext in class BaseExecutionContextpublic void setKey(Object key)
protected void switchStateKey(Object newKey)
newKey - the key being switched topublic Object getKey()
If there is not a currently defined key, returns null.