public class DirectModeExecutionContext extends BatchModeExecutionContext
ExecutionContext for use in direct mode.| Modifier | Constructor and Description |
|---|---|
protected |
DirectModeExecutionContext() |
| Modifier and Type | Method and Description |
|---|---|
static DirectModeExecutionContext |
create() |
ExecutionContext.StepContext |
createStepContext(String stepName,
String transformName)
Create a new
ExecutionContext.StepContext. |
<T> List<DirectPipelineRunner.ValueWithMetadata<T>> |
getOutput(TupleTag<T> tag) |
<T> List<DirectPipelineRunner.ValueWithMetadata<T>> |
getSideOutput(TupleTag<T> tag) |
void |
noteOutput(WindowedValue<?> outputElem)
Hook for subclasses to implement that will be called whenever
DoFn.Context.output(OutputT)
is called. |
void |
noteSideOutput(TupleTag<?> tag,
WindowedValue<?> outputElem)
Hook for subclasses to implement that will be called whenever
DoFn.Context.sideOutput(com.google.cloud.dataflow.sdk.values.TupleTag<T>, T)
is called. |
protected void |
switchStateKey(Object newKey) |
getKey, setKeygetAllStepContexts, getStepContextpublic static DirectModeExecutionContext create()
public ExecutionContext.StepContext createStepContext(String stepName, String transformName)
BatchModeExecutionContextExecutionContext.StepContext.createStepContext in class BatchModeExecutionContextprotected void switchStateKey(Object newKey)
switchStateKey in class BatchModeExecutionContextnewKey - the key being switched topublic void noteOutput(WindowedValue<?> outputElem)
BaseExecutionContextDoFn.Context.output(OutputT)
is called.noteOutput in interface ExecutionContextnoteOutput in class BaseExecutionContextpublic void noteSideOutput(TupleTag<?> tag, WindowedValue<?> outputElem)
BaseExecutionContextDoFn.Context.sideOutput(com.google.cloud.dataflow.sdk.values.TupleTag<T>, T)
is called.noteSideOutput in interface ExecutionContextnoteSideOutput in class BaseExecutionContextpublic <T> List<DirectPipelineRunner.ValueWithMetadata<T>> getOutput(TupleTag<T> tag)
public <T> List<DirectPipelineRunner.ValueWithMetadata<T>> getSideOutput(TupleTag<T> tag)