public class DirectSideInputReader extends Object implements SideInputReader
PTuple of side input iterables. Encapsulates
conversion according to the PCollectionView and projection to a particular
window.| Modifier and Type | Method and Description |
|---|---|
<T> boolean |
contains(PCollectionView<T> view)
Returns true if the given
PCollectionView is valid for this reader. |
<T> T |
get(PCollectionView<T> view,
BoundedWindow window)
Returns the value of the given
PCollectionView for the given BoundedWindow. |
boolean |
isEmpty()
Returns true if there are no side inputs in this reader.
|
static DirectSideInputReader |
of(PTuple sideInputValues) |
public static DirectSideInputReader of(PTuple sideInputValues)
public <T> boolean contains(PCollectionView<T> view)
SideInputReaderPCollectionView is valid for this reader.contains in interface SideInputReaderpublic boolean isEmpty()
SideInputReaderisEmpty in interface SideInputReaderpublic <T> T get(PCollectionView<T> view, BoundedWindow window)
SideInputReaderPCollectionView for the given BoundedWindow.
It is valid for a side input to be null. It is not valid for this to
return null for any other reason.
get in interface SideInputReader