public interface ExecutionContext
| Modifier and Type | Interface and Description |
|---|---|
static interface |
ExecutionContext.StepContext
Per-step, per-key context used for retrieving state.
|
| Modifier and Type | Method and Description |
|---|---|
Collection<ExecutionContext.StepContext> |
getAllStepContexts()
Returns a collection view of all of the
ExecutionContext.StepContexts. |
ExecutionContext.StepContext |
getStepContext(String stepName,
String transformName)
Returns the
ExecutionContext.StepContext associated with the given step. |
void |
noteOutput(WindowedValue<?> output)
Hook for subclasses to implement that will be called whenever
DoFn.Context.output(OutputT)
is called. |
void |
noteSideOutput(TupleTag<?> tag,
WindowedValue<?> output)
Hook for subclasses to implement that will be called whenever
DoFn.Context.sideOutput(com.google.cloud.dataflow.sdk.values.TupleTag<T>, T)
is called. |
ExecutionContext.StepContext getStepContext(String stepName, String transformName)
ExecutionContext.StepContext associated with the given step.Collection<ExecutionContext.StepContext> getAllStepContexts()
ExecutionContext.StepContexts.void noteOutput(WindowedValue<?> output)
DoFn.Context.output(OutputT)
is called.void noteSideOutput(TupleTag<?> tag, WindowedValue<?> output)
DoFn.Context.sideOutput(com.google.cloud.dataflow.sdk.values.TupleTag<T>, T)
is called.