public static interface ExecutionContext.StepContext
| Modifier and Type | Method and Description |
|---|---|
ExecutionContext |
getExecutionContext()
The context in which this step is executing.
|
String |
getStepName()
The name of the step.
|
String |
getTransformName()
The name of the transform for the step.
|
void |
noteOutput(WindowedValue<?> output)
Hook for subclasses to implement that will be called whenever
DoFn.Context.output(OutputT)
is called. |
void |
noteSideOutput(TupleTag<?> tag,
WindowedValue<?> output)
Hook for subclasses to implement that will be called whenever
DoFn.Context.sideOutput(com.google.cloud.dataflow.sdk.values.TupleTag<T>, T)
is called. |
StateInternals |
stateInternals() |
TimerInternals |
timerInternals() |
<T,W extends BoundedWindow> |
writePCollectionViewData(TupleTag<?> tag,
Iterable<WindowedValue<T>> data,
Coder<Iterable<WindowedValue<T>>> dataCoder,
W window,
Coder<W> windowCoder)
Writes the given
PCollectionView data to a globally accessible location. |
String getStepName()
String getTransformName()
ExecutionContext getExecutionContext()
void noteOutput(WindowedValue<?> output)
DoFn.Context.output(OutputT)
is called.void noteSideOutput(TupleTag<?> tag, WindowedValue<?> output)
DoFn.Context.sideOutput(com.google.cloud.dataflow.sdk.values.TupleTag<T>, T)
is called.<T,W extends BoundedWindow> void writePCollectionViewData(TupleTag<?> tag, Iterable<WindowedValue<T>> data, Coder<Iterable<WindowedValue<T>>> dataCoder, W window, Coder<W> windowCoder) throws IOException
PCollectionView data to a globally accessible location.IOExceptionStateInternals stateInternals()
TimerInternals timerInternals()