K - key typeInputT - input value element typeOutputT - output value element typeW - window type@SystemDoFnInternal public abstract class GroupAlsoByWindowsDoFn<K,InputT,OutputT,W extends BoundedWindow> extends DoFn<KV<K,Iterable<WindowedValue<InputT>>>,KV<K,OutputT>>
DoFn.Context, DoFn.ProcessContext, DoFn.RequiresWindowAccess| Constructor and Description |
|---|
GroupAlsoByWindowsDoFn() |
| Modifier and Type | Method and Description |
|---|---|
static <K,InputT,AccumT,OutputT,W extends BoundedWindow> |
create(WindowingStrategy<?,W> windowingStrategy,
AppliedCombineFn<K,InputT,AccumT,OutputT> combineFn,
Coder<K> keyCoder)
Construct a
GroupAlsoByWindowsDoFn using the combineFn if available. |
static <K,V,W extends BoundedWindow> |
createForIterable(WindowingStrategy<?,W> windowingStrategy,
Coder<V> inputCoder)
Create a
GroupAlsoByWindowsDoFn without a combine function. |
createAggregator, createAggregator, finishBundle, getAllowedTimestampSkew, getInputTypeDescriptor, getOutputTypeDescriptor, processElement, startBundlepublic static <K,V,W extends BoundedWindow> GroupAlsoByWindowsDoFn<K,V,Iterable<V>,W> createForIterable(WindowingStrategy<?,W> windowingStrategy, Coder<V> inputCoder)
GroupAlsoByWindowsDoFn without a combine function. Depending on the
windowFn this will either use iterators or window sets to implement the grouping.windowingStrategy - The window function and trigger to use for groupinginputCoder - the input coder to usepublic static <K,InputT,AccumT,OutputT,W extends BoundedWindow> GroupAlsoByWindowsDoFn<K,InputT,OutputT,W> create(WindowingStrategy<?,W> windowingStrategy, AppliedCombineFn<K,InputT,AccumT,OutputT> combineFn, Coder<K> keyCoder)
GroupAlsoByWindowsDoFn using the combineFn if available.