public interface MutationDetector extends AutoCloseable
The AutoCloseable aspect of this interface allows use in a try-with-resources
style, where the implementing class may choose to perform a final mutation check upon
AutoCloseable.close().
| Modifier and Type | Method and Description |
|---|---|
void |
verifyUnmodified() |
closevoid verifyUnmodified()
IllegalMutationException - if illegal mutations are detected.