public class NullSideInputReader extends Object implements SideInputReader
SideInputReader representing a well-defined set of views, but not storing
any values for them. Used to check if a side input is present when the data itself
comes from elsewhere.| Modifier and Type | Method and Description |
|---|---|
<T> boolean |
contains(PCollectionView<T> view)
Returns true if the given
PCollectionView is valid for this reader. |
static NullSideInputReader |
empty() |
<T> T |
get(PCollectionView<T> view,
BoundedWindow window)
Returns the value of the given
PCollectionView for the given BoundedWindow. |
boolean |
isEmpty()
Returns true if there are no side inputs in this reader.
|
static NullSideInputReader |
of(Iterable<? extends PCollectionView<?>> views) |
public static NullSideInputReader empty()
public static NullSideInputReader of(Iterable<? extends PCollectionView<?>> views)
public <T> T get(PCollectionView<T> view, BoundedWindow window)
SideInputReaderPCollectionView for the given BoundedWindow.
It is valid for a side input to be null. It is not valid for this to
return null for any other reason.
get in interface SideInputReaderpublic boolean isEmpty()
SideInputReaderisEmpty in interface SideInputReaderpublic <T> boolean contains(PCollectionView<T> view)
SideInputReaderPCollectionView is valid for this reader.contains in interface SideInputReader