public class PackageUtil extends Object
| Modifier and Type | Field and Description |
|---|---|
static int |
SANE_CLASSPATH_SIZE
A reasonable upper bound on the number of jars required to launch a Dataflow job.
|
| Constructor and Description |
|---|
PackageUtil() |
| Modifier and Type | Method and Description |
|---|---|
static com.google.api.services.dataflow.model.DataflowPackage |
createPackage(File classpathElement,
String stagingPath,
String overridePackageName)
Creates a DataflowPackage containing information about how a classpath element should be
staged.
|
static List<com.google.api.services.dataflow.model.DataflowPackage> |
stageClasspathElements(Collection<String> classpathElements,
String stagingPath)
Transfers the classpath elements to the staging location.
|
public static final int SANE_CLASSPATH_SIZE
public static com.google.api.services.dataflow.model.DataflowPackage createPackage(File classpathElement, String stagingPath, String overridePackageName)
classpathElement - The local path for the classpath element.stagingPath - The base location in for staged classpath elements.overridePackageName - If non-null, use the given value as the package name
instead of generating one automatically.public static List<com.google.api.services.dataflow.model.DataflowPackage> stageClasspathElements(Collection<String> classpathElements, String stagingPath)
classpathElements - The elements to stage.stagingPath - The base location to stage the elements to.