public static interface ReduceFn.MergingStateContext extends ReduceFn.StateContext
ReduceFn.onMerge(com.google.cloud.dataflow.sdk.util.ReduceFn<K, InputT, OutputT, W>.OnMergeContext).| Modifier and Type | Method and Description |
|---|---|
<StateT extends MergeableState<?,?>> |
accessAcrossMergingWindows(StateTag<StateT> address)
Access a merged view of the storage for the given
address
in all of the windows being merged. |
<StateT extends State> |
accessInEachMergingWindow(StateTag<StateT> address)
Access a map from windows being merged to the associated
StateT. |
access, accessAcrossMergedWindows<StateT extends MergeableState<?,?>> StateT accessAcrossMergingWindows(StateTag<StateT> address)
address
in all of the windows being merged.<StateT extends State> Map<BoundedWindow,StateT> accessInEachMergingWindow(StateTag<StateT> address)
StateT.