public interface SideInputReader
| Modifier and Type | Method and Description |
|---|---|
<T> boolean |
contains(PCollectionView<T> view)
Returns true if the given
PCollectionView is valid for this reader. |
<T> T |
get(PCollectionView<T> view,
BoundedWindow window)
Returns the value of the given
PCollectionView for the given BoundedWindow. |
boolean |
isEmpty()
Returns true if there are no side inputs in this reader.
|
@Nullable <T> T get(PCollectionView<T> view, BoundedWindow window)
PCollectionView for the given BoundedWindow.
It is valid for a side input to be null. It is not valid for this to
return null for any other reason.
<T> boolean contains(PCollectionView<T> view)
PCollectionView is valid for this reader.boolean isEmpty()