public interface SizedSideInputReader extends SideInputReader
SideInputReader that can approximate the size of the side input.| Modifier and Type | Interface and Description |
|---|---|
static class |
SizedSideInputReader.Defaults
Abstract class providing default implementations for methods of
SizedSideInputReader. |
| Modifier and Type | Method and Description |
|---|---|
<T> Sized<T> |
getSized(PCollectionView<T> view,
BoundedWindow window)
Returns the value of the requested
PCollectionView for the given BoundedWindow
along with a rough estimate of the number of bytes of memory it consumes. |
contains, get, isEmpty<T> Sized<T> getSized(PCollectionView<T> view, BoundedWindow window)
PCollectionView for the given BoundedWindow
along with a rough estimate of the number of bytes of memory it consumes.
It is valid for a side input value to be null. In this case, the return
value of this method must still be non-null. It should be a Sized
object where Sized.getValue() returns null and Sized.getSize() may
still return any non-negative value.