public static enum StateFetcher.SideInputState extends Enum<StateFetcher.SideInputState>
| Enum Constant and Description |
|---|
CACHED_IN_WORKITEM |
KNOWN_READY |
UNKNOWN |
| Modifier and Type | Method and Description |
|---|---|
static StateFetcher.SideInputState |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static StateFetcher.SideInputState[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final StateFetcher.SideInputState CACHED_IN_WORKITEM
public static final StateFetcher.SideInputState KNOWN_READY
public static final StateFetcher.SideInputState UNKNOWN
public static StateFetcher.SideInputState[] values()
for (StateFetcher.SideInputState c : StateFetcher.SideInputState.values()) System.out.println(c);
public static StateFetcher.SideInputState valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is null