public static class StreamingModeExecutionContext.StreamingModeSideInputReader extends Object implements SideInputReader
SideInputReader that fetches side inputs from the streaming worker's
cache.| Modifier and Type | Method and Description |
|---|---|
<T> boolean |
contains(PCollectionView<T> view)
Returns true if the given
PCollectionView is valid for this reader. |
<T> T |
get(PCollectionView<T> view,
BoundedWindow window)
Returns the value of the given
PCollectionView for the given BoundedWindow. |
boolean |
isEmpty()
Returns true if there are no side inputs in this reader.
|
static StreamingModeExecutionContext.StreamingModeSideInputReader |
of(Iterable<? extends PCollectionView<?>> views,
StreamingModeExecutionContext context) |
public static StreamingModeExecutionContext.StreamingModeSideInputReader of(Iterable<? extends PCollectionView<?>> views, StreamingModeExecutionContext context)
public <T> T get(PCollectionView<T> view, BoundedWindow window)
SideInputReaderPCollectionView for the given BoundedWindow.
It is valid for a side input to be null. It is not valid for this to
return null for any other reason.
get in interface SideInputReaderpublic <T> boolean contains(PCollectionView<T> view)
SideInputReaderPCollectionView is valid for this reader.contains in interface SideInputReaderpublic boolean isEmpty()
SideInputReaderisEmpty in interface SideInputReader