T - element typepublic class StreamingPCollectionViewWriterFn<T> extends DoFn<Iterable<T>,T> implements DoFn.RequiresWindowAccess
DoFn.Context, DoFn.ProcessContext, DoFn.RequiresWindowAccess| Modifier and Type | Method and Description |
|---|---|
static <T> StreamingPCollectionViewWriterFn<T> |
create(PCollectionView<?> view,
Coder<T> dataCoder) |
void |
processElement(DoFn.ProcessContext c)
Processes one input element.
|
createAggregator, createAggregator, finishBundle, getAllowedTimestampSkew, getInputTypeDescriptor, getOutputTypeDescriptor, startBundlepublic static <T> StreamingPCollectionViewWriterFn<T> create(PCollectionView<?> view, Coder<T> dataCoder)
public void processElement(DoFn.ProcessContext c) throws Exception
DoFn The current element of the input PCollection is returned by
c.element(). It should be considered immutable. The Dataflow
runtime will not mutate the element, so it is safe to cache, etc. The element should not be
mutated by any of the DoFn methods, because it may be cached elsewhere, retained by the
Dataflow runtime, or used in other unspecified ways.
A value is added to the main output PCollection by DoFn.Context.output(OutputT).
Once passed to output the element should be considered immutable and not be modified in
any way. It may be cached elsewhere, retained by the Dataflow runtime, or used in other
unspecified ways.
processElement in class DoFn<Iterable<T>,T>ExceptionDoFn.ProcessContext