@Documented @Retention(value=RUNTIME) @Target(value=TYPE) public @interface SystemDoFnInternal
DoFns as an internal component of the Dataflow SDK.
Currently, the only effect of this is to mark any aggregators reported by an annotated
DoFn as a system counter (as opposed to a user counter).
This is internal to the Dataflow SDK.