public enum TimeDomain extends Enum<TimeDomain>
TimeDomain specifies whether an operation is based on
timestamps of elements or current "real-world" time as reported while processing.| Enum Constant and Description |
|---|
EVENT_TIME
The
EVENT_TIME domain corresponds to the timestamps on the elemnts. |
PROCESSING_TIME
The
PROCESSING_TIME domain corresponds to the current to the current (system) time. |
SYNCHRONIZED_PROCESSING_TIME
Same as the
PROCESSING_TIME domain, except it won't fire a timer set for time
T until all timers from earlier stages set for a time earlier than T have
fired. |
| Modifier and Type | Method and Description |
|---|---|
static TimeDomain |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static TimeDomain[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final TimeDomain EVENT_TIME
EVENT_TIME domain corresponds to the timestamps on the elemnts. Time advances
on the system watermark advances.public static final TimeDomain PROCESSING_TIME
PROCESSING_TIME domain corresponds to the current to the current (system) time.
This is advanced during execution of the Dataflow pipeline.public static final TimeDomain SYNCHRONIZED_PROCESSING_TIME
PROCESSING_TIME domain, except it won't fire a timer set for time
T until all timers from earlier stages set for a time earlier than T have
fired.public static TimeDomain[] values()
for (TimeDomain c : TimeDomain.values()) System.out.println(c);
public static TimeDomain valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is null