public interface TimerInternals
This class allows setting and deleting timers, and also retrieving an estimate of the current time.
| Modifier and Type | Interface and Description |
|---|---|
static class |
TimerInternals.TimerData
Data about a timer as represented within
TimerInternals. |
| Modifier and Type | Method and Description |
|---|---|
org.joda.time.Instant |
currentProcessingTime()
Returns the current timestamp in the
TimeDomain.PROCESSING_TIME time domain. |
org.joda.time.Instant |
currentWatermarkTime()
Returns an estimate of the current timestamp in the
TimeDomain.EVENT_TIME time domain. |
void |
deleteTimer(TimerInternals.TimerData timerKey)
Deletes the given timer.
|
void |
setTimer(TimerInternals.TimerData timerKey)
Writes out a timer to be fired when the watermark reaches the given
timestamp.
|
void setTimer(TimerInternals.TimerData timerKey)
The combination of namespace, timestamp and domain uniquely
identify a timer. Multiple timers set for the same parameters can be safely deduplicated.
void deleteTimer(TimerInternals.TimerData timerKey)
org.joda.time.Instant currentProcessingTime()
TimeDomain.PROCESSING_TIME time domain.org.joda.time.Instant currentWatermarkTime()
TimeDomain.EVENT_TIME time domain.