ElemT - the element typepublic class TimerOrElement<ElemT> extends Object
StreamingGroupAlsoByWindowsDoFn.| Modifier and Type | Class and Description |
|---|---|
static class |
TimerOrElement.TimerOrElementCoder<T>
Coder that forwards
ByteSizeObserver calls to an underlying element coder. |
| Modifier and Type | Method and Description |
|---|---|
ElemT |
element()
If this is an element, returns it, otherwise throws an exception.
|
static <ElemT> TimerOrElement<ElemT> |
element(ElemT element)
Creates a new
TimerOrElement<ElemT> representing an element. |
boolean |
equals(Object other) |
TimerInternals.TimerData |
getTimer()
If this is a timer, returns the associated
TimerInternals.TimerData. |
int |
hashCode() |
boolean |
isTimer()
Returns whether this is a timer or an element.
|
Object |
key()
If this is a timer, returns its key, otherwise throws an exception.
|
static <ElemT> TimerOrElement<ElemT> |
timer(Object key,
TimerInternals.TimerData timerData)
Creates a new
TimerOrElement<ElemT> representing a timer. |
public static <ElemT> TimerOrElement<ElemT> timer(Object key, TimerInternals.TimerData timerData)
TimerOrElement<ElemT> representing a timer.ElemT - the element typepublic static <ElemT> TimerOrElement<ElemT> element(ElemT element)
TimerOrElement<ElemT> representing an element.ElemT - the element typepublic boolean isTimer()
public TimerInternals.TimerData getTimer()
TimerInternals.TimerData. Otherwise, throws an exception.public Object key()
public ElemT element()