public static class TriggerRunner.Result extends Object
This includes the actual Trigger.TriggerResult as well as an updated set of finished bits.
The bits should typically be committed, but if the trigger fired we want to merge and apply
the merging logic on the old finished bits, hence the need to delay committing these results.
| Modifier and Type | Method and Description |
|---|---|
boolean |
isFinish() |
boolean |
isFire() |
void |
persistFinishedSet(ReduceFn.StateContext state) |
public boolean isFire()
public boolean isFinish()
public void persistFinishedSet(ReduceFn.StateContext state)