T - type of elements being windowedW - BoundedWindow subclass used to represent the
windows used by this WindowingStrategypublic class WindowingStrategy<T,W extends BoundedWindow> extends Object implements Serializable
WindowingStrategy describes the windowing behavior for a specific collection of values.
It has both a WindowFn describing how elements are assigned to windows and a
Trigger that controls when output is produced for each window.| Modifier and Type | Class and Description |
|---|---|
static class |
WindowingStrategy.AccumulationMode
The accumulation modes that can be used with windowing.
|
| Modifier and Type | Method and Description |
|---|---|
org.joda.time.Duration |
getAllowedLateness() |
Window.ClosingBehavior |
getClosingBehavior() |
WindowingStrategy.AccumulationMode |
getMode() |
ExecutableTrigger<W> |
getTrigger() |
WindowFn<T,W> |
getWindowFn() |
static WindowingStrategy<Object,GlobalWindow> |
globalDefault()
Return a fully specified, default windowing strategy.
|
boolean |
isAllowedLatenessSpecified() |
boolean |
isModeSpecified() |
boolean |
isTriggerSpecified() |
static <T,W extends BoundedWindow> |
of(WindowFn<T,W> windowFn) |
String |
toString() |
WindowingStrategy<T,W> |
withAllowedLateness(org.joda.time.Duration allowedLateness)
|
WindowingStrategy<T,W> |
withClosingBehavior(Window.ClosingBehavior closingBehavior) |
WindowingStrategy<T,W> |
withMode(WindowingStrategy.AccumulationMode mode)
|
WindowingStrategy<T,W> |
withTrigger(Trigger<?> wildcardTrigger)
|
WindowingStrategy<T,W> |
withWindowFn(WindowFn<?,?> wildcardWindowFn)
|
public static WindowingStrategy<Object,GlobalWindow> globalDefault()
public static <T,W extends BoundedWindow> WindowingStrategy<T,W> of(WindowFn<T,W> windowFn)
public ExecutableTrigger<W> getTrigger()
public boolean isTriggerSpecified()
public org.joda.time.Duration getAllowedLateness()
public boolean isAllowedLatenessSpecified()
public WindowingStrategy.AccumulationMode getMode()
public boolean isModeSpecified()
public Window.ClosingBehavior getClosingBehavior()
public WindowingStrategy<T,W> withTrigger(Trigger<?> wildcardTrigger)
public WindowingStrategy<T,W> withMode(WindowingStrategy.AccumulationMode mode)
public WindowingStrategy<T,W> withWindowFn(WindowFn<?,?> wildcardWindowFn)
public WindowingStrategy<T,W> withAllowedLateness(org.joda.time.Duration allowedLateness)
public WindowingStrategy<T,W> withClosingBehavior(Window.ClosingBehavior closingBehavior)