public static enum Counter.AggregationKind extends Enum<Counter.AggregationKind>
| Enum Constant and Description |
|---|
AND
Computes boolean AND over all added values.
|
MAX
Computes the maximum value of all added values.
|
MEAN
Computes the arithmetic mean of all added values.
|
MIN
Computes the minimum value of all added values.
|
OR
Computes boolean OR over all added values.
|
SUM
Computes the sum of all added values.
|
| Modifier and Type | Method and Description |
|---|---|
static Counter.AggregationKind |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Counter.AggregationKind[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Counter.AggregationKind SUM
public static final Counter.AggregationKind MAX
public static final Counter.AggregationKind MIN
public static final Counter.AggregationKind MEAN
public static final Counter.AggregationKind AND
Boolean values.public static final Counter.AggregationKind OR
Boolean values.public static Counter.AggregationKind[] values()
for (Counter.AggregationKind c : Counter.AggregationKind.values()) System.out.println(c);
public static Counter.AggregationKind valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is null