public class CounterSet.AddCounterMutator extends Object
| Constructor and Description |
|---|
AddCounterMutator() |
| Modifier and Type | Method and Description |
|---|---|
<T> Counter<T> |
addCounter(Counter<T> counter)
Adds the given Counter into the enclosing CounterSet.
|
public <T> Counter<T> addCounter(Counter<T> counter)
If a counter with the same name already exists, it will be reused, as long as it has the same type.
IllegalArgumentException - if a counter with the same
name but an incompatible kind had already been added