T - the type of the values being observedpublic interface ElementByteSizeObservable<T>
T.| Modifier and Type | Method and Description |
|---|---|
boolean |
isRegisterByteSizeObserverCheap(T value)
Returns whether
registerByteSizeObserver(T, com.google.cloud.dataflow.sdk.util.common.ElementByteSizeObserver) is cheap enough
to call for every element, that is, if this
ElementByteSizeObservable can calculate the byte size of
the element to be coded in roughly constant time (or lazily). |
void |
registerByteSizeObserver(T value,
ElementByteSizeObserver observer)
Notifies the
ElementByteSizeObserver about the byte size
of the encoded value using this ElementByteSizeObservable. |
boolean isRegisterByteSizeObserverCheap(T value)
registerByteSizeObserver(T, com.google.cloud.dataflow.sdk.util.common.ElementByteSizeObserver) is cheap enough
to call for every element, that is, if this
ElementByteSizeObservable can calculate the byte size of
the element to be coded in roughly constant time (or lazily).void registerByteSizeObserver(T value, ElementByteSizeObserver observer) throws Exception
ElementByteSizeObserver about the byte size
of the encoded value using this ElementByteSizeObservable.Exception