V - the type of elements returned by this iterableInputT - type type of iterator returned by this iterablepublic abstract class ElementByteSizeObservableIterable<V,InputT extends ElementByteSizeObservableIterator<V>> extends Object implements Iterable<V>
| Constructor and Description |
|---|
ElementByteSizeObservableIterable() |
| Modifier and Type | Method and Description |
|---|---|
void |
addObserver(Observer observer)
Sets the observer, which will observe the iterator returned in
the next call to iterator() method.
|
protected abstract InputT |
createIterator()
Derived classes override this method to return an iterator for this
iterable.
|
InputT |
iterator()
Returns a new iterator for this iterable.
|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitforEach, spliteratorprotected abstract InputT createIterator()
public void addObserver(Observer observer)