public class ElementByteSizeObserver extends Object implements Observer
| Constructor and Description |
|---|
ElementByteSizeObserver(Counter<Long> counter) |
| Modifier and Type | Method and Description |
|---|---|
void |
advance()
Advances the observer to the next element.
|
boolean |
getIsLazy()
Returns whether byte counting for the current element is lazy, that is,
whether the observer gets notified of the element's byte count only as
element's pieces are being processed or iterated over.
|
void |
setLazy()
Sets byte counting for the current element as lazy.
|
void |
update(Object obj)
Updates the observer with a context specified, but without an instance of
the Observable.
|
void |
update(Observable obs,
Object obj) |
public void setLazy()
public boolean getIsLazy()
public void update(Object obj)
public void update(Observable obs, Object obj)
public void advance()