| Modifier and Type | Field and Description |
|---|---|
static com.google.common.base.Function<Method,String> |
CLASS_AND_METHOD_FORMATTER
A
Function that turns a method into the declaring class + method signature. |
static com.google.common.base.Function<Class<?>,String> |
CLASS_NAME
A
Function with returns the classes name. |
static com.google.common.base.Function<Class<?>,String> |
CLASS_SIMPLE_NAME
A
Function with returns the classes name. |
static com.google.common.base.Function<Method,String> |
METHOD_FORMATTER
A
Function that turns a method into a simple method signature. |
static com.google.common.base.Function<Type,String> |
TYPE_SIMPLE_DESCRIPTION
A
Function that formats types. |
| Constructor and Description |
|---|
ReflectHelpers() |
| Modifier and Type | Method and Description |
|---|---|
static com.google.common.collect.FluentIterable<Class<?>> |
getClosureOfInterfaces(Class<?> clazz)
Returns all interfaces of the given clazz.
|
static Iterable<Method> |
getClosureOfMethodsOnInterface(Class<?> iface)
Returns all the methods visible from
iface. |
static Iterable<Method> |
getClosureOfMethodsOnInterfaces(Iterable<? extends Class<?>> interfaces)
Returns all the methods visible from the provided interfaces.
|
public static final com.google.common.base.Function<Method,String> METHOD_FORMATTER
Function that turns a method into a simple method signature.public static final com.google.common.base.Function<Method,String> CLASS_AND_METHOD_FORMATTER
Function that turns a method into the declaring class + method signature.public static final com.google.common.base.Function<Class<?>,String> CLASS_NAME
Function with returns the classes name.public static final com.google.common.base.Function<Class<?>,String> CLASS_SIMPLE_NAME
Function with returns the classes name.public static com.google.common.collect.FluentIterable<Class<?>> getClosureOfInterfaces(Class<?> clazz)
clazz - public static Iterable<Method> getClosureOfMethodsOnInterfaces(Iterable<? extends Class<?>> interfaces)
interfaces - The interfaces to use when searching for all their methods.Methods which interfaces expose.