T - the type of elements returned by this iteratorpublic interface Reiterator<T> extends Iterator<T>
Iterator with the ability to copy its iteration state.| Modifier and Type | Method and Description |
|---|---|
Reiterator<T> |
copy()
Returns a copy of the current
Reiterator. |
forEachRemaining, hasNext, next, removeReiterator<T> copy()
Reiterator. The copy's iteration
state is logically independent of the current iterator; each may be
advanced without affecting the other.
The returned Reiterator is not guaranteed to return
referentially identical iteration results as the original
Reiterator, although Object.equals(java.lang.Object) will typically return
true for the corresponding elements of each if the original source is
logically immutable.