public static interface Reader.Progress
ReaderIterator is through a
Reader.
The common worker framework does not interpret instances of this interface. But a tool-specific framework can make assumptions about the implementation, and so the concrete Reader subclasses used by a tool-specific framework should match.