public abstract class MergingStateInternals extends Object implements StateInternals
StateInternals that provides mergedState(java.lang.Iterable<com.google.cloud.dataflow.sdk.util.state.StateNamespace>, com.google.cloud.dataflow.sdk.util.state.StateNamespace, com.google.cloud.dataflow.sdk.util.state.StateTag<T>) in terms of
StateInternals.state(com.google.cloud.dataflow.sdk.util.state.StateNamespace, com.google.cloud.dataflow.sdk.util.state.StateTag<T>).| Constructor and Description |
|---|
MergingStateInternals() |
| Modifier and Type | Method and Description |
|---|---|
<T extends MergeableState<?,?>> |
mergedState(Iterable<StateNamespace> sourceNamespaces,
StateNamespace resultNamespace,
StateTag<T> address)
Return state that reads from all the source namespaces.
|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitstatepublic <T extends MergeableState<?,?>> T mergedState(Iterable<StateNamespace> sourceNamespaces, StateNamespace resultNamespace, StateTag<T> address)
StateInternals Merging state is potentially destructive, in that it may move information from the
sourceNamespaces to resultNamespace. As a result, after calling this all
future calls should include as their namespaces a superset of
sourceNamespaces and resultNamespace.
mergedState in interface StateInternals