T - The type of value returned by read().@Experimental(value=STATE) public interface StateContents<T>
StateContents is produced by the read methods on all State objects.
Calling read() returns the associated value.
This class is similar to Future, but each invocation of
read() need not return the same value.
Getting the StateContents from a read method indicates the desire to eventually
read a value. Depending on the runner this may or may not immediately start the read.
| Modifier and Type | Method and Description |
|---|---|
T |
read()
Read the current value.
|
T read()