public interface StateNamespace
StateInternals.
Instances of StateNamespace are guaranteed to have a #hashCode and
#equals that uniquely identify the namespace.
| Modifier and Type | Method and Description |
|---|---|
String |
stringKey()
Return a
String representation of the key. |
String stringKey()
String representation of the key. It is guaranteed that this
String will uniquely identify the key.
This will encode the actual namespace as a String. It is
preferable to use the StateNamespace object when possible.
The string produced by the standard implementations will not contain a '+' character. This enables adding a '+' between the actual namespace and other information, if needed, to separate the two.