public class StateNamespaces extends Object
StateNamespaces.| Modifier and Type | Class and Description |
|---|---|
static class |
StateNamespaces.GlobalNamespace
StateNamespace that is global to the current key being processed. |
static class |
StateNamespaces.WindowAndTriggerNamespace<W extends BoundedWindow>
StateNamespace that is scoped to a particular window and trigger index. |
static class |
StateNamespaces.WindowNamespace<W extends BoundedWindow>
StateNamespace that is scoped to a specific window. |
| Modifier and Type | Method and Description |
|---|---|
static <W extends BoundedWindow> |
fromString(String stringKey,
Coder<W> windowCoder)
Convert a
stringKey produced using StateNamespace.stringKey()
on one of the namespaces produced by this class into the original
StateNamespace. |
static StateNamespace |
global() |
static <W extends BoundedWindow> |
window(Coder<W> windowCoder,
W window) |
static <W extends BoundedWindow> |
windowAndTrigger(Coder<W> windowCoder,
W window,
int triggerIdx) |
public static StateNamespace global()
public static <W extends BoundedWindow> StateNamespace window(Coder<W> windowCoder, W window)
public static <W extends BoundedWindow> StateNamespace windowAndTrigger(Coder<W> windowCoder, W window, int triggerIdx)
public static <W extends BoundedWindow> StateNamespace fromString(String stringKey, Coder<W> windowCoder)
stringKey produced using StateNamespace.stringKey()
on one of the namespaces produced by this class into the original
StateNamespace.