public static class StateNamespaces.GlobalNamespace extends Object implements StateNamespace
StateNamespace that is global to the current key being processed.| Constructor and Description |
|---|
GlobalNamespace() |
| Modifier and Type | Method and Description |
|---|---|
boolean |
equals(Object obj) |
int |
hashCode() |
String |
stringKey()
Return a
String representation of the key. |
String |
toString() |
public String stringKey()
StateNamespaceString representation of the key. It is guaranteed that this
String will uniquely identify the key.
This will encode the actual namespace as a String. It is
preferable to use the StateNamespace object when possible.
The string produced by the standard implementations will not contain a '+' character. This enables adding a '+' between the actual namespace and other information, if needed, to separate the two.
stringKey in interface StateNamespace