public static class StateNamespaces.WindowNamespace<W extends BoundedWindow> extends Object implements StateNamespace
StateNamespace that is scoped to a specific window.public W getWindow()
public String stringKey()
StateNamespaceString representation of the key. It is guaranteed that this
String will uniquely identify the key.
This will encode the actual namespace as a String. It is
preferable to use the StateNamespace object when possible.
The string produced by the standard implementations will not contain a '+' character. This enables adding a '+' between the actual namespace and other information, if needed, to separate the two.
stringKey in interface StateNamespace