public static enum PCollection.IsBounded extends Enum<PCollection.IsBounded>
| Enum Constant and Description |
|---|
BOUNDED
PCollection contains bounded data elements, such as
PCollections from TextIO, BigQueryIO,
Create e.t.c. |
UNBOUNDED
PCollection contains unbounded data elements, such as
PCollections from PubsubIO. |
| Modifier and Type | Method and Description |
|---|---|
PCollection.IsBounded |
and(PCollection.IsBounded that)
Returns the composed IsBounded property.
|
static PCollection.IsBounded |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static PCollection.IsBounded[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final PCollection.IsBounded BOUNDED
PCollection contains bounded data elements, such as
PCollections from TextIO, BigQueryIO,
Create e.t.c.public static final PCollection.IsBounded UNBOUNDED
PCollection contains unbounded data elements, such as
PCollections from PubsubIO.public static PCollection.IsBounded[] values()
for (PCollection.IsBounded c : PCollection.IsBounded.values()) System.out.println(c);
public static PCollection.IsBounded valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic PCollection.IsBounded and(PCollection.IsBounded that)
The composed property is BOUNDED only if all components are BOUNDED. Otherwise, it is UNBOUNDED.