Skip navigation links

Package com.google.cloud.dataflow.sdk.values

Defines PCollection and other classes for representing data in a Pipeline.

See: Description

Package com.google.cloud.dataflow.sdk.values Description

Defines PCollection and other classes for representing data in a Pipeline.

A PCollection is an immutable collection of values of type T and is the main representation for data. A PCollectionTuple is a tuple of PCollections used in cases where PTransforms take or return multiple PCollections.

A PCollectionTuple is an immutable tuple of heterogeneously-typed PCollections, "keyed" by TupleTags. A PCollectionTuple can be used as the input or output of a PTransform taking or producing multiple PCollection inputs or outputs that can be of different types, for instance a ParDo with side outputs.

A PCollectionView is an immutable view of a PCollection that can be accessed from a DoFn and other user Fns as a side input.

Skip navigation links