| Modifier and Type | Constant Field | Value |
|---|---|---|
public static final String |
SET_PROJECT_FROM_OPTIONS_WARNING |
"No project specified for BigQuery table \"%1$s.%2$s\". Assuming it is in \"%3$s\". If the table is in a different project please specify it as a part of the BigQuery table definition." |
| Modifier and Type | Constant Field | Value |
|---|---|---|
public static final long |
SPLIT_POINTS_UNKNOWN |
-1L |
| Modifier and Type | Constant Field | Value |
|---|---|---|
public static final int |
DATASTORE_BATCH_UPDATE_LIMIT |
500 |
public static final String |
DEFAULT_HOST |
"https://www.googleapis.com" |
| Modifier and Type | Constant Field | Value |
|---|---|---|
protected static final String |
TEMPORARY_FILENAME_SEPARATOR |
"-temp-" |
| Modifier and Type | Constant Field | Value |
|---|---|---|
public static final String |
DIRECTORY_CONTAINER |
"/part-SSSSS" |
public static final String |
INDEX_OF_MAX |
"-SSSSS-of-NNNNN" |
| Modifier and Type | Constant Field | Value |
|---|---|---|
public static final long |
BACKLOG_UNKNOWN |
-1L |
| Modifier and Type | Constant Field | Value |
|---|---|---|
protected static final String |
XML_EXTENSION |
"xml" |
| Modifier and Type | Constant Field | Value |
|---|---|---|
public static final int |
NUM_QUERY_SPLITS_MAX |
50000 |
| Modifier and Type | Constant Field | Value |
|---|---|---|
public static final long |
OFFSET_INFINITY |
9223372036854775807L |
| Modifier and Type | Constant Field | Value |
|---|---|---|
public static final String |
BATCH_WORKER_HARNESS_CONTAINER_IMAGE |
"dataflow.gcr.io/v1beta3/java-batch:1.9.1" |
public static final String |
PROJECT_ID_REGEXP |
"[a-z][-a-z0-9:.]+[a-z0-9]" |
public static final String |
STREAMING_WORKER_HARNESS_CONTAINER_IMAGE |
"dataflow.gcr.io/v1beta3/java-streaming:1.9.1" |
| Modifier and Type | Constant Field | Value |
|---|---|---|
public static final long |
DEFAULT_MAX_NUM_ELEMENTS |
1000000000L |