private Object writeReplace()
Class<T> type
Schema schema
List<E> nonDeterministicReasons
ThreadLocal<T> decoder
ThreadLocal<T> encoder
ThreadLocal<T> writer
ThreadLocal<T> reader
CannotProvideCoderException.ReasonCode reason
Coder<T> coder
DelegateCoder.CodingFunction<InputT,OutputT> toFn
DelegateCoder.CodingFunction<InputT,OutputT> fromFn
VarLongCoder longCoder
BigEndianLongCoder longCoder
Class<T> protoMessageClass
List<E> extensionHostClasses
ExtensionRegistry used during
encoding and decoding.Class<T> protoMessageClass
Message type to be coded.Set<E> extensionHostClasses
ProtoCoder. The extensions from these
classes will be included in the ExtensionRegistry used during encoding and decoding.String filenamePrefix
String filenameSuffix
int numShards
String shardTemplate
Class<T> type
Schema schema
boolean validate
TableReference table
String query
boolean validate
Boolean flattenResults
String jsonTableRef
SerializableFunction<InputT,OutputT> tableRefFunction
String jsonSchema
BigQueryIO.Write.CreateDisposition createDisposition
BigQueryIO.Write.WriteDisposition writeDisposition
boolean validate
com.google.cloud.dataflow.sdk.util.BigQueryServices testBigQueryServices
FileBasedSource<T> sourceDelegate
CompressedSource.DecompressingChannelFactory channelFactory
long numElements
String host
String datasetId
null for in-progress Sources.DatastoreV1.Query query
null for in-progress Sources.String namespace
QuerySplitter mockSplitter
Long mockEstimateSizeBytes
String baseOutputFilename
String extension
String fileNamingTemplate
ShardNameTemplate for a description of
possible naming templates. Default is ShardNameTemplate.INDEX_OF_MAX.FileBasedSink<T> sink
FileBasedSink.FileBasedWriteOperation.TemporaryFileRetention temporaryFileRetention
String baseTemporaryFilename
String filename
String fileOrPatternSpec
FileBasedSource.Mode mode
long startOffset
long endOffset
long minBundleSize
PubsubIO.PubsubTopic topic
PubsubIO.PubsubSubscription subscription
String timestampLabel
String idLabel
Coder<T> coder
int maxNumRecords
Duration maxReadTime
PubsubIO.PubsubTopic topic
String timestampLabel
String idLabel
Coder<T> coder
BoundedSource<T> source
UnboundedSource<OutputT,CheckpointMarkT extends UnboundedSource.CheckpointMark> source
String filepattern
Coder<T> coder
boolean validate
TextIO.CompressionType compressionType
String filenamePrefix
String filenameSuffix
Coder<T> coder
int numShards
String shardTemplate
boolean validate
com.google.cloud.bigtable.config.BigtableOptions options
null at validation time, but may start out null while
source is being built.String tableId
com.google.bigtable.v1.RowFilter filter
com.google.cloud.dataflow.sdk.io.bigtable.BigtableService bigtableService
com.google.cloud.bigtable.config.BigtableOptions options
null at validation time, but may start out null while
source is being built.String tableId
com.google.cloud.dataflow.sdk.io.bigtable.BigtableService bigtableService
com.google.protobuf.ByteString value
DataflowPipelineJob job
DataflowPipelineJob replacedByJob
PubsubIO.Write.Bound<T> transform
Comparator<T> compareFn
int numQuantiles
int bufferSize
int numBuffers
long maxNumElements
PriorityQueue<E> heap
long sampleSize
CombineFnBase.GlobalCombineFn<InputT,AccumT,OutputT> fn
boolean insertDefault
int fanout
SerializableFunction<InputT,OutputT> combiner
int bufferSize
SerializableFunction<InputT,OutputT> hotKeyFanout
SerializableFunction<InputT,OutputT> predicate
SerializableFunction<InputT,OutputT> fn
boolean fewKeys
com.google.cloud.dataflow.sdk.util.WindowingStrategy<T,W extends BoundedWindow> windowingStrategy
SerializableFunction<InputT,OutputT> fn
Object identity
Comparator<T> comparator
Object identity
Comparator<T> comparator
private void readObject(ObjectInputStream oos)
private void writeObject(ObjectOutputStream oos)
SerializableFunction<InputT,OutputT> fn
TypeDescriptor<T> representativeType
Top.TopCombineFn<T,ComparatorT extends Comparator<T> & Serializable> topCombineFn
Random rand
long limit
int count
Comparator<T> compareFn
Object defaultValue
boolean hasDefault
PCollectionView<T> view
SerializableFunction<InputT,OutputT> fn
SerializableFunction<InputT,OutputT> fn
Duration allowedTimestampSkew
CoGbkResultSchema schema
com.google.cloud.dataflow.sdk.transforms.join.UnionCoder unionCoder
TupleTagList tupleTagList
HashMap<K,V> tagMap
List<E> timestampMappers
com.google.cloud.dataflow.sdk.util.TimeDomain timeDomain
int countElems
int number
DateTime startDate
DateTimeZone timeZone
int number
int dayOfMonth
DateTime startDate
DateTimeZone timeZone
int number
int monthOfYear
int dayOfMonth
DateTime startDate
DateTimeZone timeZone
String cause
WindowFn<T,W extends BoundedWindow> originalWindowFn
Duration gapDuration
WindowFn<T,W extends BoundedWindow> windowFn
Trigger<W extends BoundedWindow> trigger
com.google.cloud.dataflow.sdk.util.WindowingStrategy.AccumulationMode mode
Duration allowedLateness
Window.ClosingBehavior closingBehavior
OutputTimeFn<W extends BoundedWindow> outputTimeFn
String id
boolean generated