T - the type of the values being transcodedpublic abstract class AtomicCoder<T> extends DeterministicStandardCoder<T>
AtomicCoder is a Coder that has no component
Coders or other state.
Note that, unless the behavior is overriden, atomic coders are presumed to be deterministic and all instances are considered equal.
Coder.Context, Coder.NonDeterministicException| Modifier | Constructor and Description |
|---|---|
protected |
AtomicCoder() |
| Modifier and Type | Method and Description |
|---|---|
List<Coder<?>> |
getCoderArguments()
If this is a
Coder for a parameterized type, returns the
list of Coders being used for each of the parameters, or
returns null if this cannot be done or this is not a
parameterized type. |
static <T> List<Object> |
getInstanceComponents(T exampleValue)
Returns a list of values contained in the provided example
value, one per type parameter.
|
verifyDeterministicasCloudObject, consistentWithEquals, equals, getComponents, getEncodedElementByteSize, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, structuralValue, toString, verifyDeterministic, verifyDeterministicpublic List<Coder<?>> getCoderArguments()
CoderCoder for a parameterized type, returns the
list of Coders being used for each of the parameters, or
returns null if this cannot be done or this is not a
parameterized type.