T - the type of the values being transcodedpublic abstract class AtomicCoder<T> extends StandardCoder<T>
Coder.Context, Coder.NonDeterministicException| Modifier | Constructor and Description |
|---|---|
protected |
AtomicCoder() |
| Modifier and Type | Method and Description |
|---|---|
java.util.List<Coder<?>> |
getCoderArguments()
If this is a
Coder for a parameterized type, returns the
list of Coders being used for each of the parameters, or
returns null if this cannot be done or this is not a
parameterized type. |
static <T> java.util.List<java.lang.Object> |
getInstanceComponents(T exampleValue)
Returns a list of values contained in the provided example
value, one per type parameter.
|
asCloudObject, equals, getComponents, getEncodedElementByteSize, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, toString, verifyDeterministic, verifyDeterministic, verifyDeterministicclone, finalize, getClass, notify, notifyAll, wait, wait, waitdecode, encode, isDeterministicpublic java.util.List<Coder<?>> getCoderArguments()
CoderCoder for a parameterized type, returns the
list of Coders being used for each of the parameters, or
returns null if this cannot be done or this is not a
parameterized type.public static <T> java.util.List<java.lang.Object> getInstanceComponents(T exampleValue)