T - the type of elements handled by this coderpublic abstract class CustomCoder<T> extends AtomicCoder<T> implements java.io.Serializable
Coder.encode(T, java.io.OutputStream, com.google.cloud.dataflow.sdk.coders.Coder.Context)
and Coder.decode(java.io.InputStream, com.google.cloud.dataflow.sdk.coders.Coder.Context) methods.
Not to be confused with SerializableCoder that encodes serializables.
Coder.Context, Coder.NonDeterministicException| Constructor and Description |
|---|
CustomCoder() |
| Modifier and Type | Method and Description |
|---|---|
com.google.cloud.dataflow.sdk.util.CloudObject |
asCloudObject()
Returns the
CloudObject that represents this Coder. |
boolean |
isDeterministic()
Deprecated.
|
static CustomCoder<?> |
of(java.lang.String typeId,
java.lang.String type,
java.lang.String serializedCoder) |
getCoderArguments, getInstanceComponentsequals, getComponents, getEncodedElementByteSize, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, toString, verifyDeterministic, verifyDeterministic, verifyDeterministicpublic static CustomCoder<?> of(java.lang.String typeId, java.lang.String type, java.lang.String serializedCoder)
public com.google.cloud.dataflow.sdk.util.CloudObject asCloudObject()
CoderCloudObject that represents this Coder.asCloudObject in interface Coder<T>asCloudObject in class StandardCoder<T>@Deprecated public boolean isDeterministic()
Coder In order for a Coder to be considered deterministic,
the following must be true:
Object.equals()
or Comparable.compareTo(), if supported), have the same
encoding.
Coder always produces a canonical encoding, which is the
same for an instance of an object even if produced on different
computers at different times.
isDeterministic in interface Coder<T>