public class DoubleCoder extends AtomicCoder<Double>
DoubleCoder encodes Doubles in 8 bytes.Coder.Context, Coder.NonDeterministicException| Modifier and Type | Method and Description |
|---|---|
boolean |
consistentWithEquals()
Returns true if the encoded bytes of two objects are
equal only when they are also equal according to
Object.equals(). |
Double |
decode(InputStream inStream,
Coder.Context context)
Decodes a value of type
T from the given input stream in
the given context. |
void |
encode(Double value,
OutputStream outStream,
Coder.Context context)
Encodes the given value of type
T onto the given output stream
in the given context. |
protected long |
getEncodedElementByteSize(Double value,
Coder.Context context)
Returns the size in bytes of the encoded value using this
coder.
|
boolean |
isRegisterByteSizeObserverCheap(Double value,
Coder.Context context)
Returns true since registerByteSizeObserver() runs in constant time.
|
static DoubleCoder |
of() |
void |
verifyDeterministic()
Floating-point operations are not guaranteed to be deterministic, even
if the storage format might be, so floating point representations are not
recommended for use in operations that require deterministic inputs.
|
getCoderArguments, getInstanceComponentsasCloudObject, equals, getComponents, hashCode, registerByteSizeObserver, structuralValue, toString, verifyDeterministic, verifyDeterministicpublic static DoubleCoder of()
public void encode(Double value, OutputStream outStream, Coder.Context context) throws IOException, CoderException
CoderT onto the given output stream
in the given context.IOException - if writing to the OutputStream fails
for some reasonCoderException - if the value could not be encoded for some reasonpublic Double decode(InputStream inStream, Coder.Context context) throws IOException, CoderException
CoderT from the given input stream in
the given context. Returns the decoded value.IOException - if reading from the InputStream fails
for some reasonCoderException - if the value could not be decoded for some reasonpublic void verifyDeterministic()
throws Coder.NonDeterministicException
verifyDeterministic in interface Coder<Double>verifyDeterministic in class DeterministicStandardCoder<Double>Coder.NonDeterministicException - if this coder is not deterministic.public boolean consistentWithEquals()
CoderObject.equals().
(and also implements a compatible Object.hasCode())
This most notably false for arrays. It will generally
be false when Object.equals() compares object identity,
rather than performing a semantic/structural comparison.
consistentWithEquals in interface Coder<Double>consistentWithEquals in class StandardCoder<Double>public boolean isRegisterByteSizeObserverCheap(Double value, Coder.Context context)
isRegisterByteSizeObserverCheap in interface Coder<Double>isRegisterByteSizeObserverCheap in class StandardCoder<Double>protected long getEncodedElementByteSize(Double value, Coder.Context context) throws Exception
StandardCodergetEncodedElementByteSize in class StandardCoder<Double>Exception