public class InstantCoder extends AtomicCoder<Instant>
Coder.Context| Modifier and Type | Method and Description |
|---|---|
Instant |
decode(java.io.InputStream inStream,
Coder.Context context)
Decodes a value of type
T from the given input stream in
the given context. |
void |
encode(Instant value,
java.io.OutputStream outStream,
Coder.Context context)
Encodes the given value of type
T onto the given output stream
in the given context. |
boolean |
isDeterministic()
Returns true if the coding is deterministic.
|
static InstantCoder |
of() |
getCoderArguments, getInstanceComponentsasCloudObject, equals, getComponents, getEncodedElementByteSize, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, toStringpublic static InstantCoder of()
public void encode(Instant value, java.io.OutputStream outStream, Coder.Context context) throws CoderException, java.io.IOException
CoderT onto the given output stream
in the given context.CoderException - if the value could not be encoded for some reasonjava.io.IOException - if writing to the OutputStream fails
for some reasonpublic Instant decode(java.io.InputStream inStream, Coder.Context context) throws CoderException, java.io.IOException
CoderT from the given input stream in
the given context. Returns the decoded value.CoderException - if the value could not be decoded for some reasonjava.io.IOException - if reading from the InputStream fails
for some reasonpublic boolean isDeterministic()
Coder In order for a Coder to be considered deterministic,
the following must be true:
Object.equals()
or Comparable.compareTo(), if supported), have the same
encoding.
Coder always produces a canonical encoding, which is the
same for an instance of an object even if produced on different
computers at different times.