T - type of JAXB annotated objects that will be serialized.public class JAXBCoder<T> extends CustomCoder<T>
Class of the JAXB annotated object.Coder.Context, Coder.NonDeterministicException| Modifier and Type | Method and Description |
|---|---|
T |
decode(java.io.InputStream inStream,
Coder.Context context)
Decodes a value of type
T from the given input stream in
the given context. |
void |
encode(T value,
java.io.OutputStream outStream,
Coder.Context context)
Encodes the given value of type
T onto the given output stream
in the given context. |
java.lang.Class<T> |
getJAXBClass() |
static <T> JAXBCoder<T> |
of(java.lang.Class<T> jaxbClass)
Create a coder for a given type of JAXB annotated objects.
|
asCloudObject, isDeterministic, ofgetCoderArguments, getInstanceComponentsconsistentWithEquals, equals, getComponents, getEncodedElementByteSize, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, structuralValue, toString, verifyDeterministic, verifyDeterministic, verifyDeterministicpublic java.lang.Class<T> getJAXBClass()
public static <T> JAXBCoder<T> of(java.lang.Class<T> jaxbClass)
jaxbClass - the Class of the JAXB annotated objects.public void encode(T value, java.io.OutputStream outStream, Coder.Context context) throws CoderException, java.io.IOException
CoderT onto the given output stream
in the given context.CoderException - if the value could not be encoded for some reasonjava.io.IOException - if writing to the OutputStream fails
for some reasonpublic T decode(java.io.InputStream inStream, Coder.Context context) throws CoderException, java.io.IOException
CoderT from the given input stream in
the given context. Returns the decoded value.CoderException - if the value could not be decoded for some reasonjava.io.IOException - if reading from the InputStream fails
for some reason