T - the type of the elements of the Lists being transcodedpublic class ListCoder<T> extends IterableLikeCoder<T,java.util.List<T>>
Coder.Context| Modifier and Type | Method and Description |
|---|---|
protected java.util.List<T> |
decodeToIterable(java.util.List<T> decodedElements)
Builds an instance of the coder's associated
Iterable from a list
of decoded elements. |
static <T> java.util.List<java.lang.Object> |
getInstanceComponents(java.util.List<T> exampleValue)
Returns the first element in this list if it is non-empty,
otherwise returns
null. |
boolean |
isDeterministic()
List sizes are always known, so ListIterable may be deterministic while
the general IterableLikeCoder is not.
|
static <T> ListCoder<T> |
of(Coder<T> elemCoder) |
static ListCoder<?> |
of(java.util.List<Coder<?>> components) |
decode, encode, getCoderArguments, getElemCoder, getInstanceComponentsHelper, isRegisterByteSizeObserverCheap, registerByteSizeObserverasCloudObject, equals, getComponents, getEncodedElementByteSize, hashCode, toStringprotected final java.util.List<T> decodeToIterable(java.util.List<T> decodedElements)
IterableLikeCoderIterable from a list
of decoded elements. If IT is a supertype of List<T>, the
derived class implementation is permitted to return decodedElements
directly.decodeToIterable in class IterableLikeCoder<T,java.util.List<T>>public static <T> java.util.List<java.lang.Object> getInstanceComponents(java.util.List<T> exampleValue)
null.public boolean isDeterministic()
isDeterministic in interface Coder<java.util.List<T>>isDeterministic in class IterableLikeCoder<T,java.util.List<T>>