T - the type of values being transcodedpublic abstract class MapCoderBase<T> extends StandardCoder<T>
MapCoder directly (as of this writing, Jackson2 walks off the end of
an array when it tries to deserialize a class with multiple generic type
parameters). This should be removed in favor of a better workaround.Coder.Context, Coder.NonDeterministicException| Modifier | Constructor and Description |
|---|---|
protected |
MapCoderBase() |
| Modifier and Type | Method and Description |
|---|---|
static MapCoderBase<?> |
of(java.lang.String typeId,
java.util.List<Coder<?>> components) |
asCloudObject, equals, getComponents, getEncodedElementByteSize, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, toString, verifyDeterministic, verifyDeterministic, verifyDeterministicclone, finalize, getClass, notify, notifyAll, wait, wait, waitdecode, encode, getCoderArguments, isDeterministicpublic static MapCoderBase<?> of(java.lang.String typeId, java.util.List<Coder<?>> components)