public class TableRowJsonCoder extends AtomicCoder<TableRow>
Coder.Context| Modifier and Type | Method and Description |
|---|---|
TableRow |
decode(java.io.InputStream inStream,
Coder.Context context)
Decodes a value of type
T from the given input stream in
the given context. |
void |
encode(TableRow value,
java.io.OutputStream outStream,
Coder.Context context)
Encodes the given value of type
T onto the given output stream
in the given context. |
protected long |
getEncodedElementByteSize(TableRow value,
Coder.Context context)
Returns the size in bytes of the encoded value using this
coder.
|
boolean |
isDeterministic()
TableCell can hold arbitrary Object instances, which makes the encoding
non-deterministic.
|
static TableRowJsonCoder |
of() |
getCoderArguments, getInstanceComponentsasCloudObject, equals, getComponents, hashCode, isRegisterByteSizeObserverCheap, registerByteSizeObserver, toStringpublic static TableRowJsonCoder of()
public void encode(TableRow value, java.io.OutputStream outStream, Coder.Context context) throws java.io.IOException
CoderT onto the given output stream
in the given context.java.io.IOException - if writing to the OutputStream fails
for some reasonCoderException - if the value could not be encoded for some reasonpublic TableRow decode(java.io.InputStream inStream, Coder.Context context) throws java.io.IOException
CoderT from the given input stream in
the given context. Returns the decoded value.java.io.IOException - if reading from the InputStream fails
for some reasonCoderException - if the value could not be decoded for some reasonprotected long getEncodedElementByteSize(TableRow value, Coder.Context context) throws java.lang.Exception
StandardCodergetEncodedElementByteSize in class StandardCoder<TableRow>java.lang.Exceptionpublic boolean isDeterministic()