public static class BigQueryIO.Read.Bound extends PTransform<PInput,PCollection<com.google.api.services.bigquery.model.TableRow>>
name| Modifier and Type | Method and Description |
|---|---|
PCollection<com.google.api.services.bigquery.model.TableRow> |
apply(PInput input)
Applies this
PTransform on the given InputT, and returns its
Output. |
BigQueryIO.Read.Bound |
from(String tableSpec)
Sets the table specification.
|
BigQueryIO.Read.Bound |
from(com.google.api.services.bigquery.model.TableReference table)
Sets the table specification.
|
BigQueryIO.Read.Bound |
fromQuery(String query)
Sets the BigQuery query to be used.
|
protected Coder<com.google.api.services.bigquery.model.TableRow> |
getDefaultOutputCoder()
Returns the default
Coder to use for the output of this
single-output PTransform. |
String |
getQuery() |
com.google.api.services.bigquery.model.TableReference |
getTable()
Returns the table to write.
|
boolean |
getValidate()
Returns true if table validation is enabled.
|
BigQueryIO.Read.Bound |
named(String name)
Sets the name associated with this transformation.
|
void |
validate(PInput input)
Validates the current
PTransform. |
BigQueryIO.Read.Bound |
withoutValidation()
Disable table validation.
|
getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, toStringpublic BigQueryIO.Read.Bound named(String name)
public BigQueryIO.Read.Bound from(String tableSpec)
Refer to BigQueryIO.parseTableSpec(String) for the specification format.
public BigQueryIO.Read.Bound fromQuery(String query)
public BigQueryIO.Read.Bound from(com.google.api.services.bigquery.model.TableReference table)
public BigQueryIO.Read.Bound withoutValidation()
public void validate(PInput input)
PTransform.validate in class PTransform<PInput,PCollection<com.google.api.services.bigquery.model.TableRow>>public PCollection<com.google.api.services.bigquery.model.TableRow> apply(PInput input)
PTransformPTransform on the given InputT, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<InputT, OutputT>, InputT).
apply in class PTransform<PInput,PCollection<com.google.api.services.bigquery.model.TableRow>>protected Coder<com.google.api.services.bigquery.model.TableRow> getDefaultOutputCoder()
PTransformCoder to use for the output of this
single-output PTransform.
By default, always throws
getDefaultOutputCoder in class PTransform<PInput,PCollection<com.google.api.services.bigquery.model.TableRow>>public com.google.api.services.bigquery.model.TableReference getTable()
public String getQuery()
public boolean getValidate()