public static class BigQueryIO.Read.Bound extends PTransform<PInput,PCollection<TableRow>>
PCollection<TableRow>.name| Modifier and Type | Method and Description |
|---|---|
PCollection<TableRow> |
apply(PInput input)
Applies this
PTransform on the given Input, and returns its
Output. |
BigQueryIO.Read.Bound |
from(java.lang.String tableSpec)
Sets the table specification.
|
BigQueryIO.Read.Bound |
from(TableReference table)
Sets the table specification.
|
protected Coder<TableRow> |
getDefaultOutputCoder()
Returns the default
Coder to use for the output of this
single-output PTransform, or null if
none can be inferred. |
protected java.lang.String |
getKindString()
Returns a string describing what kind of
PTransform this is. |
TableReference |
getTable()
Returns the table to write.
|
boolean |
getValidate()
Returns true if table validation is enabled.
|
BigQueryIO.Read.Bound |
named(java.lang.String name)
Sets the name associated with this transformation.
|
BigQueryIO.Read.Bound |
withoutValidation()
Disable table validation.
|
finishSpecifying, getCoderRegistry, getDefaultName, getDefaultOutputCoder, getInput, getName, getOutput, getPipeline, setName, setPipeline, toString, withNamepublic BigQueryIO.Read.Bound named(java.lang.String name)
public BigQueryIO.Read.Bound from(java.lang.String tableSpec)
Refer to BigQueryIO.parseTableSpec(String) for the specification format.
public BigQueryIO.Read.Bound from(TableReference table)
public BigQueryIO.Read.Bound withoutValidation()
public PCollection<TableRow> apply(PInput input)
PTransformPTransform on the given Input, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<Input, Output>, Input).
apply in class PTransform<PInput,PCollection<TableRow>>protected Coder<TableRow> getDefaultOutputCoder()
PTransformCoder to use for the output of this
single-output PTransform, or null if
none can be inferred.
By default, returns null.
getDefaultOutputCoder in class PTransform<PInput,PCollection<TableRow>>protected java.lang.String getKindString()
PTransformPTransform this is.
By default, returns the base name of this
PTransform's class.
getKindString in class PTransform<PInput,PCollection<TableRow>>public TableReference getTable()
public boolean getValidate()