public static class BigQueryIO.Write.Bound extends PTransform<PCollection<TableRow>,PDone>
PCollection<TableRow>s to a BigQuery table.name| Constructor and Description |
|---|
BigQueryIO.Write.Bound() |
| Modifier and Type | Method and Description |
|---|---|
PDone |
apply(PCollection<TableRow> input)
Applies this
PTransform on the given Input, and returns its
Output. |
BigQueryIO.Write.CreateDisposition |
getCreateDisposition()
Returns the create disposition.
|
protected Coder<java.lang.Void> |
getDefaultOutputCoder()
Returns the default
Coder to use for the output of this
single-output PTransform, or null if
none can be inferred. |
protected java.lang.String |
getKindString()
Returns a string describing what kind of
PTransform this is. |
TableSchema |
getSchema()
Returns the table schema.
|
TableReference |
getTable()
Returns the table reference.
|
boolean |
getValidate()
Returns true if table validation is enabled.
|
BigQueryIO.Write.WriteDisposition |
getWriteDisposition()
Returns the write disposition.
|
BigQueryIO.Write.Bound |
named(java.lang.String name)
Sets the name associated with this transformation.
|
BigQueryIO.Write.Bound |
to(java.lang.String tableSpec)
Specifies the table specification.
|
BigQueryIO.Write.Bound |
to(TableReference table)
Specifies the table to be written to.
|
BigQueryIO.Write.Bound |
withCreateDisposition(BigQueryIO.Write.CreateDisposition createDisposition)
Specifies options for creating the table.
|
BigQueryIO.Write.Bound |
withoutValidation()
Disable table validation.
|
BigQueryIO.Write.Bound |
withSchema(TableSchema schema)
Specifies the table schema, used if the table is created.
|
BigQueryIO.Write.Bound |
withWriteDisposition(BigQueryIO.Write.WriteDisposition writeDisposition)
Specifies options for writing the table.
|
finishSpecifying, getCoderRegistry, getDefaultName, getDefaultOutputCoder, getInput, getName, getOutput, getPipeline, setName, setPipeline, toString, withNamepublic BigQueryIO.Write.Bound named(java.lang.String name)
public BigQueryIO.Write.Bound to(java.lang.String tableSpec)
Refer to BigQueryIO.parseTableSpec(String) for the specification format.
public BigQueryIO.Write.Bound to(TableReference table)
public BigQueryIO.Write.Bound withSchema(TableSchema schema)
public BigQueryIO.Write.Bound withCreateDisposition(BigQueryIO.Write.CreateDisposition createDisposition)
public BigQueryIO.Write.Bound withWriteDisposition(BigQueryIO.Write.WriteDisposition writeDisposition)
public BigQueryIO.Write.Bound withoutValidation()
public PDone apply(PCollection<TableRow> input)
PTransformPTransform on the given Input, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<Input, Output>, Input).
apply in class PTransform<PCollection<TableRow>,PDone>protected Coder<java.lang.Void> getDefaultOutputCoder()
PTransformCoder to use for the output of this
single-output PTransform, or null if
none can be inferred.
By default, returns null.
getDefaultOutputCoder in class PTransform<PCollection<TableRow>,PDone>protected java.lang.String getKindString()
PTransformPTransform this is.
By default, returns the base name of this
PTransform's class.
getKindString in class PTransform<PCollection<TableRow>,PDone>public BigQueryIO.Write.CreateDisposition getCreateDisposition()
public BigQueryIO.Write.WriteDisposition getWriteDisposition()
public TableSchema getSchema()
public TableReference getTable()
public boolean getValidate()