Returns the current offset of the reader. The value returned by this method is undefined
until the method
Source.Reader.start() is called. After
Source.Reader.start() is
called the value returned by this method should represent the offset of the value that will
be returned by the
Source.Reader.getCurrent() call. Values returned for two consecutive
records should be non-strictly increasing. If the reader has reached the end of the stream
this should return
Long.MAX_VALUE. The value returned may be outside the range
defined by the
ByteOffsetBasedSource corresponding to this reader, for reasons
described in the comment to
ByteOffsetBasedSource.