T - public abstract static class Source.AbstractReader<T> extends Object implements Source.Reader<T>
Source.Reader in a default way:
BoundedWindow.TIMESTAMP_MIN_VALUE.
| Constructor and Description |
|---|
Source.AbstractReader() |
| Modifier and Type | Method and Description |
|---|---|
org.joda.time.Instant |
getCurrentTimestamp()
Returns the timestamp associated with the current data item.
|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitadvance, close, getCurrent, getCurrentSource, startpublic org.joda.time.Instant getCurrentTimestamp()
throws NoSuchElementException
Source.Reader
If the source does not support timestamps, this should return
BoundedWindow.TIMESTAMP_MIN_VALUE.
getCurrentTimestamp in interface Source.Reader<T>NoSuchElementException