public interface DataflowPipelineDebugOptions extends PipelineOptions
| Modifier and Type | Interface and Description |
|---|---|
static class |
DataflowPipelineDebugOptions.DataflowClientFactory
Returns the default Dataflow client built from the passed in PipelineOptions.
|
static class |
DataflowPipelineDebugOptions.NameMap
Map of old names to new names.
|
static class |
DataflowPipelineDebugOptions.PathValidatorFactory
Creates a
PathValidator object using the class specified in
getPathValidatorClass(). |
static class |
DataflowPipelineDebugOptions.StagerFactory
Creates a
Stager object using the class specified in
getStagerClass(). |
PipelineOptions.CheckEnabled| Modifier and Type | Method and Description |
|---|---|
String |
getApiRootUrl()
The root URL for the Dataflow API.
|
com.google.api.services.dataflow.Dataflow |
getDataflowClient()
An instance of the Dataflow client.
|
String |
getDataflowEndpoint()
Dataflow endpoint to use.
|
String |
getDataflowJobFile()
The path to write the translated Dataflow job specification out to
at job submission time.
|
List<String> |
getExperiments()
The list of backend experiments to enable.
|
String |
getOverrideWindmillBinary()
Custom windmill_main binary to use with the streaming runner.
|
com.google.cloud.dataflow.sdk.util.PathValidator |
getPathValidator()
The path validator instance that should be created and used to validate paths.
|
Class<? extends com.google.cloud.dataflow.sdk.util.PathValidator> |
getPathValidatorClass()
The class of the validator that should be created and used to validate paths.
|
String |
getPubsubRootUrl()
Root URL for use with the Pubsub API.
|
boolean |
getReload()
Whether to reload the currently running pipeline with the same name as this one.
|
com.google.cloud.dataflow.sdk.util.Stager |
getStager()
The resource stager instance that should be created and used to stage resources.
|
Class<? extends com.google.cloud.dataflow.sdk.util.Stager> |
getStagerClass()
The class responsible for staging resources to be accessible by workers
during job execution.
|
DataflowPipelineDebugOptions.NameMap |
getTransformNameMapping()
Mapping of old PTranform names to new ones, specified as a semicolon-separated list of
oldName=newName pairs.
|
void |
setApiRootUrl(String value) |
void |
setDataflowClient(com.google.api.services.dataflow.Dataflow value) |
void |
setDataflowEndpoint(String value) |
void |
setDataflowJobFile(String value) |
void |
setExperiments(List<String> value) |
void |
setOverrideWindmillBinary(String value) |
void |
setPathValidator(com.google.cloud.dataflow.sdk.util.PathValidator validator) |
void |
setPathValidatorClass(Class<? extends com.google.cloud.dataflow.sdk.util.PathValidator> validatorClass) |
void |
setPubsubRootUrl(String value) |
void |
setReload(boolean value) |
void |
setStager(com.google.cloud.dataflow.sdk.util.Stager stager) |
void |
setStagerClass(Class<? extends com.google.cloud.dataflow.sdk.util.Stager> stagerClass) |
void |
setTransformNameMapping(DataflowPipelineDebugOptions.NameMap value) |
as, cloneAs, getRunner, getStableUniqueNames, setRunner, setStableUniqueNamesList<String> getExperiments()
Dataflow provides a number of experimental features that can be enabled with this flag.
Please sync with the Dataflow team before enabling any experiments.
String getApiRootUrl()
dataflowEndpoint can override this value
if it contains an absolute URL, otherwise apiRootUrl will be combined with
dataflowEndpoint to generate the full URL to communicate with the Dataflow API.void setApiRootUrl(String value)
String getDataflowEndpoint()
Defaults to the current version of the Google Cloud Dataflow API, at the time the current SDK version was released.
If the string contains "://", then this is treated as a url,
otherwise getApiRootUrl() is used as the root
url.
void setDataflowEndpoint(String value)
String getDataflowJobFile()
void setDataflowJobFile(String value)
Class<? extends com.google.cloud.dataflow.sdk.util.PathValidator> getPathValidatorClass()
void setPathValidatorClass(Class<? extends com.google.cloud.dataflow.sdk.util.PathValidator> validatorClass)
com.google.cloud.dataflow.sdk.util.PathValidator getPathValidator()
void setPathValidator(com.google.cloud.dataflow.sdk.util.PathValidator validator)
Class<? extends com.google.cloud.dataflow.sdk.util.Stager> getStagerClass()
void setStagerClass(Class<? extends com.google.cloud.dataflow.sdk.util.Stager> stagerClass)
com.google.cloud.dataflow.sdk.util.Stager getStager()
void setStager(com.google.cloud.dataflow.sdk.util.Stager stager)
com.google.api.services.dataflow.Dataflow getDataflowClient()
void setDataflowClient(com.google.api.services.dataflow.Dataflow value)
String getPubsubRootUrl()
void setPubsubRootUrl(String value)
@Experimental boolean getReload()
void setReload(boolean value)
@Experimental DataflowPipelineDebugOptions.NameMap getTransformNameMapping()
void setTransformNameMapping(DataflowPipelineDebugOptions.NameMap value)
String getOverrideWindmillBinary()
void setOverrideWindmillBinary(String value)