public interface DataflowPipelineDebugOptions extends PipelineOptions
| Modifier and Type | Interface and Description |
|---|---|
static class |
DataflowPipelineDebugOptions.DataflowClientFactory
Returns the default Dataflow client built from the passed in PipelineOptions.
|
static class |
DataflowPipelineDebugOptions.PathValidatorFactory
Creates a
PathValidator object using the class specified in
getPathValidatorClass(). |
static class |
DataflowPipelineDebugOptions.StagerFactory
Creates a
Stager object using the class specified in
getStagerClass(). |
| Modifier and Type | Method and Description |
|---|---|
String |
getApiRootUrl()
The endpoint to use with the Dataflow API.
|
com.google.api.services.dataflow.Dataflow |
getDataflowClient()
An instance of the Dataflow client.
|
String |
getDataflowEndpoint()
Dataflow endpoint to use.
|
String |
getDataflowJobFile()
The path to write the translated Dataflow job specification out to
at job submission time.
|
List<String> |
getExperiments()
The list of backend experiments to enable.
|
com.google.cloud.dataflow.sdk.util.PathValidator |
getPathValidator()
The path validator instance that should be created and used to validate paths.
|
Class<? extends com.google.cloud.dataflow.sdk.util.PathValidator> |
getPathValidatorClass()
The class of the validator that should be created and used to validate paths.
|
boolean |
getReload()
Whether to reload the currently running pipeline with the same name as this one.
|
com.google.cloud.dataflow.sdk.util.Stager |
getStager()
The resource stager instance that should be created and used to stage resources.
|
Class<? extends com.google.cloud.dataflow.sdk.util.Stager> |
getStagerClass()
The class responsible for staging resources to be accessible by workers
during job execution.
|
void |
setApiRootUrl(String value) |
void |
setDataflowClient(com.google.api.services.dataflow.Dataflow value) |
void |
setDataflowEndpoint(String value) |
void |
setDataflowJobFile(String value) |
void |
setExperiments(List<String> value) |
void |
setPathValidator(com.google.cloud.dataflow.sdk.util.PathValidator validator) |
void |
setPathValidatorClass(Class<? extends com.google.cloud.dataflow.sdk.util.PathValidator> validatorClass) |
void |
setReload(boolean value) |
void |
setStager(com.google.cloud.dataflow.sdk.util.Stager stager) |
void |
setStagerClass(Class<? extends com.google.cloud.dataflow.sdk.util.Stager> stagerClass) |
as, cloneAs, getRunner, setRunnerString getDataflowEndpoint()
Defaults to the current version of the Google Cloud Dataflow API, at the time the current SDK version was released.
If the string contains "://", then this is treated as a url,
otherwise getApiRootUrl() is used as the root
url.
void setDataflowEndpoint(String value)
List<String> getExperiments()
Dataflow provides a number of experimental features that can be enabled with this flag.
Please sync with the Dataflow team before enabling any experiments.
String getApiRootUrl()
void setApiRootUrl(String value)
String getDataflowJobFile()
void setDataflowJobFile(String value)
Class<? extends com.google.cloud.dataflow.sdk.util.PathValidator> getPathValidatorClass()
void setPathValidatorClass(Class<? extends com.google.cloud.dataflow.sdk.util.PathValidator> validatorClass)
com.google.cloud.dataflow.sdk.util.PathValidator getPathValidator()
void setPathValidator(com.google.cloud.dataflow.sdk.util.PathValidator validator)
Class<? extends com.google.cloud.dataflow.sdk.util.Stager> getStagerClass()
void setStagerClass(Class<? extends com.google.cloud.dataflow.sdk.util.Stager> stagerClass)
com.google.cloud.dataflow.sdk.util.Stager getStager()
void setStager(com.google.cloud.dataflow.sdk.util.Stager stager)
com.google.api.services.dataflow.Dataflow getDataflowClient()
void setDataflowClient(com.google.api.services.dataflow.Dataflow value)
@Experimental boolean getReload()
void setReload(boolean value)