public interface DataflowPipelineOptions extends PipelineOptions, GcpOptions, ApplicationNameOptions, DataflowPipelineDebugOptions, DataflowPipelineWorkerPoolOptions, BigQueryOptions, GcsOptions, StreamingOptions, CloudDebuggerOptions, DataflowWorkerLoggingOptions
DataflowPipeline.| Modifier and Type | Interface and Description |
|---|---|
static class |
DataflowPipelineOptions.JobNameFactory
Returns a normalized job name constructed from
ApplicationNameOptions.getAppName(), the
local system user name (if available), and the current time. |
DataflowPipelineDebugOptions.DataflowClientFactory, DataflowPipelineDebugOptions.PathValidatorFactory, DataflowPipelineDebugOptions.StagerFactoryDataflowPipelineWorkerPoolOptions.AutoscalingAlgorithmType, DataflowPipelineWorkerPoolOptions.TeardownPolicyGcpOptions.CredentialDirFactory, GcpOptions.DefaultProjectFactory, GcpOptions.GcpUserCredentialsFactoryGoogleApiDebugOptions.GoogleApiTracerPipelineOptions.CheckEnabledGcsOptions.ExecutorServiceFactoryDataflowWorkerLoggingOptions.Level, DataflowWorkerLoggingOptions.WorkerLogLevelOverrides| Modifier and Type | Field and Description |
|---|---|
static String |
DATAFLOW_STORAGE_LOCATION |
| Modifier and Type | Method and Description |
|---|---|
String |
getJobName()
The Dataflow job name is used as an idempotence key within the Dataflow service.
|
String |
getProject()
Project id to use when launching jobs.
|
String |
getStagingLocation()
GCS path for staging local files, e.g.
|
String |
getTempLocation()
GCS path for temporary files, e.g.
|
void |
setJobName(String value) |
void |
setProject(String value) |
void |
setStagingLocation(String value) |
void |
setTempLocation(String value) |
getApiRootUrl, getDataflowClient, getDataflowEndpoint, getDataflowJobFile, getExperiments, getNumberOfWorkerHarnessThreads, getOverrideWindmillBinary, getPathValidator, getPathValidatorClass, getPubsubRootUrl, getStager, getStagerClass, getTransformNameMapping, getUpdate, setApiRootUrl, setDataflowClient, setDataflowEndpoint, setDataflowJobFile, setExperiments, setNumberOfWorkerHarnessThreads, setOverrideWindmillBinary, setPathValidator, setPathValidatorClass, setPubsubRootUrl, setStager, setStagerClass, setTransformNameMapping, setUpdategetAutoscalingAlgorithm, getDiskSizeGb, getDiskSourceImage, getFilesToStage, getMaxNumWorkers, getNetwork, getNumWorkers, getTeardownPolicy, getWorkerDiskType, getWorkerMachineType, getZone, setAutoscalingAlgorithm, setDiskSizeGb, setDiskSourceImage, setFilesToStage, setMaxNumWorkers, setNetwork, setNumWorkers, setTeardownPolicy, setWorkerDiskType, setWorkerMachineType, setZonegetTempDatasetId, setTempDatasetIdisStreaming, setStreaminggetAppName, setAppNamegetCredentialDir, getCredentialFactoryClass, getCredentialId, getGcpCredential, getSecretsFile, getServiceAccountKeyfile, getServiceAccountName, setCredentialDir, setCredentialFactoryClass, setCredentialId, setGcpCredential, setSecretsFile, setServiceAccountKeyfile, setServiceAccountNamegetGoogleApiTrace, setGoogleApiTraceas, cloneAs, getRunner, getStableUniqueNames, setRunner, setStableUniqueNamesgetExecutorService, getGcsEndpoint, getGcsUtil, setExecutorService, setGcsEndpoint, setGcsUtilgetEnableCloudDebugger, setEnableCloudDebuggergetDefaultWorkerLogLevel, getWorkerLogLevelOverrides, setDefaultWorkerLogLevel, setWorkerLogLevelOverridesstatic final String DATAFLOW_STORAGE_LOCATION
String getProject()
GcpOptionsgetProject in interface GcpOptionsvoid setProject(String value)
setProject in interface GcpOptionsString getTempLocation()
Must be a valid Cloud Storage url, beginning with the prefix "gs://"
At least one of getTempLocation() or getStagingLocation() must be set. If
getTempLocation() is not set, then the Dataflow pipeline defaults to using
getStagingLocation().
void setTempLocation(String value)
String getStagingLocation()
Must be a valid Cloud Storage url, beginning with the prefix "gs://"
At least one of getTempLocation() or getStagingLocation() must be set. If
getTempLocation() is not set, then the Dataflow pipeline defaults to using
getStagingLocation().
void setStagingLocation(String value)
String getJobName()
void setJobName(String value)