public interface DirectPipelineOptions extends ApplicationNameOptions, BigQueryOptions, GcsOptions, GcpOptions, PipelineOptions, StreamingOptions
DirectPipeline.GcpOptions.CredentialDirFactory, GcpOptions.DefaultProjectFactory, GcpOptions.GcpUserCredentialsFactoryGoogleApiDebugOptions.GoogleApiTracerPipelineOptions.CheckEnabledGcsOptions.ExecutorServiceFactory| Modifier and Type | Method and Description |
|---|---|
Long |
getDirectPipelineRunnerRandomSeed()
The random seed to use for pseudorandom behaviors in the
DirectPipelineRunner. |
void |
setDirectPipelineRunnerRandomSeed(Long value) |
getTempDatasetId, setTempDatasetIdisStreaming, setStreaminggetAppName, setAppNamegetCredentialDir, getCredentialFactoryClass, getCredentialId, getGcpCredential, getProject, getSecretsFile, getServiceAccountKeyfile, getServiceAccountName, setCredentialDir, setCredentialFactoryClass, setCredentialId, setGcpCredential, setProject, setSecretsFile, setServiceAccountKeyfile, setServiceAccountNamegetGoogleApiTrace, setGoogleApiTraceas, cloneAs, getRunner, getStableUniqueNames, setRunner, setStableUniqueNamesgetExecutorService, getGcsEndpoint, getGcsUtil, setExecutorService, setGcsEndpoint, setGcsUtilLong getDirectPipelineRunnerRandomSeed()
DirectPipelineRunner.
If not explicitly specified, a random seed will be generated.void setDirectPipelineRunnerRandomSeed(Long value)