public static class DataflowAssert.SingletonAssert<T> extends Object implements Serializable
T
associated with a PCollectionView.| Modifier | Constructor and Description |
|---|---|
protected |
SingletonAssert(com.google.cloud.dataflow.sdk.testing.DataflowAssert.CreateActual<?,T> createActual,
Pipeline pipeline) |
| Modifier and Type | Method and Description |
|---|---|
Coder<T> |
getCoder()
Gets the coder, which may yet be absent.
|
DataflowAssert.SingletonAssert<T> |
is(T expectedValue)
Deprecated.
replaced by
isEqualTo(T) |
DataflowAssert.SingletonAssert<T> |
isEqualTo(T expectedValue)
Checks that the value of this
SingletonAssert's view is equal
to the expected value. |
DataflowAssert.SingletonAssert<T> |
satisfies(DataflowAssert.AssertRelation<T,T> relation,
T expectedValue)
Applies an
DataflowAssert.AssertRelation to check the provided relation against the
value of this assert and the provided expected value. |
DataflowAssert.SingletonAssert<T> |
satisfies(SerializableFunction<T,Void> checkerFn)
Applies a
SerializableFunction to check the value of this
SingletonAssert's view. |
DataflowAssert.SingletonAssert<T> |
setCoder(Coder<T> coderOrNull)
Sets the coder to use for elements of type
T, as needed
for internal purposes. |
public DataflowAssert.SingletonAssert<T> setCoder(Coder<T> coderOrNull)
T, as needed
for internal purposes.
Returns this IterableAssert.
public DataflowAssert.SingletonAssert<T> satisfies(SerializableFunction<T,Void> checkerFn)
SerializableFunction to check the value of this
SingletonAssert's view.
Returns this SingletonAssert.
public DataflowAssert.SingletonAssert<T> satisfies(DataflowAssert.AssertRelation<T,T> relation, T expectedValue)
DataflowAssert.AssertRelation to check the provided relation against the
value of this assert and the provided expected value.
Returns this SingletonAssert.
public DataflowAssert.SingletonAssert<T> isEqualTo(T expectedValue)
SingletonAssert's view is equal
to the expected value.
Returns this SingletonAssert.
@Deprecated public DataflowAssert.SingletonAssert<T> is(T expectedValue)
isEqualTo(T)SingletonAssert's view is equal to
the expected value.