See: Description
| Interface | Description |
|---|---|
| RunnableOnService |
Category tag for tests that can be run on the
DataflowPipelineRunner if the
runIntegrationTestOnService System property is set to true. |
| TestDataflowPipelineOptions |
A set of options used to configure the
TestPipeline. |
| Class | Description |
|---|---|
| CoderProperties |
Properties for use in
Coder tests. |
| DataflowAssert |
An assertion on the contents of a
PCollection
incorporated into the pipeline. |
| DataflowAssert.IterableAssert<T> |
An assertion about the contents of a
PCollectionView yielding an Iterable<T>. |
| DataflowAssert.SingletonAssert<T> |
An assertion about the single value of type
T
associated with a PCollectionView. |
| SourceTestUtils |
Helper functions and test harnesses for checking correctness of
implementations. |
| TestDataflowPipelineRunner |
TestDataflowPipelineRunner is a pipeline runner that wraps a
DataflowPipelineRunner when running tests against the TestPipeline. |
| TestPipeline |
A creator of test pipelines that can be used inside of tests that can be
configured to run locally or against the live service.
|
| WindowFnTestUtils |
A utility class for testing
WindowFns. |
| Enum | Description |
|---|---|
| SourceTestUtils.ExpectedSplitOutcome |
Expected outcome of
BoundedSource.BoundedReader.splitAtFraction(double). |
PTransforms and
examples included the Dataflow SDK provide examples of using these utilities.