See: Description
| Interface | Description |
|---|---|
| DataflowAssert.AssertRelation<Actual,Expected> |
A serializable function implementing a binary predicate
between types
Actual and Expected. |
| RunnableOnService |
Category tag for tests that can be run on the DataflowPipelineRunner if the
runIntegrationTestOnService System property is set to true.
|
| TestDataflowPipelineOptions |
A set of options used to configure the
TestPipeline. |
| Class | Description |
|---|---|
| DataflowAssert |
An assertion on the contents of a
PCollection
incorporated into the pipeline. |
| DataflowAssert.AssertThat<Actual,Expected> | |
| DataflowAssert.IterableAssert<T> |
An assertion about the contents of a
PCollectionView<. |
| DataflowAssert.SingletonAssert<T> |
An assertion about the single value of type
T
associated with a PCollectionView. |
| TestDataflowPipelineRunner |
TestDataflowPipelineRunner is a pipeline runner that wraps a
DataflowPipelineRunner when running tests against the
TestPipeline. |
| TestPipeline |
A creator of test pipelines which can be used inside of tests that can be
configured to run locally or against the live service.
|
| WindowFnTestUtils |
A utility class for testing
WindowFns. |
PTransforms and
examples included the Dataflow SDK provide examples of using these utilities.