I - the type of the (main) input PCollection elementsO - the type of the (main) output PCollection elementspublic static class IntraBundleParallelization.Bound<I,O> extends PTransform<PCollection<? extends I>,PCollection<O>>
PTransform that, when applied to a PCollection<I>,
invokes a user-specified DoFn<I, O> on all its elements,
with all its outputs collected into an output
PCollection<O>.
Note that the specified doFn needs to be thread safe.
name| Modifier and Type | Method and Description |
|---|---|
PCollection<O> |
apply(PCollection<? extends I> input)
Applies this
PTransform on the given Input, and returns its
Output. |
<I,O> IntraBundleParallelization.Bound<I,O> |
of(DoFn<I,O> doFn)
|
IntraBundleParallelization.Bound<I,O> |
withMaxParallelism(int maxParallelism)
Returns a new
IntraBundleParallelization PTransform like this one
with the specified maximum concurrency level. |
finishSpecifyingInternal, getDefaultName, getDefaultOutputCoder, getDefaultOutputCoder, getDefaultOutputCoder, getKindString, getName, setName, setPipeline, toString, validate, withNamepublic IntraBundleParallelization.Bound<I,O> withMaxParallelism(int maxParallelism)
IntraBundleParallelization PTransform like this one
with the specified maximum concurrency level.public <I,O> IntraBundleParallelization.Bound<I,O> of(DoFn<I,O> doFn)
IntraBundleParallelization PTransform like this one
with the specified DoFn.
Note that the specified doFn needs to be thread safe.
public PCollection<O> apply(PCollection<? extends I> input)
PTransformPTransform on the given Input, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<Input, Output>, Input).
apply in class PTransform<PCollection<? extends I>,PCollection<O>>