N - the type of the Numbers being comparedpublic static class Max.MaxFn<N extends java.lang.Number & java.lang.Comparable<N>> extends java.lang.Object implements SerializableFunction<java.lang.Iterable<N>,N>
SerializableFunction that computes the maximum of an
Iterable of numbers of type N, useful as an
argument to Combine.globally(com.google.cloud.dataflow.sdk.transforms.SerializableFunction<java.lang.Iterable<V>, V>) or Combine.perKey(com.google.cloud.dataflow.sdk.transforms.SerializableFunction<java.lang.Iterable<V>, V>).| Constructor and Description |
|---|
Max.MaxFn(N initialValue)
Constructs a combining function that computes the maximum over
a collection of values of type
N, given the smallest
value of type N, which is the identity value for the
maximum operation over Ns. |
public Max.MaxFn(N initialValue)
N, given the smallest
value of type N, which is the identity value for the
maximum operation over Ns.public N apply(java.lang.Iterable<N> input)
SerializableFunction