I - the type of the (main) input PCollection elementsO - the type of the main output PCollection elementspublic static class ParDo.BoundMulti<I,O> extends PTransform<PCollection<? extends I>,PCollectionTuple>
PTransform that, when applied to a
PCollection<I>, invokes a user-specified
DoFn<I, O> on all its elements, which can emit elements
to any of the PTransform's main and side output
PCollections, which are bundled into a result
PCollectionTuple.name| Modifier and Type | Method and Description |
|---|---|
PCollectionTuple |
apply(PCollection<? extends I> input)
Applies this
PTransform on the given Input, and returns its
Output. |
protected java.lang.String |
getDefaultName()
Returns the name to use by default for this
PTransform
(not including the names of any enclosing PTransforms). |
protected Coder<O> |
getDefaultOutputCoder()
Returns the default
Coder to use for the output of this
single-output PTransform, or null if
none can be inferred. |
DoFn<I,O> |
getFn() |
protected java.lang.String |
getKindString()
Returns a string describing what kind of
PTransform this is. |
TupleTag<O> |
getMainOutputTag() |
java.util.List<PCollectionView<?,?>> |
getSideInputs() |
ParDo.BoundMulti<I,O> |
named(java.lang.String name)
Returns a new multi-output
ParDo PTransform
that's like this PTransform but with the specified
name. |
ParDo.BoundMulti<I,O> |
withSideInputs(java.lang.Iterable<? extends PCollectionView<?,?>> sideInputs)
Returns a new multi-output
ParDo PTransform
that's like this PTransform but with the specified side
inputs. |
ParDo.BoundMulti<I,O> |
withSideInputs(PCollectionView<?,?>... sideInputs)
Returns a new multi-output
ParDo PTransform
that's like this PTransform but with the specified side
inputs. |
finishSpecifying, getCoderRegistry, getDefaultOutputCoder, getInput, getName, getOutput, getPipeline, setName, setPipeline, toString, withNamepublic ParDo.BoundMulti<I,O> named(java.lang.String name)
ParDo PTransform
that's like this PTransform but with the specified
name. Does not modify this PTransform.
See the discussion of Naming above for more explanation.
public ParDo.BoundMulti<I,O> withSideInputs(PCollectionView<?,?>... sideInputs)
ParDo PTransform
that's like this PTransform but with the specified side
inputs. Does not modify this PTransform.
See the discussion of Side Inputs above and on
ParDo.withSideInputs(com.google.cloud.dataflow.sdk.values.PCollectionView<?, ?>...) for more explanation.
public ParDo.BoundMulti<I,O> withSideInputs(java.lang.Iterable<? extends PCollectionView<?,?>> sideInputs)
ParDo PTransform
that's like this PTransform but with the specified side
inputs. Does not modify this PTransform.
See the discussion of Side Inputs above and on
ParDo.withSideInputs(com.google.cloud.dataflow.sdk.values.PCollectionView<?, ?>...) for more explanation.
public PCollectionTuple apply(PCollection<? extends I> input)
PTransformPTransform on the given Input, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<Input, Output>, Input).
apply in class PTransform<PCollection<? extends I>,PCollectionTuple>protected Coder<O> getDefaultOutputCoder()
PTransformCoder to use for the output of this
single-output PTransform, or null if
none can be inferred.
By default, returns null.
getDefaultOutputCoder in class PTransform<PCollection<? extends I>,PCollectionTuple>protected java.lang.String getDefaultName()
PTransformPTransform
(not including the names of any enclosing PTransforms).
By default, returns PTransform.getKindString().
The caller is responsible for ensuring that names of applied
PTransforms are unique, e.g., by adding a uniquifying
suffix when needed.
getDefaultName in class PTransform<PCollection<? extends I>,PCollectionTuple>protected java.lang.String getKindString()
PTransformPTransform this is.
By default, returns the base name of this
PTransform's class.
getKindString in class PTransform<PCollection<? extends I>,PCollectionTuple>public java.util.List<PCollectionView<?,?>> getSideInputs()