R - The type of the elements of the input PCollectionT - The type associated with the PCollectionView used as a side inputWT - The type associated with a windowed side input from the
PCollectionViewpublic static class View.CreatePCollectionView<R,T,WT> extends PTransform<PCollection<R>,PCollectionView<T,WT>>
For internal use only.
name| Constructor and Description |
|---|
View.CreatePCollectionView(PCollectionView<T,WT> view) |
| Modifier and Type | Method and Description |
|---|---|
PCollectionView<T,WT> |
apply(PCollection<R> input)
Applies this
PTransform on the given Input, and returns its
Output. |
finishSpecifying, getCoderRegistry, getDefaultName, getDefaultOutputCoder, getDefaultOutputCoder, getInput, getKindString, getName, getOutput, getPipeline, setName, setPipeline, toString, withNamepublic View.CreatePCollectionView(PCollectionView<T,WT> view)
public PCollectionView<T,WT> apply(PCollection<R> input)
PTransformPTransform on the given Input, and returns its
Output.
Composite transforms, which are defined in terms of other transforms, should return the output of one of the composed transforms. Non-composite transforms, which do not apply any transforms internally, should return a new unbound output and register evaluators (via backend-specific registration methods).
The default implementation throws an exception. A derived class must
either implement apply, or else each runner must supply a custom
implementation via
PipelineRunner.apply(com.google.cloud.dataflow.sdk.transforms.PTransform<Input, Output>, Input).
apply in class PTransform<PCollection<R>,PCollectionView<T,WT>>