public static class DisplayData.Item extends Object
DisplayData.Builder.add(java.lang.String, java.lang.String) within
HasDisplayData.populateDisplayData(com.google.cloud.dataflow.sdk.transforms.display.DisplayData.Builder) implementations. Each metadata item is uniquely
identified by the specified key and namespace generated from the registering component's
class name.| Modifier and Type | Method and Description |
|---|---|
String |
getKey() |
String |
getLabel()
Retrieve the optional label for an item.
|
String |
getLinkUrl()
Retrieve the optional link URL for an item.
|
String |
getNamespace() |
String |
getShortValue()
Return the optional short value for an item.
|
com.google.cloud.dataflow.sdk.transforms.display.DisplayData.Type |
getType()
Retrieve the
DisplayData.Type of display metadata. |
String |
getValue()
Retrieve the value of the metadata item.
|
String |
toString() |
public String getNamespace()
public String getKey()
public com.google.cloud.dataflow.sdk.transforms.display.DisplayData.Type getType()
DisplayData.Type of display metadata. All metadata conforms to a
predefined set of allowed types.public String getValue()
@Nullable public String getShortValue()
value.
Some display data types will not provide a short value, in which case the return value will be null.
@Nullable public String getLabel()
If no label was specified, this will return null.
@Nullable public String getLinkUrl()
If no URL was specified, this will return null.