| Modifier and Type | Class and Description |
|---|---|
static class |
KeyedPCollectionTuple.TaggedKeyedPCollection<K,V>
A utility class to help ensure coherence of tag and input PCollection
types.
|
| Modifier and Type | Method and Description |
|---|---|
<V> KeyedPCollectionTuple<K> |
and(TupleTag<V> tag,
PCollection<KV<K,V>> pc)
Returns a new
KeyedPCollections<K> that is the same as this,
appended with the given PCollection. |
<O extends POutput> |
apply(PTransform<KeyedPCollectionTuple<K>,O> transform)
Applies the given transform to this input.
|
static <K> KeyedPCollectionTuple<K> |
empty(Pipeline pipeline)
Returns an empty
KeyedPCollections<K> on the given pipeline. |
java.util.Collection<? extends PValue> |
expand()
Expands the component PCollections, stripping off any tag-specific
information.
|
void |
finishSpecifying()
After building, finalizes this PInput to make it ready for
being used as an input to a PTransform.
|
CoGbkResultSchema |
getCoGbkResultSchema()
Returns the CoGbkResultSchema associated with this
KeyedPCollections.
|
Coder<K> |
getKeyCoder()
Returns the KeyCoder for all PCollections in this KeyedPCollections.
|
java.util.List<KeyedPCollectionTuple.TaggedKeyedPCollection<K,?>> |
getKeyedCollections()
Returns a list of TaggedKeyedPCollections for the PCollections contained in
this
KeyedPCollections<K>. |
Pipeline |
getPipeline()
Returns the owning Pipeline of this PInput.
|
boolean |
isEmpty() |
static <K,VI> KeyedPCollectionTuple<K> |
of(TupleTag<VI> tag,
PCollection<KV<K,VI>> pc)
Returns a new
KeyedPCollections<K> with the given tag and initial
PCollection. |
public static <K> KeyedPCollectionTuple<K> empty(Pipeline pipeline)
KeyedPCollections<K> on the given pipeline.public static <K,VI> KeyedPCollectionTuple<K> of(TupleTag<VI> tag, PCollection<KV<K,VI>> pc)
KeyedPCollections<K> with the given tag and initial
PCollection.public <V> KeyedPCollectionTuple<K> and(TupleTag<V> tag, PCollection<KV<K,V>> pc)
KeyedPCollections<K> that is the same as this,
appended with the given PCollection.public boolean isEmpty()
public java.util.List<KeyedPCollectionTuple.TaggedKeyedPCollection<K,?>> getKeyedCollections()
KeyedPCollections<K>.public <O extends POutput> O apply(PTransform<KeyedPCollectionTuple<K>,O> transform)
public java.util.Collection<? extends PValue> expand()
public Coder<K> getKeyCoder()
public CoGbkResultSchema getCoGbkResultSchema()
public Pipeline getPipeline()
PInputgetPipeline in interface PInputpublic void finishSpecifying()
PInputAfter building, finalizes this PInput to make it ready for being used as an input to a PTransform.
Automatically invoked whenever apply() is invoked on
this PInput, so users do not normally call this explicitly.
finishSpecifying in interface PInput