W - BoundedWindow subclass used to represent the windows used by this
AtMostOnceTriggerpublic abstract static class Trigger.OnceTrigger<W extends BoundedWindow> extends Trigger<W>
Triggers that are guaranteed to fire at most once should extend from this, rather
than the general Trigger class to indicate that behavior.Trigger.MergeResult, Trigger.MergingTriggerInfo<W extends BoundedWindow>, Trigger.OnceTrigger<W extends BoundedWindow>, Trigger.OnElementContext, Trigger.OnMergeContext, Trigger.OnTimerContext, Trigger.TriggerContext, Trigger.TriggerInfo<W extends BoundedWindow>, Trigger.TriggerResultsubTriggers| Modifier | Constructor and Description |
|---|---|
protected |
OnceTrigger(List<Trigger<W>> subTriggers) |
| Modifier and Type | Method and Description |
|---|---|
Trigger.OnceTrigger<W> |
getContinuationTrigger()
Return a trigger to use after a
GroupByKey to preserve the
intention of this trigger. |
buildTrigger, clear, equals, getContinuationTrigger, getWatermarkThatGuaranteesFiring, hashCode, isCompatible, onElement, onMerge, onTimer, orFinally, prefetchOnElement, prefetchOnMerge, prefetchOnTimer, subTriggers, toStringpublic final Trigger.OnceTrigger<W> getContinuationTrigger()
TriggerGroupByKey to preserve the
intention of this trigger. Specifically, triggers that are time based
and intended to provide speculative results should continue providing
speculative results. Triggers that fire once (or multiple times) should
continue firing once (or multiple times).getContinuationTrigger in class Trigger<W extends BoundedWindow>