public class PBegin extends java.lang.Object implements PInput
PBegin is used as the "input" to a root
PTransform which
is the first operation in a Pipeline, such as
TextIO.Read or
Create.
Typically created by calling Pipeline.begin() on a Pipeline.
| Modifier | Constructor and Description |
|---|---|
protected |
PBegin(Pipeline pipeline)
Constructs a
PBegin in the given Pipeline. |
| Modifier and Type | Method and Description |
|---|---|
<Output extends POutput> |
apply(PTransform<? super PBegin,Output> t)
Applies the given PTransform to this input PBegin, and
returns the PTransform's Output.
|
java.util.Collection<? extends PValue> |
expand()
Expands this PInput into a list of its component input PValues.
|
void |
finishSpecifying()
After building, finalizes this PInput to make it ready for
being used as an input to a PTransform.
|
Pipeline |
getPipeline()
Returns the owning Pipeline of this PInput.
|
static PBegin |
in(Pipeline pipeline)
Returns a
PBegin in the given Pipeline. |
protected PBegin(Pipeline pipeline)
PBegin in the given Pipeline.public <Output extends POutput> Output apply(PTransform<? super PBegin,Output> t)
public Pipeline getPipeline()
PInputgetPipeline in interface PInputpublic java.util.Collection<? extends PValue> expand()
PInputA PValue expands to itself.
A tuple or list of PValues (e.g., PCollectionTuple, and PCollectionList) expands to its component PValues.
Not intended to be invoked directly by user code.
public void finishSpecifying()
PInputAfter building, finalizes this PInput to make it ready for being used as an input to a PTransform.
Automatically invoked whenever apply() is invoked on
this PInput, so users do not normally call this explicitly.
finishSpecifying in interface PInput