public interface PInput
PTransform.| Modifier and Type | Method and Description |
|---|---|
java.util.Collection<? extends PValue> |
expand()
Expands this PInput into a list of its component input PValues.
|
void |
finishSpecifying()
After building, finalizes this PInput to make it ready for
being used as an input to a PTransform.
|
Pipeline |
getPipeline()
Returns the owning Pipeline of this PInput.
|
Pipeline getPipeline()
java.lang.IllegalStateException - if the owning Pipeline hasn't been
set yetjava.util.Collection<? extends PValue> expand()
A PValue expands to itself.
A tuple or list of PValues (e.g., PCollectionTuple, and PCollectionList) expands to its component PValues.
Not intended to be invoked directly by user code.
void finishSpecifying()
After building, finalizes this PInput to make it ready for being used as an input to a PTransform.
Automatically invoked whenever apply() is invoked on
this PInput, so users do not normally call this explicitly.