public interface POutput
PTransform.| Modifier and Type | Method and Description |
|---|---|
java.util.Collection<? extends PValue> |
expand()
Expands this
POutput into a list of its component output
PValues. |
void |
finishSpecifyingOutput()
As part of finishing the producing
PTransform, finalizes this
PTransform output to make it ready for being used as an input and
for running. |
void |
recordAsOutput(Pipeline pipeline,
PTransform<?,?> transform)
Records that this
POutput is an output of the given
PTransform in the given Pipeline. |
java.util.Collection<? extends PValue> expand()
POutput into a list of its component output
PValues.
A PValue expands to itself.
A tuple or list of PValues (e.g.,
PCollectionTuple, and
PCollectionList) expands to its component PValues.
Not intended to be invoked directly by user code.
void recordAsOutput(Pipeline pipeline, PTransform<?,?> transform)
POutput is an output of the given
PTransform in the given Pipeline.
Should expand this POutput and invoke
PValue#recordAsOutput(Pipeline,
com.google.cloud.dataflow.sdk.transforms.PTransform,
String) on each component output PValue.
Automatically invoked as part of applying a
PTransform. Not to be invoked directly by user code.
void finishSpecifyingOutput()
PTransform, finalizes this
PTransform output to make it ready for being used as an input and
for running.
This includes ensuring that all PCollections
have Coders specified or defaulted.
Automatically invoked whenever this POutput is used
as a PInput to another PTransform, or if never
used as a PInput, when Pipeline.run() is called, so
users do not normally call this explicitly.