PCollection and other classes for
representing data in a Pipeline.See: Description
| Interface | Description |
|---|---|
| PCollectionView<T> |
A
PCollectionView<T> is an immutable view of a
PCollection as a value of type T that can be accessed e.g. |
| PInput |
The interface for things that might be input to a
PTransform. |
| POutput |
The interface for things that might be output from a
PTransform. |
| PValue |
A
PValue is the interface to values that can be
input and output from PTransforms. |
| Class | Description |
|---|---|
| KV<K,V> |
An immutable key/value pair.
|
| KV.OrderByKey<K extends Comparable<? super K>,V> |
Orders the
KV by the key. |
| KV.OrderByValue<K,V extends Comparable<? super V>> |
Orders the
KV by the value. |
| PBegin |
PBegin is used as the "input" to a root PTransform that is the first
operation in a Pipeline, such as TextIO.Read or Create. |
| PCollection<T> |
A
PCollection<T> is an immutable collection of values of type
T. |
| PCollectionList<T> |
A
PCollectionList<T> is an immutable list of homogeneously
typed PCollection<T>s. |
| PCollectionTuple |
A
PCollectionTuple is an immutable tuple of
heterogeneously-typed PCollections, "keyed" by
TupleTags. |
| PDone |
PDone is the output of a
PTransform that
doesn't have a non-trival result, e.g., a Write. |
| POutputValueBase |
A
POutputValueBase is the abstract base class of
PTransform outputs. |
| PValueBase |
A
PValueBase is an abstract base class that provides
sensible default implementations for methods of PValue. |
| TimestampedValue<V> |
An immutable (value, timestamp) pair.
|
| TimestampedValue.TimestampedValueCoder<T> |
A
Coder for TimestampedValue. |
| TupleTag<V> |
A
TupleTag is a typed tag to use as the key of a
heterogeneously typed tuple, like PCollectionTuple. |
| TupleTagList |
A
TupleTagList is an immutable list of heterogeneously
typed TupleTags. |
| TypeDescriptor<T> |
A description of a Java type, including actual generic parameters where possible.
|
| TypedPValue<T> |
A
TypedPValue<T> is the abstract base class of things that
store some number of values of type T. |
| Enum | Description |
|---|---|
| PCollection.IsBounded |
The PCollection IsBounded property.
|
PCollection and other classes for
representing data in a Pipeline.
A PCollection is an immutable collection of
values of type T and is the main representation for data.
A PCollectionTuple is a tuple of PCollections
used in cases where PTransforms take or return multiple PCollections.
A PCollectionTuple is an immutable tuple of
heterogeneously-typed PCollections, "keyed" by
TupleTags.
A PCollectionTuple can be used as the input or
output of a
PTransform taking
or producing multiple PCollection inputs or outputs that can be of
different types, for instance a
ParDo with side
outputs.
A PCollectionView is an immutable view of a
PCollection that can be accessed from a DoFn and other user Fns
as a side input.