Skip navigation links

Google Cloud Dataflow SDK 1.0.0 API

Packages 
Package Description
com.google.cloud.dataflow.sdk
Provides a simple, powerful model for building both batch and streaming parallel data processing Pipelines.
com.google.cloud.dataflow.sdk.annotations
Defines annotations used across the SDK.
com.google.cloud.dataflow.sdk.coders
Defines Coders to specify how data is encoded to and decoded from byte strings.
com.google.cloud.dataflow.sdk.io
Defines transforms for reading and writing common storage formats, including AvroIO, BigQueryIO, and TextIO.
com.google.cloud.dataflow.sdk.io.range  
com.google.cloud.dataflow.sdk.options
Defines PipelineOptions for configuring pipeline execution.
com.google.cloud.dataflow.sdk.runners
Defines runners for executing Pipelines in different modes, including DirectPipelineRunner and DataflowPipelineRunner.
com.google.cloud.dataflow.sdk.runners.dataflow
Implementation of the DataflowPipelineRunner.
com.google.cloud.dataflow.sdk.runners.worker
Implementation of the harness that runs on each Google Compute Engine instance to coordinate execution of Pipeline code.
com.google.cloud.dataflow.sdk.runners.worker.logging  
com.google.cloud.dataflow.sdk.runners.worker.windmill  
com.google.cloud.dataflow.sdk.testing
Defines utilities for unit testing Dataflow pipelines.
com.google.cloud.dataflow.sdk.transforms
Defines PTransforms for transforming data in a pipeline.
com.google.cloud.dataflow.sdk.transforms.join
Defines the CoGroupByKey transform for joining multiple PCollections.
com.google.cloud.dataflow.sdk.transforms.windowing
Defines the Window transform for dividing the elements in a PCollection into windows, and the Trigger for controlling when those elements are output.
com.google.cloud.dataflow.sdk.util
Defines utilities used by the Dataflow SDK.
com.google.cloud.dataflow.sdk.util.common
Defines utilities shared by multiple PipelineRunner implementations.
com.google.cloud.dataflow.sdk.util.common.worker
Defines utilities used to implement the harness that runs user code.
com.google.cloud.dataflow.sdk.util.gcsfs
Defines utilities used to interact with Google Cloud Storage.
com.google.cloud.dataflow.sdk.util.state  
com.google.cloud.dataflow.sdk.values
Defines PCollection and other classes for representing data in a Pipeline.
Skip navigation links