Skip navigation links

Google Cloud Dataflow SDK 0.4.150710 API

Packages 
Package Description
com.google.cloud.dataflow.sdk
Provides a simple, powerful model for building both batch and streaming parallel data processing Pipelines.
com.google.cloud.dataflow.sdk.annotations
Defines annotations used across the SDK.
com.google.cloud.dataflow.sdk.coders
Defines Coders to specify how data is encoded to and decoded from byte strings.
com.google.cloud.dataflow.sdk.io
Defines transforms for reading and writing common storage formats, including AvroIO, BigQueryIO, and TextIO.
com.google.cloud.dataflow.sdk.io.range  
com.google.cloud.dataflow.sdk.options
Defines PipelineOptions for configuring pipeline execution.
com.google.cloud.dataflow.sdk.runners
Defines runners for executing Pipelines in different modes, including DirectPipelineRunner and DataflowPipelineRunner.
com.google.cloud.dataflow.sdk.testing
Defines utilities for unit testing Dataflow pipelines.
com.google.cloud.dataflow.sdk.transforms
Defines PTransforms for transforming data in a pipeline.
com.google.cloud.dataflow.sdk.transforms.join
Defines the CoGroupByKey transform for joining multiple PCollections.
com.google.cloud.dataflow.sdk.transforms.windowing
Defines the Window transform for dividing the elements in a PCollection into windows, and the Trigger for controlling when those elements are output.
com.google.cloud.dataflow.sdk.values
Defines PCollection and other classes for representing data in a Pipeline.
Skip navigation links